/****************************************************************************
* (C) 1999-2006 by BECK IPC GmbH
*
*  BECK IPC GmbH
*  Germany
*  
*  http://www.beck-ipc.com
*
* ---------------------------------------------------------------------------
* Module         : TCPIP.C
* Function       : TCPIP API socket functions
* ---------------------------------------------------------------------------

$Header: TCPIP.C, 83, 12.10.2006 14:41:45, Andre Pribil$

*****************************************************************************/

#include <STDLIB.H>
#include <DOS.H>
#include "common.h"
#include "config.h"
#include <TCPIPAPI.H>
#include <TCPIP.H>
#include "TCPPRIV.H"


/*************************************************************************/
//HTONS
/*************************************************************************/
#define HTONS(value)  ( (unsigned)(value<<8)|(unsigned)(value>>8) )

#define BIOS_VECT  (0xA0)       // Software Interrupt number for BIOS API
// Services


/*
  Note: The DOCLIST.EXE tool used by the C-Library HTML build process reacts
        to the token "#DOCLIST:" when it appears as the first non-white space
        on a line.  The tool transfers the text which follows into the
        BeckCLib.LST file that is used for the context sensitive help.


  #DOCLIST:DnsMailHost tcpstruc.htm


 @doc DOC_INDEX
 ---------------------------------------------------------------
 TCP/IP API Table of Contents
 ---------------------------------------------------------------
 @clibidx  <tab><cfont>#include <InBraces TCPIP\.H><efont><nl>
  <tab><tab><tab><tab><tab><arial>which includes<ariale> <cfont>
 <InBraces TCPIPAPI\.H><efont> |
    <tab><linkto>#TCP<linkmid>TCP/IP<linktail><tab>
    <tab><linkto>#PKI<linkmid>IPSec/PKI/SSL<linktail><tab>
    <linkto>#Client<linkmid>PPP Client<linktail><tab>
    <linkto>#Server<linkmid>PPP Server<linktail><tab>
    <linkto>#Other<linkmid>Other<linktail><tab>
 @libcat1a  TCP | TCP/IP | tcpIPR | Get_IPConfig | Get IP, subnet mask and/or gateway |
 @libcat1a  TCP | TCP/IP | tcpIPW | Set_IPConfig | Set IP, subnet mask and/or gateway |
 @libcat1a  TCP | TCP/IP | tcpPSIp | PPP_Server_GetIP | Get IP Address of the PPP Server |
 @libcat1a  TCP | TCP/IP | tcpPCIp | PPP_Client_GetIP | Get IP Address of the PPP Client |
 @libcat1a  TCP | TCP/IP | tcp11 | InetToAscii | Convert an IPv4 address to an IP string |
 @libcat1a  TCP | TCP/IP | tcp08 | inet_addr | Converts a string containing
    an IPv4 address in dot notation  |
 @libcat1a  TCP | TCP/IP | tcpC1 | inet_pton | Convert an IP address
    (IPv4 or IPv6) from standard text representation to binary|
 @libcat1a  TCP | TCP/IP | tcpC2 | inet_ntop | Convert an IP address
    (IPv4 or IPv6) from binary to standard text representation|

 @libcat1a  TCP | TCP/IP | tcp01  | opensocket   | <nl>Open TCP or UDP IPv4 socket | <tab><tab>--- Socket Functions ---<nl>
 @libcat1a  TCP | TCP/IP | tcpC3  | opensocket_ext   | Open an IPv4 or IPv6 socket |
 @libcat1a  TCP | TCP/IP | tcp02  | closesocket  | Close socket |
 @libcat1a  TCP | TCP/IP | tcp03  | bind         | Associates a local address with a socket |
 @libcat1a  TCP | TCP/IP | tcp04  | connect | Establish a connection to a specifed socket |
 @libcat1a  TCP | TCP/IP | tcp0C | GetWaitingBytes | Report the number of bytes on a socket |
 @libcat1a  TCP | TCP/IP | tcp15 | Set_IP_Type_Of_Service | Set socket's Type-Of-Service |
 @libcat1a  TCP | TCP/IP | tcp16 | setsockopt | Set options on a socket |
 @libcat1a  TCP | TCP/IP | tcp17 | getsockopt | Get options on a socket |
 @libcat1a  TCP | TCP/IP | tcp18 | Set_Blocking_Mode | Set a socket in blocking or non-blocking mode |
 @libcat1a  TCP | TCP/IP | tcp21 | get_socketerror | Get last socket error |

 @libcat1a  TCP | TCP/IP | tcpcon | tcp_connect  | <nl>Open TCP/IP socket and connect | <tab><tab>--- TCP/IP Sockets ---<nl>
 @libcat1a  TCP | TCP/IP | tcp0D | accept | Accept the next incoming connection |
 @libcat1a  TCP | TCP/IP | tcp0E | listen | Listen for incoming connections |
 @libcat1a  TCP | TCP/IP | tcphton | htons | Converts a 16 bit word from host to TCP/IP network byte order |
 @libcat1a  TCP | TCP/IP | tcp0F | send | Transmit a message (TCP) |
 @libcat1a  TCP | TCP/IP | tcp10 | recv | Receive message (TCP) |
 @libcat1a  TCP | TCP/IP | tcp12 | ResetConnection | Abort a connection on a socket |
 @libcat1a  TCP | TCP/IP | tcp13 | setlinger | Set linger time on close (TCP) |
 @libcat1a  TCP | TCP/IP | tcp14 | setreuse | Set reuse option on a listening socket |
 @libcat1a  TCP | TCP/IP | tcp22 | Get_TCP_Socket_State | Find TCP socket and return state |
 @libcat1a  TCP | TCP/IP | tcp24 | Get_TCP_Socket_State_IP_All | Find TCP socket and return state (IPv4 and IPv6)|
 @libcat1a  TCP | TCP/IP | tcp23 | FindAllOpenSockets | Get information about all open sockets |
 @libcat1a  TCP | TCP/IP | tcp25 | FindAllOpenSockets_IP_All | Get information about all open sockets (IPv4 and IPv6)|
 @libcat1a  TCP | TCP/IP | tcp26 | Shutdown | Shutdown socket in read,write or both directions |

 @libcat1a  TCP | TCP/IP | tcp05 | recvfrom | <nl>Receive a datagram and store the source address | <tab><tab>--- UDP Sockets ---<nl>
 @libcat1a  TCP | TCP/IP | tcp27 | recvfromto | <nl>Receive a datagram and store source and dest. address |
 @libcat1a  TCP | TCP/IP | tcp06 | sendto | Transmit a datagram |
 @libcat1a  TCP | TCP/IP | tcp28 | sendto_iface | Transmit a datagram via specified device|

 @libcat1a  TCP | TCP/IP | tcp30 | getHostByName   | <nl>Get a host's address(es) by domain name (IPv4) | <tab><tab>--- DNS Resolver ---<nl>
 @libcat1a  TCP | TCP/IP | tcp31 | getHostByName2  | Get a host's address(es) by domain name (IPv6) |
 @libcat1a  TCP | TCP/IP | tcp32 | getHostByAddr  | Get a host's domain name by address (IPv4) |
 @libcat1a  TCP | TCP/IP | tcp33 | getHostByAddr2  | Get a host's domain name by address (IPv6) |
 @libcat1a  TCP | TCP/IP | tcp34 | getMailHosts  | Get mail hosts |
 @libcat1a  TCP | TCP/IP | tcp35 | setNameServer  | Add prioritised name server |

 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| ipsec_index | IP Security  | <nl>API | <tab><tab>--- IP Security ---<nl>
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpD0 | PKI_CertificateAdd  | <nl>Add a certificate to the PKI | <tab><tab>--- PKI Functions ---<nl>
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpD1 | PKI_CertificateDel  | Delete a certificate from the PKI |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpD2 | PKI_OwnKeyPairAdd   | Add own private/public key pair |

 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpD8 | SSL_SessionNew      | <nl>Open a new SSL session | <tab><tab>--- SSL Functions ---<nl>
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpD7 | SSL_SessionClose    | Close a SSL session |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpD9 | SSL_SessionProp     | Set SSL session proposals |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDA | SSL_SessionOpt      | Set SSL session options |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDB | SSL_AddClientCA     | Add a client CA certificate |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDC | SSL_ClientStart     | Start the SSL client |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDD | SSL_SendFlush       | Flush SSL user data |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDE | SSL_ConnClose       | Close a SSL connection |

 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDFA | Crypt_MD5_Init     | <nl>Init MD5 checksum generator | <tab><tab>--- Cryptographic Functions ---<nl>
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDFB | Crypt_MD5_Update   | Update MD5 hash |
 @libcat1b  PKI | IPsec/PKI/SSL/CRYPT| tcpDFC | Crypt_MD5_Final    | Finalize MD5 hash |

 @libcat2y  PPP | Client | tcp40 | PPP_Client_Installed | Check if PPP client is installed |
 @libcat2y  PPP | Client | tcp41 | PPP_Client_Open | Open a PPP connection (IPv4) |
 @libcat2y  PPP | Client | tcp46 | PPP_Client_Open_IPv6  | Open a PPP
        connection with IPv6 address config |
 @libcat2y  PPP | Client | tcp42 | PPP_Client_Close | Close a PPP client connection |
 @libcat2y  PPP | Client | tcp43 | PPP_Client_GetStatus | Get PPP client status |
 @libcat2y  PPP | Client | tcp44 | PPP_Client_Get_DNSIP | Get DNS IP |
 @libcat2y  PPP | Client | tcp45 | PPP_Client_SetOptions | Set PPP options for the PPP client |
 @libcat2y  PPP | Client | tcpPCIp | PPP_Client_GetIP | Get IP Address of the PPP Client |

 @libcat3y  PPP | Server | tcp50 | PPP_Server_Installed | Check if PPP server is installed |
 @libcat3y  PPP | Server | tcp51 | PPP_Server_Suspend | Suspend the PPP server task |
 @libcat3y  PPP | Server | tcp52 | PPP_Server_Activate | Activate the PPP server |
 @libcat3y  PPP | Server | tcp53 | PPP_Server_GetStatus | Get the current state of the PPP server |
 @libcat3y  PPP | Server | tcp54 | PPP_Server_Get_Cfg | Get configuration data of
                        the IPv4 PPP server |
 @libcat3y  PPP | Server | tcp56 | PPP_Server_Get_Cfg_IPv6 | Get configuration data of
                        the IPv6 PPP server |
 @libcat3y  PPP | Server | tcp55 | PPP_Server_SetOptions | Set PPP options for the PPP server |
 @libcat3y  PPP | Server | tcpPSIp | PPP_Server_GetIP | Get IP Address of the PPP Server |

 @libcat4  Other | tcp65 | Get_FTP_Login_Counters | <nl>Access the FTP server login counters | <tab><tab>--- Monitoring ---<nl>
 @libcat4  Other | tcp66 | Get_Telnet_Login_Counters | Access the Telnet server login counters |
 @libcat4  Other | tcp67 | Get_Telnet_State | Check if have an active telnet session |
 @libcat4  Other | tcp70 | Get_Installed_Servers | Get information about running servers |
 @libcat4  Other | tcp78 | Get_TCPIP_Memory_Status | Get information about TCP/IP stack memory usage |
 @libcat4  Other | tcp74 | Get_TCPIP_Statistics | Access the internal network packet counter |
 @libcat4  Other | tcp60 | Get_SNMP_Data | Get internal TCP/IP SNMP variables |
 @libcat4  Other | tcp60a | Get_SNMP_DataEx | Get internal TCP/IP SNMP variables (Extended) |

 @libcat4  Other | tcp72 | DHCP_use | <nl>Set/Reset DHCP usage of the Ethernet interface | <tab><tab>--- DHCP ---<nl>
 @libcat4  Other | tcp73 | Get_DHCP_Status | Get DHCP status of the Ethernet interface |
 @libcat4  Other | tcp73a | Get_DHCP_Status_Ext | Get DHCP status of the Ethernet interface |

 @libcat4  Other | tcp75 | Ping_Open | <nl>Open and start ICMP echo requests | <tab><tab>--- ping ---<nl>
 @libcat4  Other | tcp76 | Ping_Close | Finish ICMP echo requests |
 @libcat4  Other | tcp77 | Ping_Statistics | Retrieve ping information |

 @libcat4  Other | tcp79 | Set_FTPServer_Idle_Timeout | <nl>Set FTP server time-out  | <tab><tab>--- Server Time-outs ---<nl>
 @libcat4  Other | tcp79a | Set_TelnetServer_Idle_Timeout | Set Telnet server time-out  |
 @libcat4  Other | tcp79b | Get_FTPServer_Idle_Timeout | Get FTP server time-out value  |
 @libcat4  Other | tcp79c | Get_TelnetServer_Idle_Timeout | Get Telnet server time-out value  |

 @libcat4  Other | tcp80 | AddDefaultGateway | <nl>Add the default gateway | <tab><tab>--- Gateway ---<nl>
 @libcat4  Other | tcp80a | AddDefaultGatewayEx | Add the default gateway (Extended) |
 @libcat4  Other | tcp81 | DelDefaultGateway | Delete the default gateway |
 @libcat4  Other | tcp82 | GetDefaultGateway | Get the current default gateway |
 @libcat4  Other | tcp83 | AddStaticRoute | Add a route for a interface |
 @libcat4  Other | tcp84 | DelStaticRoute | Delete a route from an interface |

 @libcat4  Other | tcp88 | DelArpEntryByPhys | <nl>Delete ARP entry by physical address | <tab><tab>--- ARP cache access ---<nl>
 @libcat4  Other | tcp89 | AddArpEntry | Add an entry in the ARP table |
 @libcat4  Other | tcp8A | GetARPRouteCacheEntries | Read ARP cache table|

 @libcat4  Other | tcp90 | Add_IGMP_Membership | <nl>Install an IP multicast address entry | <tab><tab>--- IP Multicast ---<nl>
 @libcat4  Other | tcp91 | Drop_IGMP_Membership | Delete an IP multicast address entry |
 @libcat4  Other | tcp92 | IPMulticast_to_MacAddr | Map IP multicast address to Ethernet address |

 @libcat4  Other | tcpA0  | Dev_Open_Interface | <nl>Install user device driver | <tab><tab>--- TCP/IP Device driver ---<nl>
 @libcat4  Other | tcpA1  | Dev_Close_Interface |  Close user device driver/interface |
 @libcat4  Other | tcpA2  | Dev_Recv_Interface |  Receive and process incoming data |
 @libcat4  Other | tcpA3  | Dev_Recv_Wait | Waits for data received signal |
 @libcat4  Other | tcpA4  | Dev_Notify_ISR | Signal from Interrupt Service Routine |
 @libcat4  Other | tcpA5  | Dev_Get_Buffer | Get a buffer from TCP/IP stack        |
 @libcat4  Other | tcpA6  | Dev_Send_Complete | Signal message send complete     |
 @libcat4  Other | tcpA7  | Dev_Wait_DHCP_Complete | Waits for DHCP completion   |
 @libcat4  Other | tcpA8  | Dev_PPP_Register_Chap | Register a PPP CHAP authentication callback function |
 @libcat4  Other | tcpA9  | Dev_PPP_Register_Pap  | Register a PPP PAP  authentication callback function |
 @libcat4  Other | tcpAA  | Dev_PPP_Set_Option | Set PPP options  |
 @libcat4  Other | tcp9F  | Dev_Get_IP | Get IP address of a user defined device |
 @libcat4  Other | tcpAB  | Dev_PPP_Get_Peer_IP | Get IP address of a PPP peer |
 @libcat4  Other | tcpAC  | Dev_PPP_Get_Peer_DNSIP | Get IP address of the DNS server from a PPP peer |
 @libcat4  Other | tcpAD  | Dev_Get_Handle_By_Name | Get device driver handle by device name |
 @libcat4  Other | tcpAE  | Dev_Config_Iface | IPv4 device configuration |
 @libcat4  Other | tcpAF  | Dev_Config_Iface_IPv6 | IPv6 configuration of an interface |
 @libcat4  Other | tcpB0  | Dev_UnConfig_Iface | Remove IPv4 or IPv6 device configuration from particular home index|
 @libcat4  Other | tcp19 | RegisterCallbackFunction | <nl>Register a user TCP callback function | <tab><tab>--- Callback Installers ---<nl>
 @libcat4  Other | tcp7a | RegisterIPCallbackHandler | Register an User callback handler for incoming IP packets|
 @libcat4  Other | tcp7c | RegisterIPCallbackHandler_Snd | Register an User callback handler for outgoing IP packets |
 @libcat4  Other | tcp7b | Register_ARP_User_CB | Register an ARP User callback handler. |

 @libcat4  Other | tcp09 | api_sleep | <nl>Sleep for specified number of milliseconds | <tab><tab>--- Miscellaneous ---<nl>
 @libcat4  Other | tcp71 | Reconfigure_ethernet | Reconfigure Ethernet interface |
 @libcat4  Other | tcp8D | Get_Iface_Entries | Read table of TCP/IP device interfaces |
 @libcat4  Other | tcp8F | Get_Iface_Entries_Ext | Read table of TCP/IP device interfaces with all IPv4 configurations/per interface|
 @libcat4  Other | tcp8E | SetIfaceMTU | Set MTU of an device interface |
 @libcat4  Other | tcpC0 | Get_IPv6_Iface_Entries | TCP/IP IPv6 device interface information |


*/

/*************************************************************************/
// Get IP of the Ethernet interface
/*************************************************************************/
#ifdef _tcpIPR_
/*
 @doc DOC_tcpIPR_
 ---------------------------------------------------------------
 Get IP, Net Mask of the default Ethernet interface and the Gateway
 ---------------------------------------------------------------
 @clib  Get_IPConfig | Get IP, subnet mask  
        and/or gateway of the default Ethernet interface. |
        <cfont>void Get_IPConfig ( char far *IP,<nl>
        <tab><tab><tab><tab><tab>char far *Mask,<nl>
        <tab><tab><tab><tab><tab>char far *Gateway );<efont> |
 @parm  int  | IP  | Output parameter:<s2> Pointer to a 16 byte memory area
        where the IP address is to be stored as a null terminated string.
 @parm  int  | Mask  | Output parameter:<s2> Pointer to a 16 byte memory area
        where the subnet mask is to be stored as a null terminated string.
 @parm  int  | Gateway | Output parameter:<s2> Pointer to a 16 byte memory
        area where the gateway address is to be stored as a null terminated
        string.
 @rdesc -- none --
 @comm  Any of the three output parameters can be set to NULL pointers if
        the respective output is not desired.
 @commtarget SC1x3 |
        This function applies only to the IPv4 configuration of the internal
        integrated Ethernet device interface.<nl>
        <nl>
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../biosints.htm#0xA00x01<linkmid>documentation<linktail>
        for more details.

 @Also tcpIPW.htm | Set_IPConfig  | 
       tcpC0.htm | Get_IPv6_Iface_Entries |  |
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 |  n/a  | V0.90
*/
void Get_IPConfig (char far *IP, char far * Mask, char far *Gateway)
{
    if (FP_SEG(IP))
    {
        _DX = FP_OFF(IP);
        _ES = FP_SEG(IP);
        _AH = 0x01;                         // Get IP Address in [ES:DX]
        asm { int BIOS_VECT  } ;
    }

    if (FP_SEG(Mask))
    {
        _DX = FP_OFF(Mask);
        _ES = FP_SEG(Mask);
        _AH = 0x03;                         // Get Net Mask in [ES:DX]
        asm { int BIOS_VECT  } ;
    }

    if (FP_SEG(Gateway))
    {
        _DX = FP_OFF(Gateway);
        _ES = FP_SEG(Gateway);
        _AH = 0x05;                         // Get Gateway in [ES:DX]
        asm { int BIOS_VECT  } ;
    }
}
#endif

/*************************************************************************/
// Set IP configuration,becomes valid after call of reconfigure Ethernet
/*************************************************************************/
#ifdef _tcpIPW_
/*
 @doc DOC_tcpIPW_
 ---------------------------------------------------------------
 Set IP, Net Mask of the default Ethernet interface and/or Gateway
 ---------------------------------------------------------------
 @clib  Set_IPConfig | Set IP, subnet mask of the default Ethernet interface
         and/or gateway. |
        <cfont>void Set_IPConfig ( const char far *IP,<nl>
        <tab><tab><tab><tab><tab>const char far *Mask,<nl>
        <tab><tab><tab><tab><tab>const char far *Gateway );<efont> |
 @parm  int  | IP  | Pointer to new IP address expressed as a null
        terminated ASCII string in network address dot notation.
 @parm  int  | Mask  | Pointer to new net submask expressed as a null
        terminated ASCII string in dot notation.
 @parm  int  | Gateway | Pointer to new gateway address expressed as a null
        terminated ASCII string in dot notation.
 @rdesc -- none --
 @comm  Any of the three parameters can be set to NULL pointers if
        the respective value is not to be set.<nl>
        <nl>
 @comm  <bold>Important:<bolde><nl>
        This API function writes to chip.ini and is not reentrant.<s2>
        Do not use this API in combination with other tasks or @CHIP-RTOS commands
        which are writing to chip.ini, e.g. DHCP.<s2> Avoid race conditions with
        any other API call which writes or reads to/from the chip.ini,
        e.g. <linkto>../../BIOSINTS.HTM#0xA00x23<linkmid>BIOS service 0x23<linktail>.
 @commtarget SC1x3 |
        This function applies only to the IPv4 configuration of the internal
        integrated Ethernet device interface.<nl>
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../biosints.htm#0xA00x02<linkmid>documentation<linktail>
        for more details.
 @Also  tcpPSIp.htm | PPP_Server_GetIP |
        tcpPCIp.htm | PPP_Client_GetIP |
        tcpIPR.htm  | Get_IPConfig
 @Also  tcp71.htm   | Reconfigure_ethernet | | | |
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 |  n/a  | V0.90

*/
void Set_IPConfig(const char far *IP,
                  const char far *Mask,
                  const char far *Gateway)
{
    if (FP_SEG(IP))
    {
        _DX = FP_OFF(IP);
        _ES = FP_SEG(IP);
        _AH = 0x02;                         // Set IP Address in [ES:DX]
        asm { int BIOS_VECT  } ;
    }

    if (FP_SEG(Mask))
    {
        _DX = FP_OFF(Mask);
        _ES = FP_SEG(Mask);
        _AH = 0x04;                         // Set Net Mask in [ES:DX]
        asm { int BIOS_VECT  } ;
    }

    if (FP_SEG(Gateway))
    {
        _DX = FP_OFF(Gateway);
        _ES = FP_SEG(Gateway);
        _AH = 0x06;                         // Set Gateway in [ES:DX]
        asm { int BIOS_VECT  } ;
    }
}
#endif

/*************************************************************************/
//PPP Server IP
/*************************************************************************/
#ifdef _tcpPSIp_
/*
 @doc DOC_tcpPSIp_
 ---------------------------------------------------------------
 Reads the IP Address of the PPP Server
 ---------------------------------------------------------------
 @clib  PPP_Server_GetIP | Reads the IP Address of the PPP Server |
        <cfont>void PPP_Server_GetIp (char far *IP );<efont> |
 @parm  int  | IP  | Output parameter:<s2> Pointer to a 16 byte
        memory area where the IPv4 address is to be stored as a null
        terminated string.
 @rdesc -- none --
 @comm  Copies the current IPv4 address of the PPP Server into the provided
        string.<s2> If no IP address of the PPP Server is available, the string
        will be empty.<nl>
 @commtarget SC1x3 |
        <bold>This function is deprecated,<bolde> because it does not work if the 
        PPP server uses the IPv6 protocol.<s2> The IP configuration of
        all TCP/IP devices can be read
        by using <linkto>tcp8D.htm<linkmid>Get_Iface_Entries<linktail>
        or <linkto>tcpC0.htm<linkmid>Get_IPv6_Iface_Entries<linktail>.<nl>

 @Also  tcpIPR.htm | Get_IPConfig |
        tcpPCIp.htm | PPP_Client_GetIP | |
 @Also  tcp8D.htm | Get_Iface_Entries |
        tcpC0.htm | Get_IPv6_Iface_Entries | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../biosints.htm#0xA00x50<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
void PPP_Server_GetIP (char far *IP)
{
    _DX = FP_OFF(IP);
    _ES = FP_SEG(IP);
    _AH = 0x50;
    asm { int BIOS_VECT  } ;
}
#endif





/*************************************************************************/
//PPP Client IP
/*************************************************************************/
#ifdef _tcpPCIp_
/*
 @doc DOC_tcpPCIp_
 ---------------------------------------------------------------
 Reads the IP Address of the PPP Client
 ---------------------------------------------------------------
 @clib  PPP_Client_GetIP | Reads the IP Address of the PPP Client |
        <cfont>void PPP_Client_GetIP ( const char far *IP );<efont> |
 @parm int  | IP  | Output parameter:<s2> Pointer to a 16 byte
        memory area where the IPv4 address is to be stored as a null
        terminated string.
 @rdesc -- none --
 @comm   Copies the current IPv4 address of the PPP Client into the provided
        string.<s2> If no IP address of the PPP Client is available, the string
        will be empty.<nl>
 @commtarget SC1x3 |
        <bold>This function is deprecated,<bolde> because it does not work if the 
        PPP server uses the IPv6 protocol.<s2> The IP configuration of
        all TCP/IP devices can be read using either 
         <linkto>tcp8D.htm<linkmid>Get_Iface_Entries<linktail>
        or <linkto>tcpC0.htm<linkmid>Get_IPv6_Iface_Entries<linktail>.<nl>
 @Also  tcpIPR.htm | Get_IPConfig |
        tcpPSIp.htm | PPP_Server_GetIP | |
 @Also  tcp8D.htm | Get_Iface_Entries |
        tcpC0.htm | Get_IPv6_Iface_Entries | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../biosints.htm#0xA00x55<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90
*/
void PPP_Client_GetIP (const char far *IP)
{
    _DX = FP_OFF(IP);
    _ES = FP_SEG(IP);
    _AH = 0x55;
    asm { int BIOS_VECT  } ;
}
#endif


/*****************************************************************************
*
*  open a tcp connection
*
*  DestIPStr: destination IP address format xxx.xxx.xxx.xxx
*  ClientPort: local port (0=random port)
*  HostPort: remote port
*  error: TCP/IP error
*
*
*  return: socket descriptor (-1 = error)
*/

#ifdef _tcpcon_
/*
 @doc DOC_tcpcon_
 ---------------------------------------------------------------
 open a tcp connection
 ---------------------------------------------------------------
 @clib  tcp_connect | Open a client TCP/IP socket connection to a specified
        host. |
        <cfont>int tcp_connect ( const char far *DestIPStr,<nl>
        <tab><tab><tab><tab>&nbsp; unsigned int ClientPort,<nl>
        <tab><tab><tab><tab>&nbsp; unsigned int HostPort,<nl>
        <tab><tab><tab><tab>&nbsp; int *error );<efont> |
 @parm  int  | DestIPStr  | Pointer to server's IPv4 address, 
        expressed as a null terminated ASCII string in network dot notation.
 @parm  int  | ClientPort  | Optional local port number to assign to socket.<s2>
        Set this to zero if a bind operation is not desired (random port).
 @parm  int  | HostPort    | Remote port number to which connection is desired.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1 = Failure (see <code>error<codee> output parameter) <nl>
        else new socket descriptor
 @comm This function calls the required set of TCP/IP functions
        to establish a IPv4 client connection to a host.<nl>
        <nl>
        Pseudo code:<nl>
        <nl>
        <code>
        struct sockaddr_in addr;<nl>
        int sd = opensocket(SOCK_STREAM, error) ;<nl>
        addr.sin_family = PF_INET ;<nl>
        addr.sin_addr.s_addr =  0 ;<nl>
        IF ClientPort != 0 THEN<nl>
        <tab>addr.sin_port = htons(ClientPort) ;<nl>
        <tab>bind(sd, &addr, error) ;<nl>
        ENDIF<nl>
        addr.sin_port = htons(HostPort) ;<nl>
        error = inet_addr(DestIPStr, &addr.sin_addr.s_addr) ;<nl>
        error = connect (sd, (const struct sockaddr *)&addr) ;<nl>
        return sd ;<nl>
        <codee><nl>
        <nl>
        The error handling is not shown in the above simplified pseudo code.<s2>
        In case of errors, the socket is closed by this API function and a return
        is made from the point of the error with return value -1.<s2>
        On success, the new socket descriptor is returned.<s2> The caller is then
        responsible for calling <linkto>tcp02.htm<linkmid>closesocket<linktail> when
        finished with the connection.
 @commtarget SC1x3 |
        The actual library function reached 
        here is named <code>tcp_connect_ipstackV2<codee>.<s2> The name change
        occurs due to a macro in the library header file.
         
 @Also  tcp01.htm | opensocket  |
        tcphton.htm | htons  |
        tcp03.htm | bind
 @Also  tcp08.htm | inet_addr  |
        tcp04.htm | connect  |
        tcp02.htm | closesocket
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90
*/
#undef tcp_connect     // Maintain original name

    // This version is for original SC12 TCP/IP stack
int tcp_connect (const char far *DestIPStr,
                 unsigned int ClientPort,
                 unsigned int HostPort,
                 int *error)
{
    int local_error;
    // sd = socket descriptor, open socket
    int sd = opensocket (SOCK_STREAM, &local_error) ;
    if (local_error == 0)                       // Open successful?
    {
        struct sockaddr_in_ipstack addr;

        addr.sin_family = PF_INET ;
        addr.sin_addr.s_addr =  0 ;
        if (ClientPort != 0)
        {   // force client port
            addr.sin_port = HTONS(ClientPort);  // convert byte order
            bind (sd, (const struct sockaddr *)&addr, &local_error ) ;
        }
        if (local_error == 0)                   // No bind failure?
        {
            addr.sin_port = HTONS(HostPort); // convert byte order
            // convert server IP address string to binary
            local_error = inet_addr (DestIPStr, &addr.sin_addr.s_addr);
            if (local_error == 0)               // Valid IP address?
            {
                // establish a connection to the server
                connect (sd, (const struct sockaddr *)&addr, &local_error) ;
            }
        }
        if (local_error)                        // Failure?
        {
            int discard_error ;
            closesocket (sd, &discard_error) ;  // Give up.
            sd = -1 ;
        }
    }
    *error = local_error ;                      // Set output parameter

    return sd ;
}  // tcp_connect()

#endif //tcpcon

#ifdef _tcpcone_
    // This version is for new TCP/IP version, used  at target sc123
int tcp_connect_ipstackV2(const char far *DestIPStr,
                          unsigned int ClientPort,
                          unsigned int HostPort,
                          int *error)
{
    int local_error;
    // sd = socket descriptor, open socket
    int sd = opensocket (SOCK_STREAM, &local_error) ;
    if (local_error == 0)                       // Open successful?
    {
        struct sockaddr_in_ipstackV2 addr;

        addr.sin_family = PF_INET ;
        addr.sin_addr.s_addr =  0 ;
        if (ClientPort != 0)
        {   // force client port
            addr.sin_port = HTONS(ClientPort);  // convert byte order
            bind (sd, (const struct sockaddr *)&addr, &local_error ) ;
        }
        if (local_error == 0)                   // No bind failure?
        {
            addr.sin_port = HTONS(HostPort); // convert byte order
            // convert server IP address string to binary
            local_error = inet_addr (DestIPStr, &addr.sin_addr.s_addr);
            if (local_error == 0)               // Valid IP address?
            {
                // establish a connection to the server
                connect (sd, (const struct sockaddr *)&addr, &local_error) ;
            }
        }
        if (local_error)                        // Failure?
        {
            int discard_error ;
            closesocket (sd, &discard_error) ;  // Give up.
            sd = -1 ;
        }
    }
    *error = local_error ;                      // Set output parameter

    return sd ;
}  // tcp_connect()
#endif  //tcpcon_e

/*************************************************************************/
// open socket
/*************************************************************************/
#ifdef _tcp01_
/*
 @doc DOC_tcp01_
 ---------------------------------------------------------------
 open socket
 ---------------------------------------------------------------
 @clib  opensocket | Open a socket. |
        <cfont>int opensocket ( unsigned char type, int *error );<efont> |
 @parm  int  | type  | SOCK_STREAM = 1 for TCP socket<nl>
        SOCK_DGRAM = 2 for UDP datagram socket.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1: Failure (see <code>error<codee> output parameter)<nl>
        else socket descriptor
 @comm  Creates an endpoint for communication and returns a socket descriptor.
        This function provides the BSD socket() functionality.
 @commtarget SC1x3 |
        This function applies only to IPv4 sockets.<s2> The
        <linkto>tcpC3.htm<linkmid>opensocket_ext<linktail> API may be used
        to open either IPv4 or IPv6 sockets.
 @Also  tcp02.htm | closesocket  |
        tcp03.htm | bind |
        tcp04.htm | connect
 @Also  tcpC3.htm | opensocket_ext  |
        |  | | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x01<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int opensocket (unsigned char type, int *error)
{
    int sd ;
    int error_code = 0 ;
    _AL = type ;
    _AH = API_OPENSOCKET;
    asm { int TCPIPVECT  } ;
    sd = _AX ;
    if (_DX != 0)
    {
        error_code = sd ;       // Error code was returned in AX.
        sd = -1 ;
    }
    *error = error_code ;
    return sd ;
}
#endif


/*************************************************************************/
// close socket
/*************************************************************************/
#ifdef _tcp02_
/*
 @doc DOC_tcp02_
 ---------------------------------------------------------------
 close socket
 ---------------------------------------------------------------
 @clib  closesocket | Close a socket. |
        <cfont>int closesocket ( int sd, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | error | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1: Failure (see <code>error<codee> output parameter)<nl>
         0: success
 @comm  Closes the socket indicated by <code>sd<codee> and releases all of
        its associated resources.

 @Also tcp01.htm | opensocket  | 
       tcpC3.htm | opensocket_ext | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x02<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90
*/
int closesocket (int sd, int *error)
{
    _BX = sd ;
    _AH = API_CLOSESOCKET;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
// bind
/*************************************************************************/
#ifdef _tcp03_
/*
 @doc DOC_tcp03_
 ---------------------------------------------------------------
 Bind socket
 ---------------------------------------------------------------
 @clib  bind | Bind an unnamed socket to an address and port number. |
        <cfont>int bind ( int sd,<nl>
        <tab><tab>&nbsp;&nbsp; const struct sockaddr far *addressPtr,<nl>
        <tab><tab>&nbsp;&nbsp; int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm int  | addressPtr  | Pointer to a
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail> 
         (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure preset by caller.

 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>

 @comm  It is only necessary to use the bind call in server applications.<s2>
        If you use the bind call in a client application, the client uses the
        given port number as its own source port address.<s2> Otherwise a random
        16-bit source port number will be used when no bind call is made.<nl>
        <nl>
        The caller must fill in the
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail> (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure at <code>addressPtr<codee> prior 
          to making this API call.<s2>An example (IPv4) of how this
        can be done follows.<s2> This function's prototype uses a pointer to the 
        generic type <code>sockaddr<codee> for its <code>addressPtr<codee> parameter,  
        for compatibility between IPv4 and IPv6 protocols.<s2> The pointer to the
        <code>sockaddr_in<codee> (IPv4) or <code>sockaddr_in6<codee> (IPv6) 
        data structure which
        is actually used should be cast to this type as shown below to avoid 
        compiler warnings, "Suspicious pointer conversion".<nl>

        @raw
        // Example
        int ClientPort = 4000 ;
        struct sockaddr_in addr ;
        int error_code ;

        addr.sin_family = PF_INET ;
        addr.sin_addr.s_addr =  0 ;
        addr.sin_port = htons(ClientPort);   // convert byte order
        error_code = bind (sd, (const struct sockaddr *)&addr, &error_code) ;

 @Also  tcp01.htm | opensocket  |
        tcpC3.htm | opensocket_ext  |
        tcp04.htm | connect 

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x03<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90
*/
int bind (int sd, const struct sockaddr far * addressPtr, int *error)
{
    _DX = FP_SEG(addressPtr);
    _SI = FP_OFF(addressPtr);
    _BX = sd ;
    _AH = API_BIND;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;
}
#endif

/*************************************************************************/
// connect
/*************************************************************************/
#ifdef _tcp04_
/*
 @doc DOC_tcp04_
 ---------------------------------------------------------------
 Connect socket
 ---------------------------------------------------------------
 @clib  connect | Connect to another socket. |
        <cfont>int connect ( int sd,<nl>
        <tab><tab><tab>&nbsp; const struct sockaddr far *addressPtr,<nl>
        <tab><tab><tab>&nbsp; int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm int  | addressPtr  | Pointer to a 
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>  (IPv4) or
         <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
          (IPv6, <i>SC123/SC143 only!<ie>) data structure containing host's IP 
          address and port number.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm   The caller must fill in the
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>  (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure at <code>addressPtr<codee>
         prior to calling here.<s2> An example of how
        this normally would be done follows.<s2> The PF_INET setting for the
        <code>sin_family<codee> is required for IPv4.<s2> For IPv6 set 
        <code>sin6_family<codee> to PF_INET6.<nl>
        <nl>
        This function's prototype uses a pointer to the 
        generic type <code>sockaddr<codee> for its <code>addressPtr<codee> parameter,  
        for compatibility between IPv4 and IPv6 protocols.<s2> The pointer to the
        <code>sockaddr_in<codee> or <code>sockaddr_in6<codee> data structure which
        is actually used should be cast to this type as shown below to avoid 
        compiler warnings, "Suspicious pointer conversion".<nl>        <nl>

        @raw
        // Example
        char szHostIPStr[] = "172.30.1.68" ;
        int HostPort = 4000 ;
        struct sockaddr_in addr ;
        int error_code ;

        addr.sin_family = PF_INET ;
        addr.sin_addr.s_addr =  0 ;
        addr.sin_port = htons (HostPort) ;   // convert byte order

        // convert server IP address string to binary
        inet_addr (szHostIPStr, &addr.sin_addr.s_addr);
        // establish a connection to the server
        error_code = connect (sd, (const struct sockaddr far *)&addr) ;

 @Also  tcp01.htm | opensocket |
        tcpcon.htm | tcp_connect  |
        tcphton.htm | htons
 @Also  tcpc3.htm | opensocket_ext |
        tcp08.htm | inet_addr |
        tcp03.htm | bind

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x04<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90


*/
int connect (int sd, const struct sockaddr far * addressPtr, int *error)
{
    _DX = FP_SEG(addressPtr);
    _SI = FP_OFF(addressPtr);
    _BX = sd ;
    _AH = API_CONNECT;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif


/*************************************************************************/
//recvfrom
/*************************************************************************/
#ifdef _tcp05_
/*
 @doc DOC_tcp05_
 ---------------------------------------------------------------
 UDP only, receive message from another socket
 ---------------------------------------------------------------
 @clib  recvfrom | Receive message from another socket. |
        <cfont>int recvfrom ( int sd, char far *bufptr, int bufLen,<nl>
        <tab><tab><tab>&nbsp;&nbsp; int flags, unsigned long timeout,<nl>
        <tab><tab><tab>&nbsp;&nbsp; struct sockaddr far *fromPtr,<nl>
        <tab><tab><tab>&nbsp;&nbsp; int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | bufptr  | Pointer to input buffer where received
        characters will be output.
 @parm  int  | bufLen  | Maximum characters to store in
        buffer at <code>bufptr<codee>.
 @parm  int  | flags  | Wait option:<nl>
        <ul>
        <li><bold>MSG_BLOCKING<bolde>  - Sleep until data comes in<nl>
        <li><bold>MSG_TIMEOUT<bolde>  - The caller wakes up after timeout or
           if <code>bufLen<codee> data bytes are received.<nl>
        <li><bold>MSG_DONTWAIT<bolde> - Return immediately after collecting 
           what ever data is ready<nl>
        <ule>
 @parm  int  | timeout  | Maximum milliseconds to wait if <code>flags<codee> is set
        to MSG_TIMEOUT:<nl>
 @parm int  | fromPtr  | Output parameter:<s2>Pointer to a
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail> 
         (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure, which will be set
         to indicate from where the received data originated.<s2> This pointer 
         can be set to NULL if this information is not desired.<nl>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1:  Failure, see error value reported<nl>
        otherwise: Count of bytes received and placed in <code>bufptr<codee><s2>
        (0 if time-out)
 @comm   This API function applies only to UDP sockets.<nl>
        <nl>
        The MSG_BLOCKING mode will not work if the socket has
        been put into non-blocking mode using the
        <linkto>tcp18.htm<linkmid>Set_Blocking_Mode<linktail> API.<nl>
        <nl>
 @comm  This function's prototype takes a pointer to the 
        generic type <code>sockaddr<codee> for its <code>fromPtr<codee> parameter,  
        for compatibility between IPv4 and IPv6 protocols.<s2> The pointer to the
        <code>sockaddr_in<codee>  (IPv4) or <code>sockaddr_in6<codee>  
        (IPv6, <i>SC123/SC143 only!<ie>) data structure which
        is actually used should be cast to a <code>sockaddr<codee> type 
        pointer to avoid compiler warnings, "Suspicious pointer conversion".<nl>
        <nl>
 @commtarget SC1x3 |
        The actual library function reached 
        here is named <code>recvfrom_ipstackV2<codee>.<s2> The name change
        occurs due to a macro in the library header file.

 @Also  tcp06.htm | sendto  |
        tcp01.htm | opensocket |
        tcp18.htm | Set_Blocking_Mode
 @Also  tcpC3.htm | opensocket_ext  | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x05<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
#undef recvfrom     // Maintain original name
                   // This version is for the new TCP/IP version, used  at target sc123
int recvfrom(int sd, char far * bufptr, int bufLen, int flags,
             unsigned long timeout,
             struct sockaddr far * fromPtr,
             int *error)
{
    int bytes_received ;
    int the_error_code = 0 ;
    int fromLen;
    struct recv_params R;



    //fill the struct recv_param R
    fromLen          =   sizeof(struct sockaddr_in_ipstack);
    R.bufferPtr      =   bufptr;
    R.bufferLength   =   bufLen;
    R.flags          =   flags;
    R.fromPtr        =   (struct sockaddr *)fromPtr;
    R.fromlengthPtr  =   &fromLen;
    R.timeout        =   timeout; /*milliseconds*/


    //API
    _BX = sd;
    _DX = FP_SEG(&R);
    _SI = FP_OFF(&R);
    _AH = API_RECVFROM;
    asm { int TCPIPVECT  } ;
    bytes_received = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_received ;       // AX value
        bytes_received = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_received ;

}
#endif //#ifdef _tcp05_

#ifdef _tcp05e_
    // This version is for SC123 TCP/IP version supporting IPv6
int recvfrom_ipstackV2(int sd, char far * bufptr, int bufLen, int flags,
                       unsigned long timeout,
                       struct sockaddr far * fromPtr,
                       int *error)
{
    int bytes_received ;
    int the_error_code = 0 ;
    int fromLen;
    struct recv_params R;


    //fill the struct recv_param R
    if ( ((struct sockaddr_in_ipstackV2 far *)fromPtr)->sin_family == AF_INET)
    {
       fromLen          =   sizeof(struct sockaddr_in_ipstackV2);
    }
    else
    {
       fromLen          =   sizeof(struct sockaddr_in6);
    }
    R.bufferPtr      =   bufptr;
    R.bufferLength   =   bufLen;
    R.flags          =   flags;
    R.fromPtr        =   (struct sockaddr *)fromPtr;
    R.fromlengthPtr  =   &fromLen;
    R.timeout        =   timeout; /*milliseconds*/

    //API
    _BX = sd;
    _DX = FP_SEG(&R);
    _SI = FP_OFF(&R);
    _AH = API_RECVFROM;
    asm { int TCPIPVECT  } ;
    bytes_received = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_received ;       // AX value
        bytes_received = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_received ;

}
#endif //#ifdef _tcp05e


/*************************************************************************/
//recvfromto
/*************************************************************************/
#ifdef _tcp27_
/*
 @doc DOC_tcp27_
 -----------------------------------------------------------------------------
 UDP only, receive message from another socket and store destination address
 -----------------------------------------------------------------------------
 @clib  recvfromto | Same as recvfrom, but returns the destination address |
        <cfont>int recvfromto ( int sd, char far *bufptr, int bufLen,<nl>
        <tab><tab><tab>&nbsp;&nbsp; int flags, unsigned long timeout,<nl>
        <tab><tab><tab>&nbsp;&nbsp; struct sockaddr far *fromPtr,<nl>
        <tab><tab><tab>&nbsp;&nbsp; struct sockaddr far *toPtr,<nl>
        <tab><tab><tab>&nbsp;&nbsp; int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | bufptr  | Pointer to input buffer where received
        characters will be output.
 @parm  int  | bufLen  | Maximum characters to store in
        buffer at <code>bufptr<codee>.
 @parm  int  | flags  | Wait option:<nl>
        <ul>
        <li><bold>MSG_BLOCKING<bolde>  - Sleep until data comes in<nl>
        <li><bold>MSG_TIMEOUT<bolde>  - The caller wakes up after timeout or
           if <code>bufLen<codee> data bytes are received.<nl>
        <li><bold>MSG_DONTWAIT<bolde> - Return immediately after collecting
           what ever data is ready<nl>
        <ule>
 @parm  int  | timeout  | Maximum milliseconds to wait if <code>flags<codee> is set
        to MSG_TIMEOUT:<nl>
 @parm int  | fromPtr  | Output parameter:<s2>Pointer to a
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>
         (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure, which will be set
         to indicate from where the received data originated.<s2> This pointer
         can be set to NULL if this information is not desired.<nl>

 @parm int  | toPtr  | Output parameter:<s2>Pointer to a user provided storage from type
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>
         (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure, which will contain
         (after sucessful return) the destination address.<nl>

 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1:  Failure, see error value reported<nl>
        otherwise: Count of bytes received and placed in <code>bufptr<codee><s2>
        (0 if time-out). Storage pointed by toPtr holds the destination address.<nl>
        occurs due to a macro in the library header file.

 @Also  tcp05.htm | recvfrom | | | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x27<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version     n/a  | n/a   | n/a   | V1.07

*/
int recvfromto(int sd, char far * bufptr, int bufLen, int flags,
               unsigned long timeout,
               struct sockaddr far * fromPtr,
               struct sockaddr far * toPtr,
               int *error)
{
    int bytes_received ;
    int the_error_code = 0 ;
    int fromLen;
    struct recv_params R;

    //fill the struct recv_param R
    fromLen          =   sizeof(struct sockaddr_in_ipstack);
    R.bufferPtr      =   bufptr;
    R.bufferLength   =   bufLen;
    R.flags          =   flags;
    R.fromPtr        =   (struct sockaddr *)fromPtr;
    R.fromlengthPtr  =   &fromLen;
    R.timeout        =   timeout; /*milliseconds*/


    //API
    _BX = sd;
    _DX = FP_SEG(&R);
    _SI = FP_OFF(&R);
    _ES = FP_SEG(toPtr);
    _DI = FP_OFF(toPtr);
    _AH = API_RECVFROM_TO;
    asm { int TCPIPVECT  } ;
    bytes_received = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_received ;       // AX value
        bytes_received = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_received ;

}
#endif //#ifdef _tcp27_





/*************************************************************************/
//sendto
/*************************************************************************/
#ifdef _tcp06_
/*
 @doc DOC_tcp06_
 ---------------------------------------------------------------
 Transmit a datagram
 ---------------------------------------------------------------
 @clib  sendto | Transmit a datagram. |
        <cfont>int sendto ( int sd, const char far *bufptr, int bufLen,<nl>
        <tab><tab><tab> int flags, const struct sockaddr far *toPtr,<nl>
        <tab><tab><tab> int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | bufptr  | Pointer to output buffer containing
        characters to be transmitted.
 @parm  int  | bufLen  | Maximum characters to output from <code>bufptr<codee>.
 @parm  int  | flags  | Wait option:<nl>
        <ul>
        <li><bold>MSG_BLOCKING<bolde>  - Wait for data send to complete.<nl>
        <li><bold>MSG_DONTWAIT<bolde> - Don't wait for data send to complete.<nl>
        <ule>
 @parm  int  | toPtr  | Data destination, pointer to a
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>
         (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure.

 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1:  Failure, see error value reported<nl>
        otherwise: Count of bytes transfered into the socket send queue.
 @comm  This API function applies only to UDP sockets.<s2>
        This function will output up to <code>bufLen<codee> bytes from the buffer
        at <code>bufptr<codee> to the IP address specified by the 
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail> 
        (IPv4) structure or
        the  <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
        (IPv6, <i>SC123/SC143 only!<ie>) structure referenced by the 
        <code>toPtr<codee> parameter.<nl>
        <nl>
        This function's prototype takes a pointer to the 
        generic type <code>sockaddr<codee> for its <code>toPtr<codee> parameter,  
        for compatibility between IPv4 and IPv6 protocols.<s2> The pointer to the
        <code>sockaddr_in<codee> (IPv4) or <code>sockaddr_in6<codee>
        (IPv6, <i>SC123/SC143 only!<ie>) data structure which
        is actually used should be cast to a <code>sockaddr<codee> type 
        pointer to avoid compiler warnings, "Suspicious pointer conversion".<nl>
        <nl>
        The MSG_BLOCKING mode will not work if the socket has
        been put into non-blocking mode using the
        <linkto>tcp18.htm<linkmid>Set_Blocking_Mode<linktail> API.<nl>
        <nl>
 @commtarget SC1x3 |
        The actual library function reached here is named 
        <code>sendto_ipstackV2<codee>.<s2> The name change
        occurs due to a macro in the library header file. 

 @Also  tcp05.htm | recvfrom  |
        tcp01.htm | opensocket |
        tcp18.htm | Set_Blocking_Mode

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x06<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
#undef sendto     // Maintain original name

   // This version is for original SC12 TCP/IP stack
int sendto (int sd, const char far * bufptr, int bufLen, int flags,
            const struct sockaddr far * toPtr, int *error)
{
    int bytes_sent ;
    int the_error_code = 0 ;
    int toLen;
    struct send_params S;

    toLen = sizeof(struct sockaddr_in_ipstack);

    //Init the struct send_param S for API-Call

    S.bufferPtr      = bufptr;
    S.bufferLength   = bufLen;
    S.flags          = flags;
    S.toPtr          = (struct sockaddr *) toPtr;
    S.tolengthPtr    = &toLen;

    //API
    _BX = sd;
    _DX = FP_SEG(&S);
    _SI = FP_OFF(&S);
    _AH = API_SENDTO;
    asm { int TCPIPVECT  } ;
    bytes_sent = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_sent ;       // AX value
        bytes_sent = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_sent ;
}
#endif

#ifdef _tcp06e_
// This version is for the new TCP/IP version, used  at target sc123
int sendto_ipstackV2(int sd, const char far * bufptr, int bufLen, int flags,
                      const struct sockaddr far * toPtr, int *error)
{
    int bytes_sent ;
    int the_error_code = 0 ;
    int toLen;
    struct send_params S;

    if ( ((struct sockaddr_in_ipstackV2 far *)toPtr)->sin_family == AF_INET)
    {
       toLen = sizeof(struct sockaddr_in_ipstackV2);
    }
    else
    {
       toLen = sizeof(struct sockaddr_in6);
    }

    //Init the struct send_param S for API-Call
    S.bufferPtr      = bufptr;
    S.bufferLength   = bufLen;
    S.flags          = flags;
    S.toPtr          = (struct sockaddr *) toPtr;
    S.tolengthPtr    = &toLen;

    //API
    _BX = sd;
    _DX = FP_SEG(&S);
    _SI = FP_OFF(&S);
    _AH = API_SENDTO;
    asm { int TCPIPVECT  } ;
    bytes_sent = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_sent ;       // AX value
        bytes_sent = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_sent ;
}
#endif  //#ifdef _tcp06e

/*************************************************************************/
//
/*************************************************************************/
#ifdef _tcphton_
/*
 @doc DOC_tcphton_
 ---------------------------------------------------------------
 Converts a 16 bit word from host to TCP/IP network byte order
 ---------------------------------------------------------------
 @clib  htons | Converts a 16 bit word from host to TCP/IP network byte order. |
        <cfont>unsigned short htons ( unsigned short hostshort );<efont> |
 @parm  int  | hostshort  | Port number in little endian (PC) byte order
 @rdesc input value returned in network byte order (big endian)
 @comm  This function converts the provided 16 bit value from Intel byte
        ordering (little endian) to network byte order (big endian).<s2>
        This is commonly needed for TCP/IP port number specifications.<nl>
        <nl>
        No entry into the @CHIP-RTOS API is made here.<s2> This action
        is taken immediately within this library call.
 @Also  tcp04.htm | connect  |
        tcp03.htm | bind     | |
*/
unsigned short htons (unsigned short hostshort )
{
    _AX = hostshort ;
    asm { XCHG AH,AL } ;
    return _AX ;
}
#endif


/*************************************************************************/
// inet_addr
/*************************************************************************/
#ifdef _tcp08_
/*
 @doc DOC_tcp08_
 ---------------------------------------------------------------
 Converts a dotted decimal IP address string to an unsigned long
 ---------------------------------------------------------------
 @clib  inet_addr | Converts a dotted decimal IP address string to an unsigned long. |
        <cfont>int inet_addr ( const char far *IPAddressStringPtr,<nl>
        <tab><tab><tab><tab>unsigned long far *IPAddress );<efont> |
 @parm  int  | IPAddressStringPtr  | Pointer to null terminated
        ASCII string of network address in dot notation.
 @parm  int  | IPAddress  | Output parameter:<s2>Pointer to a
        32 bit location where binary equivalent to the provided ASCII
        IP address will be output.
 @rdesc 0:  success <nl>
        non-zero:  Invalid IP address.

 @commtarget SC1x3 |
        This function applies only to IPv4 addresses.<s2> The
        <linkto>tcpC1.htm<linkmid>inet_pton<linktail> API can be used 
        for either IPv4 or IPv6 address conversions.
 @Also  tcpcon.htm | tcp_connect |
        tcp11.htm | InetToAscii |
        tcpC1.htm | inet_pton

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x08<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int inet_addr (const char far * IPAddressStringPtr,
               unsigned long far * IPAddress)
{
    _BX = FP_SEG(IPAddressStringPtr);
    _SI = FP_OFF(IPAddressStringPtr);
    _ES = FP_SEG(IPAddress);
    _DI = FP_OFF(IPAddress);

    _AH = API_INETADDR;
    asm { int TCPIPVECT  } ;
    return _DX ;
}
#endif

/*************************************************************************/
//sleep
/*************************************************************************/
#ifdef _tcp09_
/*
 @doc DOC_tcp09_
 ---------------------------------------------------------------
 The application sleeps for given number of milliseconds
 ---------------------------------------------------------------
 @clib  api_sleep | The calling task sleeps for specified
        number of milliseconds. |
        <cfont>void api_sleep ( unsigned int howlong );<efont> |
 @parm  int  | howlong  | Sleep period in milliseconds
 @rdesc -- none --
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x09<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
void api_sleep (unsigned int howlong)
{
    _BX = howlong ;
    _AH = API_SLEEP ;
    asm { int TCPIPVECT  } ;
}
#endif


/*************************************************************************/
//get waiting bytes
/*************************************************************************/
#ifdef _tcp0C_
/*
 @doc DOC_tcp0C_
 ---------------------------------------------------------------
 Get the number of bytes on a socket, waiting for read
 ---------------------------------------------------------------
 @clib  GetWaitingBytes | Report the number of bytes available
        on a socket, waiting to be read. |
        <cfont>int GetWaitingBytes ( int sd, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1 on failure, see error reported<nl>
        else count of received bytes waiting on socket.

 @Also  tcp10.htm | recv  |
        tcp05.htm | recvfrom |
        tcp01.htm | opensocket

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x0C<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int GetWaitingBytes (int sd, int *error)
{
    int bytes_ready ;
    int the_error_code = 0 ;

    _BX = sd ;
    _AH = API_GETRCV_BYTES ;
    asm { int TCPIPVECT  } ;
    bytes_ready = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_ready ;
        bytes_ready = API_ERROR ;
    }

    *error = the_error_code ;
    return bytes_ready ;
}
#endif

/*************************************************************************/
//accept
/*************************************************************************/
#ifdef _tcp0D_
/*
 @doc DOC_tcp0D_
 ---------------------------------------------------------------
 accept the next incoming connection
 ---------------------------------------------------------------
 @clib  accept | Accept the next incoming connection. |
        <cfont>int accept ( int sd,<nl>
        <tab><tab><tab> struct sockaddr far *addressPtr,<nl>
        <tab><tab><tab> int *error );<efont> |
 @parm  int  | sd  | Socket descriptor (must be switched into
        listen mode using <linkto>tcp0E.htm<linkmid>listen<linktail> API).
 @parm int  | addressPtr  | Optional output parameter:<s2>Pointer to a
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>  (IPv4)
        or  <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6 <linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure.<s2>
        On success, this function fills in this sockaddr_in or sockaddr_in6 structure with the
        IP address and port number of the accepted connection.<s2>
        This pointer can be set to NULL if this address and port number report is not desired.

 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1: Failure, error code output to <code>error<codee><nl>
        otherwise: New socket descriptor for the connection
 @comm  This call is used by a TCP server.<nl>
        <nl>
        This API function extracts the first connection on the queue
        of pending connections.<s2>  It then creates
        a new socket for this connection.<s2> This new socket will have
        the same socket options as the listening socket, <code>sd.<codee><nl>
        <nl>
        This function's prototype uses a pointer to the 
        generic type <code>sockaddr<codee> for its <code>addressPtr<codee> parameter,  
        for compatibility between IPv4 and IPv6 protocols.<s2> The pointer to the
        <code>sockaddr_in<codee>  (IPv4) or <code>sockaddr_in6<codee>  
        (IPv6, <i>SC123/SC143 only!<ie>) data structure which
        is actually used should be cast to <code>sockaddr<codee> pointer type here
        to avoid compiler warnings, "Suspicious pointer conversion".<nl>


 @Also  tcp0E.htm | listen     |
        tcp01.htm | opensocket | 
        tcpC3.htm | opensocket_ext
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x0D<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int accept (int sd,
            struct sockaddr far * addressPtr,
            int *error)
{
    int sd_accepted ;
    int the_error_code = 0 ;

    _BX = sd ;
    _DX = FP_SEG(addressPtr);
    _SI = FP_OFF(addressPtr);

    _AH = API_ACCEPT ;
    asm { int TCPIPVECT  } ;
    sd_accepted = _AX ;
    if (_DX != 0)
    {
        the_error_code = sd_accepted ;
        sd_accepted = API_ERROR ;
    }

    *error = the_error_code ;
    return sd_accepted ;
}
#endif


/*************************************************************************/
//listen
/*************************************************************************/
#ifdef _tcp0E_
/*
 @doc DOC_tcp0E_
 ---------------------------------------------------------------
 Listen for incoming connections
 ---------------------------------------------------------------
 @clib  listen | Listen for incoming connections. |
        <cfont>int listen ( int sd, int backlog, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | backlog  | The maximum number (limited to 5) of allowed
        outstanding connections
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function places the socket in passive mode and sets the
        number of incoming TCP connections that the system will queue
        (<code>backlog<codee>).<nl>
        <nl>
        This call is used by a TCP server.

 @Also  tcp0D.htm | accept  |
        tcp01.htm | opensocket |
        tcpC3.htm | opensocket_ext 

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x0E<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int listen (int sd, int backlog, int * error)
{
    _BX = sd ;
    _CX = backlog ;

    _AH = API_LISTEN ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX;
}
#endif


/*************************************************************************/
//send
/*************************************************************************/
#ifdef _tcp0F_
/*
 @doc DOC_tcp0F_
 ---------------------------------------------------------------
 Transmit a message
 ---------------------------------------------------------------
 @clib  send | Transmit a message. |
        <cfont>int send ( int sd, const char far *bufptr, int bufLen,<nl>
        <tab><tab>&nbsp;&nbsp; int flags, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | bufptr  | Pointer to output buffer containing
        data to be transmitted.
 @parm  int  | bufLen  | Maximum characters to output from <code>bufptr<codee>.
 @parm  int  | flags  | Wait option:<nl>
        <ul>
        <li><bold>MSG_BLOCKING<bolde>  - Wait for data send 
        to complete.<nl>
        <li><bold>MSG_DONTWAIT<bolde> - Don't wait for data
        send to complete.<nl>
        <ule>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1:  Failure, see error value reported<nl>
        otherwise: Count of bytes transfered into the socket send queue
 @comm  This API function applies only to TCP sockets.<s2>
        It transmits a message to another transport end-point.<s2>
        It may be used only if the socket is in a
        connected state.<nl>
        <nl>
        The MSG_BLOCKING mode will not work if the socket has
        been put into non-blocking mode using the
        <linkto>tcp18.htm<linkmid>Set_Blocking_Mode<linktail> API.

 @Also  tcp10.htm | recv  |
        tcp06.htm | sendto |
        tcp01.htm | opensocket
 @Also  tcp18.htm | Set_Blocking_Mode  | | | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x0F<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int send(int sd, const char far * bufptr, int bufLen,
         int flags, int *error)
{
    int bytes_sent ;
    int the_error_code = 0 ;

    //Init the struct send_param S for API-Call
    struct send_params S;
    S.bufferPtr      = bufptr;
    S.bufferLength   = bufLen;
    S.flags          = flags;
    S.toPtr          = NULL ;
    S.tolengthPtr    = NULL ;

    //API
    _BX = sd;
    _DX = FP_SEG(&S);
    _SI = FP_OFF(&S);
    _AH = API_SEND;
    asm { int TCPIPVECT  } ;
    bytes_sent = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_sent ;       // AX value
        bytes_sent = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_sent ;
}
#endif


/*************************************************************************/
//recv
/*************************************************************************/
#ifdef _tcp10_
/*
 @doc DOC_tcp10_
 ---------------------------------------------------------------
 Receive a message
 ---------------------------------------------------------------
 @clib  recv | Receive a message from another socket. |
        <cfont>int recv ( int sd, char far *bufptr, int bufLen,<nl>
        <tab><tab>&nbsp;&nbsp; int flags, unsigned long timeout,<nl>
        <tab><tab>&nbsp;&nbsp; int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | bufptr  | Output parameter:<s2> Pointer to input buffer
        where received characters will be stored.
 @parm  int  | bufLen  | Maximum characters to store in
        buffer at <code>bufptr<codee>.
 @parm  int  | flags  | Wait option:<nl>
         <ul>
        <li><bold>MSG_BLOCKING<bolde>  - Sleep until data comes in.<nl>
        <li><bold>MSG_TIMEOUT<bolde>  - The caller wakes up after timeout
        or if <code>bufLen<codee> data is received.<nl>
        <li><bold>MSG_DONTWAIT<bolde> - Return immediately after collecting what
        ever data is ready.<nl>
        <ule>
 @parm  int  | timeout  | Maximum milliseconds to wait if <code>flags<codee> is set
        to MSG_TIMEOUT<nl>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1:  Failure, see error value reported<nl>
        otherwise: Count of received bytes stored in buffer at <code>bufptr<codee>
 @comm  This API function applies only to TCP sockets.<s2>
        It receives a message from another socket.<s2>
        This API function may be used only if the socket is in a
        connected state.<nl>
        <nl>
        If <code>flags<codee> parameter is set to MSG_DONTWAIT, this API call returns
        immediately.<s2>If no data is available -1 is returned and output parameter
        <code>error<codee> is set to 235.<nl>
        <nl>If <code>flags<codee> parameter is set to MSG_BLOCKING, the <code>recv<codee>
        call waits for a message to arrive.<s2>
        By default the blocking mode is set for all sockets at the
        <linkto>tcp01.htm<linkmid>opensocket<linktail> call.<s2> If however
        a socket was subsequently set to non blocking mode with the
        <linkto>tcp18.htm<linkmid>Set_Blocking_Mode<linktail> API, the MSG_BLOCKING flag
        will then not work here.
 @Also  tcp0F.htm | send  |
        tcp05.htm | recvfrom |
        tcp01.htm | opensocket
 @Also  tcp18.htm | Set_Blocking_Mode  | | | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x10<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int recv (int sd, char far * bufptr, int bufLen, int flags,
          unsigned long timeout, int *error)
{
    int bytes_received ;
    int the_error_code = 0 ;
    struct recv_params R;

    //fill the struct recv_param R
    R.bufferPtr      =   bufptr;
    R.bufferLength   =   bufLen;
    R.flags          =   flags;
    R.fromPtr        =   NULL ;
    R.fromlengthPtr  =   NULL ;
    R.timeout        =   timeout; /*milliseconds*/

    //API
    _BX = sd;
    _DX = FP_SEG(&R);
    _SI = FP_OFF(&R);
    _AH = API_RECV ;
    asm { int TCPIPVECT  } ;
    bytes_received = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_received ;       // AX value
        bytes_received = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_received ;
}
#endif

/*************************************************************************/
// InetToAscii
/*************************************************************************/
#ifdef _tcp11_
/*
 @doc DOC_tcp11_
 ---------------------------------------------------------------
 Convert an IP address to an IP string
 ---------------------------------------------------------------
 @clib  InetToAscii | Convert an IP address to an ASCII dotted decimal
        IP  string. |
        <cfont>int InetToAscii ( const unsigned long far *IPAddress,<nl>
        <tab><tab><tab><tab>&nbsp; char far *IPAddressStringPtr );<efont> |
 @parm  int  | IPAddress  | Pointer to the 32 bit IP address in
        network byte order ("big endian").
 @parm  int  | IPAddressStringPtr  | Output parameter:<s2>
        Pointer to a <bold>16 character buffer<bolde> (minimum)
        where a null terminated ASCII string
        will be written by this API function containing the
        IP address expressed in dotted decimal notation.
 @rdesc Always 0
 @comm  This buffer at <code>IPAddressStringPtr<codee> must have
        space for 16 Bytes!.
 @commtarget SC1x3 |
        This function applies only to IPv4 addresses.<s2> The
        <linkto>tcpC2.htm<linkmid>inet_ntop<linktail> API can be used 
        for either IPv4 or IPv6 address conversions.
 @Also  tcp08.htm | inet_addr |
        tcpC2.htm | inet_ntop | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x11<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int InetToAscii (const unsigned long far * IPAddress,
                 char far * IPAddressStringPtr)
{
    _BX = FP_SEG(IPAddress) ;
    _SI = FP_OFF(IPAddress) ;
    _ES = FP_SEG(IPAddressStringPtr) ;
    _DI = FP_OFF(IPAddressStringPtr) ;

    _AH = API_INETTOASCII ;
    asm { int TCPIPVECT  } ;
    return 0;
}
#endif


/*************************************************************************/
//reset connection
/*************************************************************************/
#ifdef _tcp12_
/*
 @doc DOC_tcp12_
 ---------------------------------------------------------------
 Abort a connection on a socket
 ---------------------------------------------------------------
 @clib  ResetConnection | Abort a connection on a TCP socket. |
        <cfont>int ResetConnection ( int sd, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function only works on TCP sockets.<s2>
        <nl><nl>
        A reset socket cannot be used for a new connection.<s2> You must close the socket
        and open a new one.<nl>
        <nl>
        This API function does not close the socket,<s2> This must be done
        using the <linkto>tcp02.htm<linkmid>closesocket<linktail> API.<nl>
 @Also  tcp02.htm | closesocket |
        tcp01.htm | opensocket  | 
        tcpC3.htm | opensocket_ext
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x12<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int ResetConnection (int sd, int * error)
{
    _BX = sd ;

    _AH = API_RESETCONNECTION ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;                    // AX = 0, unless error code
}
#endif



/*************************************************************************/
// set linger time on close
/*************************************************************************/
#ifdef _tcp13_
/*
 @doc DOC_tcp13_
 ---------------------------------------------------------------
 Set linger time on close
 ---------------------------------------------------------------
 @clib  setlinger | Set linger time on close (TCP only). |
        <cfont>int setlinger ( int sd, int seconds, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | seconds  | Linger time in seconds, default: 60 sec,
        0 means linger turned off.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function works only with TCP sockets.
 @Also  tcp01.htm | opensocket | 
        tcpC3.htm | opensocket_ext  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x13<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int setlinger (int sd, int seconds, int *error)
{
    _BX = sd ;
    _CX = seconds ;

    _AH = API_SETLINGER ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
// set resuse option on a listening socket
/*************************************************************************/
#ifdef _tcp14_
/*
 @doc DOC_tcp14_
 ---------------------------------------------------------------
 Set reuse option on a listening socket
 ---------------------------------------------------------------
 @clib  setreuse | Set reuse option on a listening socket. |
        <cfont>int setreuse ( int sd, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function works only with TCP sockets.<s2>  
        In earlier SC12 @CHIP-RTOS versions, this API was necessary when
        a listening socket was closed and was to be re-opened and bound to
        the same port as it was bound to before.<nl>
        <nl>
        Since SC12 @CHIP-RTOS 071, every TCP socket is set by default as 
        reusable so use of this API function is no longer necessary.
 @Also  tcp01.htm | opensocket |
        tcp03.htm | bind | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x14<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int setreuse (int sd, int *error)
{
    _BX = sd ;

    _AH = API_SETREUSE ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX;
}
#endif

/*************************************************************************/
// Set IP Type-Of-Service on a socket
/*************************************************************************/
#ifdef _tcp15_
/*
 @doc DOC_tcp15_
 ---------------------------------------------------------------
 Set socket's Type-Of-Service
 ---------------------------------------------------------------
 @clib  Set_IP_Type_Of_Service | Set socket's default Type-Of-Service
        put into the IP datagram header's TOS field. |
        <cfont>int Set_IP_Type_Of_Service ( int sd,<nl>
        <tab><tab><tab><tab><tab><tab><tab> unsigned char tos,<nl>
        <tab><tab><tab><tab><tab><tab><tab> int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | tos  | Type-Of-Service for IP datagrams
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  Bits in the IP Type-Of-Service field of a IP datagram:<nl>
        <ul>
        Bits 0-2: Datagram precedence, 7 is the highest.<nl>
        Bits 3-5: type of transport, see TCP/IP documentation e.g.<nl>
        <tab><tab>Internet networking with TCP/IP by Douglas E.Comer<nl>
        Bits 6-7: unused<nl>
        <ule><nl>
        Note:<s2> Many routers ignore this IP datagram header field.<nl>
 @Also  tcp01.htm | opensocket | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x15<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int Set_IP_Type_Of_Service (int sd, unsigned char tos, int *error)
{
    _BX = sd ;

    _AL = tos ;
    _AH = API_SETIPTOS ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;
}
#endif

/*************************************************************************/
// set socket option
/*************************************************************************/
#ifdef _tcp16_
/*
 @doc DOC_tcp16_
 ---------------------------------------------------------------
 Set options on a socket
 ---------------------------------------------------------------
 @clib  setsockopt | Set options on a socket. |
        <cfont>int setsockopt ( int sd,<nl>
        <tab><tab><tab><tab> const SetSocketOption far *sockoptptr,<nl>
        <tab><tab><tab><tab> int *error);<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | sockoptptr  | Pointer to SetSocketOption
        <linkto>../../tcpstruc.htm#SetSocketOption<linkmid>type<linktail> that
        specifies the socket options (see tcpipapi.h).
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function makes it possible to manipulate options associated
        with a socket.<s2>Prior to calling this function the caller must fill in
        a SetSocketOption
        <linkto>../../tcpstruc.htm#SetSocketOption<linkmid>type<linktail>
        data structure.<s2>The socket options of an incoming connection (using
        <linkto>tcp0D.htm<linkmid>accept<linktail>) will be the same as the
        socket options of the listening socket.
 @Also  tcp01.htm | opensocket |
        tcp0D.htm | accept |
        tcp17.htm | getsockopt
 @Also  tcpC3.htm | opensocket_ext | | | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x16<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int setsockopt (int sd, const SetSocketOption far *sockoptptr, int *error)
{
    _BX = sd ;

    _ES = FP_SEG(sockoptptr);
    _DI = FP_OFF(sockoptptr);

    _AH = API_SETSOCKOPT ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;
}
#endif

/*************************************************************************/
// get socket option
/*************************************************************************/
#ifdef _tcp17_
/*
 @doc DOC_tcp17_
 ---------------------------------------------------------------
 Get options on a socket
 ---------------------------------------------------------------
 @clib  getsockopt | Get options on a socket. |
        <cfont>int getsockopt ( int sd,<nl>
        <tab><tab><tab><tab> const GetSocketOption far *sockoptptr,<nl>
        <tab><tab><tab><tab> int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | sockoptptr  | Pointer to GetSocketOption
        <linkto>../../tcpstruc.htm#GetSocketOption<linkmid>type<linktail> that
        specifies the socket options (see tcpipapi.h) and contains pointers
        to where the specified socket option will be reported to.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  On success, this function reports the requested socket option value to
        the buffer pointed to by the <code>optionValue<codee> member of
        GetSocketOption type at <code>sockoptptr<codee> and the length
        of this reported value is written to the location pointed to by
        the <code>optionLen<codee> member.<nl>
        <nl>
        The caller must setup the GetSocketOption
        <linkto>../../tcpstruc.htm#GetSocketOption<linkmid>type<linktail> structure
        prior to calling.<s2>In particular, the <code>optionValue<codee>
        member must point to a sufficiently large buffer to receive the
        reported option value and the size of this buffer must be stated
        in the location referenced by the <code>optionLen<codee> member.<s2>
        Note that this length specifier is both an input and an output
        parameter for this function.<s2>If on entry, the location referenced
        by <code>optionLen<codee> contains a value less than the buffer
        space required to report the requested socket option value, then
        the function will fail and return error code 242.<nl>
        <nl>
        The socket options of an incoming connection (using
        <linkto>tcp0D.htm<linkmid>accept<linktail>) will be the same as the
        socket options of the listening socket.
 @Also  tcp01.htm | opensocket |
        tcp16.htm | setsockopt | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x17<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int getsockopt (int sd, const GetSocketOption far *sockoptptr, int *error)
{
    _BX = sd ;

    _ES = FP_SEG(sockoptptr);
    _DI = FP_OFF(sockoptptr);

    _AH = API_GETSOCKOPT ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX;
}
#endif

/*************************************************************************/
//Set blocking mode on a socket (default is blocking!!)
/*************************************************************************/
#ifdef _tcp18_
/*
 @doc DOC_tcp18_
 ---------------------------------------------------------------
 Set a socket in blocking or non-blocking mode
 ---------------------------------------------------------------
 @clib  Set_Blocking_Mode | Set a socket in blocking or non-blocking mode. |
        <cfont>int Set_Blocking_Mode ( int sd,<nl>
        <tab><tab><tab><tab><tab><tab>unsigned char blocking_mode,<nl>
        <tab><tab><tab><tab><tab><tab>int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | blocking_mode  | 0: switch blocking off, 1:switch blocking on.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  By default all sockets are in blocking mode.<s2> If a socket is
        set to non blocking mode, socket calls such as
        <linkto>tcp04.htm<linkmid>connect<linktail> and
        <linkto>tcp0D.htm<linkmid>accept<linktail> do not wait until
        full completion.<s2>Instead they  return immediately.<nl>
        <nl>
        Example usage of non-blocking mode:<nl><ul>
        The <linkto>tcp04.htm<linkmid>connect<linktail> call returns
        at a non blocking socket with error code 236 or 237, when
        the connection was not completed.<s2> The user can repeat this
        API call in a periodic loop until a successful connection is
        established. In this case the connect function returns error code
        0 or 256 (socket is already connected).<nl>
        <ule>
 @Also  tcp04.htm | connect  |
        tcp0D.htm | accept |
        tcp10.htm | recv
 @Also  tcp05.htm | recvfrom  |
        tcp0F.htm | send |
        tcp06.htm | sendto
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x18<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int Set_Blocking_Mode (int sd, unsigned char blocking_mode, int *error)
{
    _BX = sd ;

    _AL = blocking_mode ;
    _AH = API_SETBLOCKINGMODE ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;                    // AX = 0, unless error code
}
#endif


/*************************************************************************/
//Register callback function on socket events
/*************************************************************************/
#ifdef _tcp19_
/*
 @doc DOC_tcp19_
 ---------------------------------------------------------------
 Register a user callback function
 ---------------------------------------------------------------
 @clib  RegisterCallbackFunction | Register a TCP user callback function. |
        <cfont>int RegisterCallbackFunction ( int sd,<nl>
        <tab><tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; void far *funcptr,<nl>
        <tab><tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; int eventflagmask,<nl>
        <tab><tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | funcptr  | Pointer to user's callback function.
 @parm  int  | eventflagmask  | Event flag mask bit field (see menu below)
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  The events which trigger the callback are controlled with the
        <code>eventflagmask<codee> input parameter.<s2>The set of possible
        event flags are (defined in TCPIPAPI.H):<nl>
        <nl>
        <ul>
        <li>CB_CONNECT_COMPLT - connection complete<nl>
        <li>CB_ACCEPT<s2>     - remote has established a connection to our listening server<nl>
        <li>CB_RECV<s2>     - incoming data arrived<nl>
        <li>CB_SEND_COMPLT<s2>     - sending of data has been acknowledged by the peer<nl>
        <li>CB_REMOTE_CLOSE<s2>     - peer has shut down the connection<nl>
        <li>CB_SOCKET_ERROR<s2>     - an error occured on the connection<nl>
        <li>CB_RESET<s2>     - peer has sent a rest on the connection<nl>
        <li>CB_CLOSE_COMPLT<s2>     - close has been completed<nl>
        <ule>
        <nl>
        These flags can be OR'ed together to form the mask for the set of events
        at which you want to be called.<nl>
        <nl>
        The callback function should satisfy the following prototype (Borland C):<nl>
        <nl>
        <code>void huge socketCallBackFunc(int socketdescriptor,<nl>
        <tab><tab><tab><tab><tab><tab><tab> int eventFlags) ;<codee>
        <nl><nl>
        The callback function's parameter <code>eventFlags<codee> contains the event(s)
        that have occured.<s2>This bit field is encoded the same as the
        <code>eventflagmask<codee> input parameter to this API function.
        <nl><nl>
        Before closing a socket, you must remove the callback function.<s2>
        This is done by calling this API function with both a null 
        <code>funcptr<codee> and zero <code>eventflagmask<codee>.<nl><nl>
 @Also  tcp01.htm | opensocket  |
        tcp02.htm | closesocket |
        tcp7a.htm | RegisterIPCallbackHandler
 @Also  tcpC3.htm | opensocket_ext  |
        tcp7B.htm | Register_ARP_User_CB |
        tcp7C.htm | RegisterIPCallbackHandler_Snd
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x19<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int RegisterCallbackFunction (int sd, void far *funcptr, int eventflagmask, int *error)
{
    _BX = sd ;
    _CX = eventflagmask ;
    _ES = FP_SEG(funcptr) ;
    _DI = FP_OFF(funcptr) ;

    _AH = API_REGISTERCALLBACK ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX;
}
#endif





/*************************************************************************/
//get last socket error
/*************************************************************************/
#ifdef _tcp21_
/*
 @doc DOC_tcp21_
 ---------------------------------------------------------------
 Get last socket error
 ---------------------------------------------------------------
 @clib  get_socketerror | Get last socket error. |
        <cfont>int get_socketerror ( int sd );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @rdesc <linkto>../../iperrlst.htm<linkmid>error<linktail> code
 @comm  Returns the last error which occured on specified socket.
 @Also  tcp01.htm | opensocket  | tcpC3.htm | opensocket_ext | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x21<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int get_socketerror (int sd)
{
    _BX = sd ;
    _AH = API_GET_SOCKETERROR ;
    asm { int TCPIPVECT  } ;

    return _AX ;
}
#endif


/*********************************************************************************/
// search for tcp socket by given local and return state,remote ip and local port
/*********************************************************************************/
#ifdef _tcp22_
/*
 @doc DOC_tcp22_
 ---------------------------------------------------------------
 Find TCP socket and return state
 ---------------------------------------------------------------
 @clib  Get_TCP_Socket_State | Find TCP socket and return its state. |
        <cfont>unsigned char Get_TCP_Socket_State ( unsigned int localPort,<nl>
        <tab><tab><tab><tab><tab><tab><tab> unsigned long far *remoteIP,<nl>
        <tab><tab><tab><tab><tab><tab><tab> unsigned int *remotePort );<efont> |
 @parm  int  | localPort  | Local port (e.g. htons(23) for telnet).
 @parm  int  | remoteIP  | Output parameter:<s2>Pointer to storage for
        32 bit remote IPv4 address.
 @parm  int  | remotePort  | Output parameter:<s2>Pointer to storage for
        16 bit remote peer port number.
 @rdesc Socket state (see list below)

 @comm  This API searches for a TCP socket by a given local port number, returning the
        socket state, IP address and port number of the remote peer (if any).<nl>
        <nl>
        If the return value is not INVALID (=20) and is greater or equal to SYN_SENT (=2)
        then a TCP connection is established.<s2>In this case the storage at
        <code>remoteIP<codee> holds the 32 bit IP address of the connected remote peer
        and <code>remotePort<codee> contains the remote peer port number.

        Possible TCP socket states:<nl>

        <tab>0:<s2>CLOSED<nl>
        <tab>1:<s2>LISTEN<nl>
        <tab>2:<s2>SYN_SENT<nl>
        <tab>3:<s2>SYN_RECEIVED<nl>
        <tab>4:<s2>ESTABLISHED<nl>
        <tab>5:<s2>CLOSE_WAIT<nl>
        <tab>6:<s2>FIN_WAIT_1<nl>
        <tab>7:<s2>CLOSING<nl>
        <tab>8:<s2>LAST_ACK<nl>
        <tab>9:<s2>FIN_WAIT_2<nl>
        <tab>10:<s2>TIME_WAIT<nl>
        <tab>20:<s2>INVALID<nl>

 @commtarget SC1x3 | Deprecated, because only IPv4 addresses can be stored at the
         provided 32-bit buffer at <code>remoteIP<codee>.<s2> The alternative
         <linkto>tcp24.htm<linkmid>Get_TCP_Socket_State_IP_All<linktail> API is 
         instead recommended, which covers both IPv4 and IPv6 protocols.<nl>

 @Also  tcp01.htm | opensocket |
        tcphton.htm | htons    |
        tcp24.htm | Get_TCP_Socket_State_IP_All
 @Also  tcpc3.htm | opensocket_ext |
         | |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x22<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.04 | V1.00 | V1.00 | V0.90

*/
unsigned char Get_TCP_Socket_State (unsigned int localPort,
                                    unsigned long far * remoteIP,
                                    unsigned int * remotePort)
{
    unsigned char state ;

    _BX = localPort ;
    _ES = FP_SEG(remoteIP) ;
    _DI = FP_OFF(remoteIP) ;

    _AH = API_GET_TCP_STATE ;
    asm { int TCPIPVECT  } ;

    state = _AL ;
    *remotePort = _CX ;

    return state ;
}
#endif


/*********************************************************************************/
// IPv4 and IPv6 SC123:
// search for tcp socket by given local and return state,remote ip and local port
/*********************************************************************************/
#ifdef _tcp24_
/*
 @doc DOC_tcp24_
 ---------------------------------------------------------------
 Find TCP socket and return state (IPv4 and IPv6)
 ---------------------------------------------------------------
 @clib  Get_TCP_Socket_State_IP_All | Find TCP socket and return its state. |
        <cfont>unsigned char Get_TCP_Socket_State_IP_All (<nl>
        <tab><tab><tab><tab><tab><tab><tab> unsigned int localPort,<nl>
        <tab><tab><tab><tab><tab><tab><tab> struct in6_addr far *remoteIP,<nl>
        <tab><tab><tab><tab><tab><tab><tab> unsigned int *remotePort );<efont> |
 @parm  int  | localPort  | Local port (e.g. htons(23) for telnet).
 @parm  int  | remoteIP  | Output parameter:<s2>Pointer to a
        <linkto>../../tcpstruc.htm#in6_addr<linkmid>in6_addr<linktail>
        structure which will receive the remote IP address.
 @parm  int  | remotePort  | Output parameter:<s2>Pointer to storage for
        16 bit remote peer port number.
 @rdesc Socket state (see list below)
 @comm  Search for a TCP socket by a given local port number, returning the
        socket state, IP address and port number of the remote peer (if any).<nl>
        <nl>
        If the return value is not INVALID (=20) and is greater or equal to SYN_SENT (=2)
        then a TCP connection is established.<s2>In this case the storage at
        <code>remoteIP<codee> holds the IP address of the connected remote peer
        and <code>remotePort<codee> contains the remote peer port number.

        Possible TCP socket states:<nl>
        @raw
        CLOSED          0
        LISTEN          1
        SYN_SENT        2
        SYN_RECEIVED    3
        ESTABLISHED     4
        CLOSE_WAIT      5
        FIN_WAIT_1      6
        CLOSING         7
        LAST_ACK        8
        FIN_WAIT_2      9
        TIME_WAIT      10
        INVALID        20
 @Also  tcp01.htm | opensocket |
        tcp22.htm | Get_TCP_Socket_State |
        tcphton.htm | htons   
 @Also  tcpC3.htm | opensocket_ext | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x24<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version     n/a  |  n/a  |  n/a  | V0.90

*/
unsigned char Get_TCP_Socket_State_IP_All(unsigned int localPort,
                                          struct in6_addr far * remoteIP,
                                          unsigned int * remotePort)
{
    unsigned char state ;

    _BX = localPort ;
    _ES = FP_SEG(remoteIP) ;
    _DI = FP_OFF(remoteIP) ;

    _AH = API_GET_TCP_STATE_IP_ALL ;
    asm { int TCPIPVECT  } ;

    state = _AL ;
    *remotePort = _CX ;

    return state ;
}
#endif





#ifdef _tcp23_
/*
 @doc DOC_tcp23_
 ---------------------------------------------------------------
 Get information about all open sockets
 ---------------------------------------------------------------
 @clib  int FindAllOpenSockets | Find/return information about all open sockets
        listed in the internal socket table. |
        <cfont>int FindAllOpenSockets( SocketInfo far * SockInfoPtr,<nl>
        <tab><tab><tab><tab><tab><s3> int max);<efont> |
 @parm  void *  | SockInfoPtr  | Output Parameter:<s2> Pointer to an array of 
        <cfont>max<efont>
        <linkto>../../tcpstruc.htm#SocketInfo<linkmid>SocketInfo<linktail> structures
        in the user's memory space into which this API will report the socket information.
 @parm  int | max | Size of the array (maximum number of table entries reported).

 @rdesc Returns the number of open sockets.<s2>
        The user provided array holds the socket information
        for up to <cfont>max<efont> sockets (the lesser of
        two counts: Return value, <cfont>max<efont>).<nl>

 @commtarget SC1x3 | Deprecated, because only IPv4 addresses can be stored 
         at the provided 32-bit IP address buffer in the <code>SocketInfo<codee>
         structure.<nl>
         <nl>
        Use <linkto>tcp25.htm<linkmid>FindAllOpenSockets_IP_All<linktail>
        instead.<nl>

 @Also  tcp25.htm | FindAllOpenSockets_IP_All | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x23<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90
*/
int FindAllOpenSockets(SocketInfo far * SockInfoPtr, int max)
{
   _CX = max;
   _ES = FP_SEG(SockInfoPtr);
   _DI = FP_OFF(SockInfoPtr);
   _AH = API_FINDALL_SOCKETS;
   asm {  int TCPIPVECT };
   return _AX;
}
#endif


#ifdef _tcp25_
/*
 @doc DOC_tcp25_
 ---------------------------------------------------------------
 Get information about all open sockets
 ---------------------------------------------------------------
 @clib  int FindAllOpenSockets_IP_All | Find/return information about all open 
        sockets listed in the internal socket table. (IPv4 and IPv6) |
        <cfont>int FindAllOpenSockets_IP_All(<nl>
        <tab><tab><tab><tab><tab><s3> SocketInfoIPv4v6 far * SockInfoPtr,<nl>
        <tab><tab><tab><tab><tab><s3> int max);<efont> |
 @parm  void *  | SockInfoPtr  | Output Parameter:<s2> Pointer to an array of 
        <cfont>max<efont>
        <linkto>../../tcpstruc.htm#SocketInfoIPv4v6<linkmid>SocketInfoIPv4v6<linktail>
        structures in the user's memory space into which this API will report
        the socket information.
 @parm  int | max | Size of the array (maximum number of table entries reported).

 @rdesc Returns the number of all open sockets.<s2>
        The user provided array holds the socket information
        for up to <cfont>max<efont> sockets (the lesser of
        two counts: Return value, <cfont>max<efont>).<nl>
 @Also  tcp23.htm | FindAllOpenSockets | | | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x25<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version     n/a  |  n/a  |  n/a  | V0.90
*/
int FindAllOpenSockets_IP_All(SocketInfoIPv4v6 far * SockInfoPtr, int max)
{
   _CX = max;
   _ES = FP_SEG(SockInfoPtr);
   _DI = FP_OFF(SockInfoPtr);
   _AH = API_FINDALL_SOCKETS_IP_ALL;
   asm {  int TCPIPVECT };
   return _AX;
}
#endif



/*************************************************************************/
//shutdown socket
/*************************************************************************/
#ifdef _tcp26_
/*
 @doc DOC_tcp26_
 ---------------------------------------------------------------
 Shutdown a socket
 ---------------------------------------------------------------
 @clib  Shutdown | Shutdown a socket in read,write or both directions. |
        <cfont>int shutdown ( int sd, unsigned char dir, int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | dir | Direction:    0:read, 1:write, 2: both
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function only works on TCP sockets.<s2>
        <nl><nl>
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x26<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V0.90

 @target_clib V2.01
*/
int shutdown (int sd, unsigned char dir, int * error)
{
    _BX = sd ;
    _AL = dir;
    _AH = API_SHUTDOWN ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;                    // AX = 0, unless error code
}
#endif

/*************************************************************************/
//sendto
/*************************************************************************/
#ifdef _tcp28_
/*
 @doc DOC_tcp28_
 ---------------------------------------------------------------
 Transmit a datagram
 ---------------------------------------------------------------
 @clib  sendto_iface | Transmit a datagram via specified interface. |
        <cfont>int sendto_face ( int sd, const char far *bufptr, int bufLen,<nl>
        <tab><tab><tab> int flags, const struct sockaddr far *toPtr,<nl>
        <tab><tab><tab> DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab> int *error );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @parm  int  | bufptr  | Pointer to output buffer containing
        characters to be transmitted.
 @parm  int  | bufLen  | Maximum characters to output from <code>bufptr<codee>.
 @parm  int  | flags  | Wait option:<nl>
        <ul>
        <li><bold>MSG_BLOCKING<bolde>  - Wait for data send to complete.<nl>
        <li><bold>MSG_DONTWAIT<bolde> - Don't wait for data send to complete.<nl>
        <ule>
 @parm  int  | toPtr  | Data destination, pointer to a
        <linkto>../../tcpstruc.htm#sockaddr_in<linkmid>sockaddr_in<linktail>
         (IPv4) or
        <linkto>../../tcpstruc.htm#sockaddr_in6<linkmid>sockaddr_in6<linktail>
         (IPv6, <i>SC123/SC143 only!<ie>) data structure.
 @parm  int  | DevHandlePtr  | Driver handle pointer
        <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>,
        which caller must fill in prior to call. TCPIP send the packet via this specified
        Device handle.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1:  Failure, see error value reported<nl>
        otherwise: Count of bytes transfered into the socket send queue.
 @comm  This API function applies only to UDP sockets and works similiar than the
        <linkto>tcp06.htm<linkmid>sendto<linktail> function.<s2>
        It is required, when the user wants to send a datagram with a multicast destination
        address via a specified device interface.
        It is not necessary to use this function, if the packet should by send via
        the default ethernet interface of the IPC@CHIP.
        The existing API function <linkto>tcp06.htm<linkmid>sendto<linktail> function
        does this by default, if a the multicast destination address is specified.
        <nl>
 @commtarget SC1x3 |
        The actual library function reached here is named
        <code>sendto_ipstackV2<codee>.<s2> The name change
        occurs due to a macro in the library header file.

 @Also  tcp06.htm | sendto  |
        tcpAD.htm | Get driver handle pointer | |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x28<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.21 | V1.21 | V1.21 | V1.10

*/

#undef sendto_iface     // Maintain original name
   // This version is for original SC12 TCP/IP stack
int sendto_iface (int sd, const char far * bufptr, int bufLen, int flags,
                  const struct sockaddr far * toPtr,
                  DevUserIfaceHandle DevHandlePtr,
                  int *error)
{
    int bytes_sent ;
    int the_error_code = 0 ;
    int toLen;
    struct send_params S;

    toLen = sizeof(struct sockaddr_in_ipstack);

    //Init the struct send_param S for API-Call
    S.bufferPtr      = bufptr;
    S.bufferLength   = bufLen;
    S.flags          = flags;
    S.toPtr          = (struct sockaddr *) toPtr;
    S.tolengthPtr    = &toLen;

    //API
    _BX = sd;
    _DX = FP_SEG(&S);
    _SI = FP_OFF(&S);
    _ES = FP_SEG(DevHandlePtr);
    _DI = FP_OFF(DevHandlePtr);
    _AH = API_SENDTO_IFACE;
    asm { int TCPIPVECT  } ;
    bytes_sent = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_sent ;       // AX value
        bytes_sent = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_sent ;
}
#endif

#ifdef _tcp28e_
// This version is for the new TCP/IP version, used  at target sc123
int sendto_iface_ipstackV2(int sd, const char far * bufptr, int bufLen, int flags,
                           const struct sockaddr far * toPtr,
                           DevUserIfaceHandle DevHandlePtr,
                           int *error)
{
    int bytes_sent ;
    int the_error_code = 0 ;
    int toLen;
    struct send_params S;

    if ( ((struct sockaddr_in_ipstackV2 far *)toPtr)->sin_family == AF_INET)
    {
       toLen = sizeof(struct sockaddr_in_ipstackV2);
    }
    else
    {
       toLen = sizeof(struct sockaddr_in6);
    }

    //Init the struct send_param S for API-Call
    S.bufferPtr      = bufptr;
    S.bufferLength   = bufLen;
    S.flags          = flags;
    S.toPtr          = (struct sockaddr *) toPtr;
    S.tolengthPtr    = &toLen;

    //API
    _BX = sd;
    _DX = FP_SEG(&S);
    _SI = FP_OFF(&S);
    _ES = FP_SEG(DevHandlePtr);
    _DI = FP_OFF(DevHandlePtr);
    _AH = API_SENDTO_IFACE;
    asm { int TCPIPVECT  } ;
    bytes_sent = _AX ;
    if (_DX != 0)
    {
        the_error_code = bytes_sent ;       // AX value
        bytes_sent = API_ERROR ;
    }
    *error = the_error_code ;
    return bytes_sent ;
}
#endif  //#ifdef _tcp28e

/*************************************************************************/
//PPP client installed
/*************************************************************************/
#ifdef _tcp40_
/*
 @doc DOC_tcp40_
 ---------------------------------------------------------------
 Check if PPP client installed
 ---------------------------------------------------------------
 @clib  PPP_Client_Installed | Check if PPP client is installed. |
        <cfont>int PPP_Client_Installed ( void );<efont> |
 @parm  int  |   | -- none --
 @rdesc 0:   PPP client is not installed<nl>
        non-zero: PPP client is installed<nl>
 @comm  Tests if PPP client services are available in @CHIP-RTOS
        version and not disabled via CHIP.INI
        <linkto>../../config.htm#PPPCLIENT_ENABLE<linkmid>configuration<linktail>.
 @Also  tcp41.htm | PPP_Client_Open  |
        tcp70.htm | Get_Installed_Servers | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x40<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Client_Installed (void)
{
    _AH = PPPCLIENT_INSTALLED ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif
/*************************************************************************/
//PPP client open  IPv4 address configuration
/*************************************************************************/
#ifdef _tcp41_
/*
 @doc DOC_tcp41_
 ---------------------------------------------------------------
 Open a PPP connection
 ---------------------------------------------------------------
 @clib  PPP_Client_Open | Open a PPP connection. |
        <cfont>int PPP_Client_Open ( PPPClient_Init far *ptr, int *error );<efont> |
 @parm  int  | ptr  | Pointer to a 
        <linkto>../../tcpstruc.htm#PPPClient_Init<linkmid>PPPClient_Init<linktail>
        type data structure (declared in tcpipapi.h)
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  On success, the structure at <code>ptr<codee> contains the needed
        IP data for further TCP/IP socket communication.<nl>
        <nl>
        Refer to the PPPCLIE.C example for how to use this API.<s2>
        Also refer to the
        <linkto>../../tcpstruc.htm#PPPClient_Init<linkmid>PPPClient_Init<linktail>
        data structure documentation.<nl>
        <nl>
        Note: <bold>Only one PPP client connection can be opened
        at a time!!<bolde><nl>
 @commtarget SC1x3 | This API applies to IPv4 type PPP connections.<s2>
        For IPv6 connections, see 
        <linkto>tcp45.htm<linkmid>PPP_Client_Open_IPv6<linktail> API.<nl>
 @Also  tcp40.htm | PPP_Client_Installed  |
        tcp42.htm | PPP_Client_Close  |
        tcp43.htm | PPP_Client_GetStatus
 @Also  tcp45.htm | PPP_Client_Open_IPv6  |
        | | | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x41<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Client_Open (PPPClient_Init far * ptr, int *error)
{
    _ES = FP_SEG(ptr) ;
    _DI = FP_OFF(ptr) ;
    _AH = PPPCLIENT_OPEN ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;
}
#endif


/*************************************************************************/
//PPP client close
/*************************************************************************/
#ifdef _tcp42_
/*
 @doc DOC_tcp42_
 ---------------------------------------------------------------
 Close a PPP client connection
 ---------------------------------------------------------------
 @clib  PPP_Client_Close | Close a PPP client connection. |
        <cfont>int PPP_Client_Close ( int * error );<efont> |
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  Within this API call, after closing the PPP session the
        PPP Client executes the modem hang-up commands specified in the
        <linkto>../../tcpstruc.htm#PPPClient_Init<linkmid>PPPClient_Init<linktail>
        data structure
        defined in the <linkto>tcp41.htm<linkmid>PPP_Client_Open<linktail>
        call.<nl>
 @Also  tcp41.htm | PPP_Client_Open  |  |  |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x42<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Client_Close (int *error)
{
    _AH = PPPCLIENT_CLOSE ;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;
}
#endif

/*************************************************************************/
//PPP client get status
/*************************************************************************/
#ifdef _tcp43_
/*
 @doc DOC_tcp43_
 ---------------------------------------------------------------
 Get PPP client status
 ---------------------------------------------------------------
 @clib  PPP_Client_GetStatus | Get PPP client status. |
        <cfont>int PPP_Client_GetStatus ( int *error );<efont> |
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @rdesc non-negative:  PPP client
        <linkto>../../iperrlst.htm#status<linkmid>status<linktail> code<nl>
        negative:  Failure, PPP client
        <linkto>../../iperrlst.htm#client<linkmid>error<linktail> code
 @comm  This API function returns -2 if the version of RTOS does not
        support the PPP client services.
 @Also  tcp41.htm | PPP_Client_Open  |
        tcp40.htm | PPP_Client_Installed | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x43<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Client_GetStatus (int *error)
{
    _DX = 0;
    _AH = PPPCLIENT_GET_STATUS ;
    asm { int TCPIPVECT  } ;
    *error = _DX;
    return _AX;
}
#endif

/*************************************************************************/
//PPP client get DNS IP as negotiated by the remote PPP server
/*************************************************************************/
#ifdef _tcp44_
/*
 @doc DOC_tcp44_
 ---------------------------------------------------------------
 Get DNS IP
 ---------------------------------------------------------------
 @clib  PPP_Client_Get_DNSIP | Get DNS IP. |
        <cfont>int PPP_Client_Get_DNSIP ( unsigned long far *IPaddress,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; int primary_sec, int *error );<efont> |
 @parm  int  | IPaddress  | Output parameter:<s2>DNS address is stored here.
 @parm  int  | primary_sec  | 1:<s2> Get primary DNS address<nl>
        2:<s2> Get secondary address.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  This API function reports the DNS addresses as negotiated by
        the remote PPP server.
 @Also  tcp41.htm | PPP_Client_Open  | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x44<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.04 | V1.00 | V1.00 | V0.90
*/
int PPP_Client_Get_DNSIP (unsigned long far * IPaddress,
                          int primary_sec,
                          int *error)
{
    _BX = primary_sec ;
    _ES = FP_SEG(IPaddress);
    _DI = FP_OFF(IPaddress);

    _AH = PPPCLIE_GET_DNSIP ;
    asm { int TCPIPVECT  } ;
    *error = _DX;
    return _AX ;
}
#endif

/*************************************************************************/
// PPP client set options
/*************************************************************************/
#ifdef _tcp45_
/*
 @doc DOC_tcp45_
 ---------------------------------------------------------------
 Set PPP options for the PPP client
 ---------------------------------------------------------------
 @clib  PPP_Client_SetOptions | Set PPP options for the PPP client. |
        <cfont>int PPP_Client_SetOptions ( const PPP_Option far *ptr );<efont> |
 @parm  int  | ptr  | Pointer to an array of
        <linkto>../../tcpstruc.htm#PPP_Option<linkmid>PPP_Option<linktail>
        type data structures
 @rdesc -3 : PPP Connection already established<nl>
        -2 : PPP client is not installed<nl>
        -1 : Invalid Option(s)<nl>
        0<s2> : Success
        @comm If you want to use this function, you have to call it before opening
        a connection.<s2> <bold>Setting options during an established connection
        does not work!<bolde><s2>
        The settings are only valid for the next established connection.<s2>
        While establishing a connection the <code>PPP_Option<codee> structure
        referenced by the <code>ptr<codee> parameter must remain valid.<s2>
        After the
        <linkto>tcp41.htm<linkmid>PPP_Client_Open<linktail> function is finished, the structure
        can then be released.
        <nl>
        <nl>
        The array of data structures at <code>ptr<codee> is terminated by
        the first structure encountered with a NULL <code>optionValuePtr<codee>
        member.<nl>
        <nl>

        @raw
        // Simplified C-Example:
        unsigned int  ipcp_comp   = 1;    
        unsigned long DNS_Pri_IP  = 0L;   
        unsigned long DNS_Sec_IP  = 0L;   

        PPP_Option My_Options[] = {

          // Allow remote to peer to use VJ TCPIP header compression.
          { PPP_IPCP_PROTOCOL, PPP_OPTION_ALLOW, PPP_IPCP_COMP_PROTOCOL,
              (const char *)&ipcp_comp, sizeof(ipcp_comp)},

          // Allow remote to peer to set primary DNS IP.
          { PPP_IPCP_PROTOCOL, PPP_OPTION_WANT, PPP_IPCP_DNS_PRI,
              (const char *)&DNS_Pri_IP, sizeof(DNS_Pri_IP)},

          // Allow remote to peer to set secondary DNS IP.
          { PPP_IPCP_PROTOCOL, PPP_OPTION_WANT, PPP_IPCP_DNS_SEC,
              (const char *)&DNS_Sec_IP, sizeof(DNS_Sec_IP)},

          // Terminate list of options.
          { 0, 0, 0, NULL, 0}
        } ;

        //***** call the functions like this ****

        // Install option with CLIB function
        PPP_Client_SetOptions(&My_Options[0]);  // Point to first member of array

        PPP_Client_Open(&pppclient);           // Open the connection

 @Also  tcp41.htm | PPP_Client_Open   | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x45<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int PPP_Client_SetOptions (const PPP_Option far *ptr)
{
    _ES = FP_SEG(ptr);
    _DI = FP_OFF(ptr);

    _AH = PPPCLIENT_SET_OPTIONS ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif

/*************************************************************************/
//PPP client open  IPv6 address configuration
/*************************************************************************/
#ifdef _tcp46_
/*
 @doc DOC_tcp46_
 ---------------------------------------------------------------
 Open a PPP connection
 ---------------------------------------------------------------
 @clib  PPP_Client_Open_IPv6 | Open a PPP connection with IPv6 address configuration. |
        <cfont>int PPP_Client_Open_IPv6 ( PPPClient_Init_IPv6 far *ptr,<nl>
        <tab><tab><tab><tab><tab><tab><s2> int *error );<efont> |
 @parm  int  | ptr  | Pointer to a
        <linkto>../../tcpstruc.htm#PPPClient_Init_IPv6<linkmid>PPPClient_Init_IPv6<linktail>
        type  data structure (declared in tcpipapi.h)
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  IPv6 address configuration is done by an auto negotiation process.<s2>
        At connection time the peers negotiate an Interface-ID for the PPP device and
        auto configure their link-local scope addresses.<s2> After sucessful
        return of this function the  <cfont>PPPClieipAddrStr<efont> and
        <cfont>PPPClieRemipAddrStr<efont> members of the <cfont>PPPClient_Init_IPv6<efont>
        data structure are filled with the negotiated IPv6 addresses.<nl>
        <nl>
        On success, the structure at <code>ptr<codee> contains the needed
        IP data for further TCP/IP socket communication.<nl>
        <nl>
        Refer to the PPP6CLIE.C example for how to use this API.<s2>
        Also refer to 
        <linkto>../../tcpstruc.htm#PPPClient_Init_IPv6<linkmid>PPPClient_Init_IPv6<linktail>
        data structure documentation.<nl>
        <nl>
        Note: <bold>Only one PPP client connection can be opened
        at a time!!<bolde><nl>
 @Also  tcp40.htm | PPP_Client_Installed  |
        tcp42.htm | PPP_Client_Close  |
        tcp43.htm | PPP_Client_GetStatus
 @Also  tcp41.htm | PPP_Client_Open  |
        | | | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x46<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version     n/a  |  n/a  |  n/a  | V0.90

*/
int PPP_Client_Open_IPv6(PPPClient_Init_IPv6 far * ptr, int *error)
{
    _ES = FP_SEG(ptr) ;
    _DI = FP_OFF(ptr) ;
    _AH = PPPCLIENT_OPEN_IPV6;
    asm { int TCPIPVECT  } ;
    *error = _AX;
    return _DX ;
}
#endif


/*************************************************************************/
//PPP server installed
/*************************************************************************/
#ifdef _tcp50_
/*
 @doc DOC_tcp50_
 ---------------------------------------------------------------
 Check if PPP server is installed
 ---------------------------------------------------------------
 @clib  PPP_Server_Installed | Check if PPP server is installed. |
        <cfont>int PPP_Server_Installed ( void );<efont> |
 @parm  int  |   | -- none --
 @rdesc zero: PPP server is not installed<nl>
        non-zero: PPP server is installed
 @comm  The CHIP.INI can specify that the PPP server not be
       <linkto>../../config.htm#PPPSERVER_ENABLE<linkmid>installed<linktail>.
 @Also  tcp52.htm | PPP_Server_Activate  |
        tcp70.htm |Get_Installed_Servers | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x50<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Server_Installed (void)
{
    _AH = PPPSERVER_INSTALLED ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif


/*************************************************************************/
//PPP server suspend
/*************************************************************************/
#ifdef _tcp51_
/*
 @doc DOC_tcp51_
 ---------------------------------------------------------------
 Suspend the PPP server task
 ---------------------------------------------------------------
 @clib  PPP_Server_Suspend | Suspend the PPP server task. |
        <cfont>int PPP_Server_Suspend (int timeoutsecs, int *error );<efont> |
 @parm  int  | timeoutsecs  | Time-out in seconds.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  Note that the time-out value in <code>timeoutsecs<codee>
        depends on your time-out entries for the modem commands
        specified in chip.ini.<s2> If this call returns with -1, the most
        likely reason is that the modem commands are not finished after
        specified time-out.
 @related Chip.ini   | ../../config.htm#PPPSERVERHANGUPTIMEOUTx
        | entry: | PPPSERVER HANGUPTIMEOUTx
        time-out in seconds for wait on answer from modem
 @Also  tcp52.htm | PPP_Server_Activate  |
        tcp53.htm | PPP_Server_GetStatus | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x51<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Server_Suspend (int timeoutsecs, int *error)
{
    _BX = timeoutsecs ;
    _AH = PPPSERVER_SUSPEND ;
    asm { int TCPIPVECT  } ;
    *error = _DX;
    return _AX ;
}
#endif

/*************************************************************************/
//PPP server  activate
/*************************************************************************/
#ifdef _tcp52_
/*
 @doc DOC_tcp52_
 ---------------------------------------------------------------
 Activate the PPP server
 ---------------------------------------------------------------
 @clib  PPP_Server_Activate | Activate the PPP server. |
        <cfont>int PPP_Server_Activate ( int timeoutsecs, int *error );<efont> |
 @parm  int  | timeoutsecs  | Time-out in seconds.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0 = success <nl>
        Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @comm  If successful, the PPP server is now able to serve a connection.<nl>
        <nl>
        Note that the time-out value in <code>timeoutsecs<codee>
        depends on your time-out entries for the modem commands
        specified in chip.ini.<s2> If this call returns with -1, the most
        likely reason is that the modem commands are not finished after
        specified time-out.
 @Also  tcp51.htm | PPP_Server_Suspend  |
        tcp50.htm | PPP_Server_Installed  |
        tcp53.htm | PPP_Server_GetStatus
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x52<linkmid>documentation<linktail>
        for more details.
 @related Chip.ini   | ../../config.htm#PPPSERVERHANGUPTIMEOUTx
        | entry: | PPPSERVER HANGUPTIMEOUTx
        time-out in seconds for wait on answer from modem
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Server_Activate (int timeoutsecs, int *error)
{
    _BX = timeoutsecs ;
    _AH = PPPSERVER_ACTIVATE ;
    asm { int TCPIPVECT  } ;
    *error = _DX;
    return _AX ;
}
#endif

/*************************************************************************/
//PPP server, get status
/*************************************************************************/
#ifdef _tcp53_
/*
 @doc DOC_tcp53_
 ---------------------------------------------------------------
 Get the current state of the PPP server
 ---------------------------------------------------------------
 @clib  PPP_Server_GetStatus | Get the current state of the PPP server. |
        <cfont>int PPP_Server_GetStatus ( void );<efont> |
 @parm  int  |   | -- none --
 @rdesc PPP server state defined below
 @comm  PPP server states:<nl>
        <ul>
        -2<s2>  PPP server is not installed.<nl>
        -1<s2>  Error state, should not happen<nl>
        1<s3>  Server disabled<nl>
        2<s3>  Server enabled, waiting for connection<nl>
        3<s3>  PPP connection is established<nl>
        4<s3>  Server tries to hang up modem<nl>
        5<s3>  Server tries to initialize modem<nl>
        <ul>
 @Also  tcp51.htm | PPP_Server_Suspend  |
        tcp52.htm | PPP_Server_Activate  |
        tcp50.htm | PPP_Server_Installed
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x53<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Server_GetStatus(void)
{
    _AH = PPPSERVER_GET_STATUS ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif


/*************************************************************************/
//PPP server  get config
/*************************************************************************/
#ifdef _tcp54_
/*
 @doc DOC_tcp54_
 ---------------------------------------------------------------
 Get configuration data of the PPP server
 ---------------------------------------------------------------
 @clib  PPP_Server_Get_Cfg | Get the current main configuration
        data of the PPP server . |
        <cfont>int PPP_Server_Get_Cfg ( PPP_IPCfg_Data far *ptr, int *error );<efont> |
 @parm  int  | ptr  | Output Parameter:<s2> Pointer to a
        <linkto>../../tcpstruc.htm#PPP_IPCfg_Data<linkmid>PPP_IPCfg_Data<linktail>
        type data structure which will be set by this function.
 @parm  int  | error | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc Non-zero = Failure (see <code>error<codee> output parameter)<nl>
        zero: The user structure <code>PPP_IPCfg_Data<codee> is filled with
        the PPP server configuration data<nl>
 @comm: (DOC_SC123)  This API applies to PPP server operating
        with IPv4 protocol.<s2>  Refer to 
        <linkto>tcp56.htm<linkmid>PPP_Server_Get_Cfg_IPv6<linktail>
        API for IPv6 PPP server configuration access.
 @Also  tcp51.htm | PPP_Server_Suspend  |
        tcp53.htm | PPP_Server_GetStatus  |
        tcp52.htm | PPP_Server_Activate
 @Also  tcp55.htm | PPP_Server_SetOptions | 
        tcp56.htm | PPP_Server_Get_Cfg_IPv6 | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x54<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int PPP_Server_Get_Cfg (PPP_IPCfg_Data far *ptr, int *error)
{
    _ES = FP_SEG(ptr);
    _DI = FP_OFF(ptr);
    _AH = PPPSERVER_GET_CFG ;
    asm { int TCPIPVECT  } ;
    *error = _DX;
    return _AX ;
}
#endif

/*************************************************************************/
// PPP server set options
/*************************************************************************/
#ifdef _tcp55_
/*
 @doc DOC_tcp55_
 ---------------------------------------------------------------
 Set PPP options for the PPP server
 ---------------------------------------------------------------
 @clib  PPP_Server_SetOptions | Set PPP options for the PPP server. |
        <cfont>int PPP_Server_SetOptions ( const PPP_Option far *ptr );<efont> |
 @parm  byte | ptr  | Pointer to an array of <code>PPP_Option<codee>
        <linkto>../../tcpstruc.htm#PPP_Option<linkmid>type<linktail>
        data structures (defined in tcpipapi.h).
 @rdesc -3: PPP Connection already established<nl>
        -2: PPP server is not installed<nl>
        -1: Invalid Option(s)<nl>
        0:<s2> Success
 @comm  It is only possible to set PPP options when the PPP server is suspended.<s2>
        (PPP server status reported by
        <linkto>tcp53.htm<linkmid>PPP_Server_GetStatus<linktail> must be 1.)<s2>
        Setting options when the PPP server is active
        (states 2, 3, 4 and 5) does not have any effect.<s2>
        The installed options take affect when the PPP server is activated.<s2>
        If you want to reset the options, call this function with a
        null <code>ptr<codee> parameter.<nl>
        <nl>
        The array of data structures at <code>ptr<codee> is terminated by
        the first structure encountered with a NULL <code>optionValuePtr<codee>
        member.<nl>

        @raw

        //  Simplified C-Example:
        unsigned int  ipcp_comp   = 1;    
        unsigned long DNS_Pri_IP  = 0L;   
        unsigned long DNS_Sec_IP  = 0L;

        static PPP_Option My_Options[] = {
          // Allow remote to peer to use VJ TCPIP header compression.
          { PPP_IPCP_PROTOCOL, PPP_OPTION_ALLOW, PPP_IPCP_COMP_PROTOCOL,
             (const char *)&ipcp_comp, sizeof(ipcp_comp)},

          // Allow remote to peer to set primary DNS IP, but do no request for it.
          { PPP_IPCP_PROTOCOL, PPP_OPTION_ALLOW, PPP_IPCP_DNS_PRI,
             (const char *)&DNS_Pri_IP, sizeof(DNS_Pri_IP)},

          // Allow remote to peer to set secondary DNS IP, but do no request for it.
          { PPP_IPCP_PROTOCOL, PPP_OPTION_ALLOW, PPP_IPCP_DNS_SEC, 
             (const char *)&DNS_Sec_IP, sizeof(DNS_Sec_IP)},

          { 0, 0, 0, NULL, 0}   // End of array marker
        } ;

        //*****call the functions like this****

        PPP_Server_Suspend(20);                 // Suspend the PPP server
        // Install option with CLIB function
        PPP_Server_SetOptions(&My_Options[0]);  // point to first member of array

        PPP_Server_Activate(20);                // Activate

 @Also  tcp51.htm | PPP_Server_Suspend  |
        tcp53.htm | PPP_Server_GetStatus  |
        tcp52.htm | PPP_Server_Activate
 @Also  tcp54.htm | PPP_Server_Get_Cfg  | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x55<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.03 | V1.00 | V1.00 | V0.90

*/
int PPP_Server_SetOptions (const PPP_Option far * ptr)
{
    _ES = FP_SEG(ptr);
    _DI = FP_OFF(ptr);
    _AH = PPPSERVER_SET_OPTIONS ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif

/*************************************************************************/
//PPP server  get config (IPv6)
/*************************************************************************/
#ifdef _tcp56_
/*
 @doc DOC_tcp56_
 ---------------------------------------------------------------
 Get configuration data of the PPP server
 ---------------------------------------------------------------
 @clib  PPP_Server_Get_Cfg_IPv6 | Get the current main configuration
        data of the PPP server. |
        <cfont>int PPP_Server_Get_Cfg_IPv6 (<nl>
        <tab><tab><tab><tab><tab> PPP_IPCfg_Data_IPv6 far *ptr,<nl>
        <tab><tab><tab><tab><tab> int *error );<efont> |
 @parm  int  | ptr  | Output parameter:<s2>Pointer to a
        <linkto>../../tcpstruc.htm#PPP_IPCfg_Data_IPv6<linkmid>PPP_IPCfg_Data_IPv6<linktail>
        type data structure which will be set by this function.
 @parm  int  | error | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc Non-zero = Failure (see <code>error<codee> output parameter)<nl>
        zero: The user structure <code>PPP_IPCfg_Data_IPv6<codee> is filled with
        the PPP server configuration data<nl>
 @comm  Only PPP IPv6 connections are supported by this API.<s2>
        IPv6 address configuration is done by an auto negotiation process.<s2>
        At connection time, the peers negotiate an Interface-ID for the PPP device and
        auto configure their link-local scope addresses.<nl>
        <nl>
        Refer to <linkto>tcp54.htm<linkmid>PPP_Server_Get_Cfg<linktail>
        API for IPv4 PPP server configuration access.
 @Also  tcp51.htm | PPP_Server_Suspend  |
        tcp53.htm | PPP_Server_GetStatus  |
        tcp52.htm | PPP_Server_Activate
 @Also  tcp55.htm | PPP_Server_SetOptions |
        tcp54.htm | PPP_Server_Get_Cfg | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x56<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version     n/a  |  n/a  |  n/a  | V0.90
*/
int PPP_Server_Get_Cfg_IPv6(PPP_IPCfg_Data_IPv6 far *ptr, int *error)
{
    _ES = FP_SEG(ptr);
    _DI = FP_OFF(ptr);
    _AH = PPPSERVER_GET_CFG_IPV6;
    asm { int TCPIPVECT  } ;
    *error = _DX;
    return _AX ;
}
#endif



/*************************************************************************/
//Get pointer to internal TCIP SNMP mib structures
/*************************************************************************/
#ifdef _tcp60_
/*
 @doc DOC_tcp60_
 ---------------------------------------------------------------
 Get internal TCP/IP SNMP variables
 ---------------------------------------------------------------
 @clib  Get_SNMP_Data | Get internal TCP/IP SNMP variables. |
        <cfont>int Get_SNMP_Data ( unsigned char which,<nl>
        <tab><tab><tab><tab><tab>void far * *snmp_mib_ptr );<efont> |
 @parm  int  | which  | Specifies which data to access.<nl>
        <ul>
         1:<s2>  Get pointer to
        <linkto>../../tcpstruc.htm#IfMib<linkmid>IfMib<linktail>
        data structure<nl>
         2:<s2> Get pointer to
         <linkto>../../tcpstruc.htm#IpMib<linkmid>IpMib<linktail>
         data structure<nl>
         3:<s2>  Get pointer to
         <linkto>../../tcpstruc.htm#IcmpMib<linkmid>IcmpMib<linktail>
         data structure<nl>
         4:<s2> Get pointer to
         <linkto>../../tcpstruc.htm#TcpMib<linkmid>TcpMib<linktail>
         data structure<nl>
         5:<s2>  Get pointer to
         <linkto>../../tcpstruc.htm#UdpMib<linkmid>UdpMib<linktail>
         data structure<nl>
         6:<s2>  Get pointer to
         <linkto>../../tcpstruc.htm#atEntry<linkmid>atEntry<linktail>
         data structure<nl>
         <ule>
 @parm  int  | snmp_mib_ptr  | Output Parameter:<s2> Pointer to a 
         far pointer in user memory which will be set with a pointer
         to requested object time within the @CHIP-RTOS memory space.<nl>
 @rdesc non-zero : BIOS without internal SNMP mib variables<nl>
        0:  Location refereced by <code>snmp_mib_ptr<codee> contains a pointer
        to the structure<nl>
 @comm  This API provides access to the internal TCP/IP variables
        which will be required if the user is to implement a SNMP (Simple 
        Network Management Protocol) agent.<nl>
        <nl>
 @commtarget SC1x3  | This API currently only supports IPv4 protocol.
 @commtarget SC1x  | These structures are only available in @CHIP-RTOS versions
        which contain the SNMP option.<s2> A SNMP agent is not part of the @CHIP-RTOS.<nl>
        <nl>
        The SNMP variables are not a part of our current official 6 SC1x @CHIP-RTOS
        versions.<s2> You must order directly an SC1x @CHIP-RTOS version which includes
        this feature.<nl>
 @Also  tcp78.htm | Get_TCPIP_Memory_Status  |
        tcp74.htm | Get_TCPIP_Statistics  |
        tcp60a.htm | Get_SNMP_DataEx

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x60<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90
*/
int Get_SNMP_Data(unsigned char which , void far * * snmp_mib_ptr)
{
    unsigned int es_reg ;
    _AL = which ;
    _AH = API_SNMP_GET ;
    asm { int TCPIPVECT  } ;
    if(_AX==0)
    {
       es_reg = _ES ;
       *snmp_mib_ptr = (void far *)MK_FP(es_reg, _DI) ;
       return 0;
    }
    return _AX;
}
#endif


#ifdef _tcp60a_
/*
 @doc DOC_tcp60a_
 ---------------------------------------------------------------
 Get internal TCP/IP SNMP variables
 ---------------------------------------------------------------
 @clib  Get_SNMP_DataEx | Get internal TCP/IP SNMP variables (Extended). |
        <cfont>int Get_SNMP_DataEx ( unsigned char which,<nl>
        <tab><tab><tab><tab><tab>&nbsp; void far * *snmp_mib_ptr,<nl>
        <tab><tab><tab><tab><tab>&nbsp; int *max );<efont> |
 @parm  int  | which  | Specifies which data to access.<nl>
        <nl>
        1:<s2>   Get pointer to
        <linkto>../../tcpstruc.htm#IfMib<linkmid>IfMib<linktail>
        data structure<nl>
         2:<s2>   Get pointer to
         <linkto>../../tcpstruc.htm#IpMib<linkmid>IpMib<linktail>
         data structure<nl>
         3:<s2>   Get pointer to
         <linkto>../../tcpstruc.htm#IcmpMib<linkmid>IcmpMib<linktail>
         data structure<nl>
         4:<s2>   Get pointer to
         <linkto>../../tcpstruc.htm#TcpMib<linkmid>TcpMib<linktail>
         data structure<nl>
         5:<s2>   Get pointer to
         <linkto>../../tcpstruc.htm#UdpMib<linkmid>UdpMib<linktail>
         data structure<nl>
         6:<s2>   Get pointer to
         <linkto>../../tcpstruc.htm#atEntry<linkmid>atEntry<linktail>
         data structure<nl>
         7:<s2>   Set array of pointers to
         <linkto>../../tcpstruc.htm#IfMib<linkmid>IfMib<linktail>
         entries of all current open TCP/IP device interfaces (Local Loopback,
         Ethernet, PPP server, PPP client).<s2> The value at 
         <cfont>max<efont> must specify the maximum number of pointers in this array.<nl>
         8:<s2> Get pointer to unsigned long <i>system up-time<ie> variable (10 Hz counter).<nl>
 @parm  int  | snmp_mib_ptr  | 
         Output Parameter:<nl>
         <nl>
         For cases where <cfont>which<efont> is not set to 7, this is a
         pointer to a single far pointer in user memory which will be set by this API
         with a pointer to requested object within the @CHIP-RTOS memory space.<nl>
         <nl>
         For case where <cfont>which<efont> is set to 7, this is a pointer to
         an array of far pointers within the caller's memory.<s2>
         This array will be set by this API call with pointers to 
         <linkto>../../tcpstruc.htm#IfMib<linkmid>IfMib<linktail>
         data structures located in @CHIP-RTOS memory.<s2> One pointer for each device
         interface will be reported, up to a maximum limited by the count specified
         at the <cfont>max<efont> input parameter.
 @parm  int  | max  | Input/Output Parameter:<s2> This parameter only applies
         to case where <cfont>which<efont> is set to 7.<s2> It is otherwise not used.<s2>
         For <cfont>which<efont> case 7, this location must be preset by caller to
         the number of pointers in the array referenced by the 
         <cfont>snmp_mib_ptr<efont> input parameter.<s2>  On return, the referenced
         count will indicate the number of devices for which 
         <linkto>../../tcpstruc.htm#IfMib<linkmid>IfMib<linktail> pointers have
         been listed in the <cfont>snmp_mib_ptr<efont> output array.
 @rdesc non-zero : RTOS version  without internal SNMP mib variables<nl>
        0:  Location refereced by <code>snmp_mib_ptr<codee> contains a pointer
        to the structure<nl>
 @comm  This API provides access to the internal TCP/IP variables
        which will be required if the user is to implement a SNMP (Simple 
        Network Management Protocol) agent.<nl>
 @commtarget SC1x3  | This API currently only supports IPv4 protocol.
 @commtarget SC1x  | These structures are only available in @CHIP-RTOS versions
        which contain the SNMP option.<s2> A SNMP agent is not part of the @CHIP-RTOS.<nl>
        <nl>
        The SNMP variables are not a part of our current official 6 SC1x @CHIP-RTOS
        versions.<s2> You must order directly an SC1x @CHIP-RTOS version which includes
        this feature.<nl>
 @Also  tcp78.htm | Get_TCPIP_Memory_Status  |
        tcp74.htm | Get_TCPIP_Statistics  |
        tcp60.htm | Get_SNMP_Data
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x60<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.01 | V1.00 | V1.00 | V0.90
*/
int Get_SNMP_DataEx(unsigned char which , void far * * snmp_mib_ptr, int * max)
{
   unsigned int es_reg;
   if (which == 7)
   {
      _CX = *max;
      asm push ds
      _DS = FP_SEG(snmp_mib_ptr) ;      // Not necessarily a far ptr
      _SI = FP_OFF(snmp_mib_ptr) ;
   }
   asm{
         mov al,which
         mov ah,API_SNMP_GET
         int TCPIPVECT
   }
   if(_AX==0)
   {
      if (which != 7)
      {
        es_reg = _ES;
        *snmp_mib_ptr = (void *)MK_FP(es_reg,_DI);
      }
      else
      {
          // Note: 'max' may be a near pointer, so we must restore DS
          //       before de-referencing 'max'.
        asm pop ds
        *max =  _CX;
      }
      return 0;
   }
   return _AX;
}
#endif

/*************************************************************************/
//FTP server: Return the addresss of the FTPserver login counters
/*************************************************************************/
#ifdef _tcp65_
/*
 @doc DOC_tcp65_
 ---------------------------------------------------------------
 Access the FTP server login counters
 ---------------------------------------------------------------
 @clib1 Get_FTP_Login_Counters | Access the FTP server login counters. |
        <cfont>int Get_FTP_Login_Counters (<nl>
        <tab><tab><tab><tab><tab>unsigned long far * * FTP_Login_Count,<nl>
        <tab><tab><tab><tab><tab>unsigned long far * * FTP_Login_failCount );<efont> |
 @parm  int  | FTP_Login_Count  | Output parameter:<s2>  A far pointer to the
        32 bit login counter will be output to the location pointed to by this
        parameter.<s2>  On failure, a NULL pointer is output here.
 @parm  int  | FTP_Login_failCount  | Output parameter:<s2>  A far pointer to the
        32 bit login fail counter will be output to the location pointed to by
        this parameter.<s2>  On failure, a NULL pointer is output here.
 @rdesc 0:  success <nl>
        non-zero:  @CHIP-RTOS doesn't support FTP server
        pointers are set to NULL).
 @Also  tcp66.htm | Get_Telnet_Login_Counters  | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x65<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.01 | V1.00 | V1.00 | V0.90

*/
int Get_FTP_Login_Counters(unsigned long far *  * FTP_Login_Count,
                           unsigned long far *  * FTP_Login_failCount)
{
    int error_code ;
    unsigned int es_reg, ds_reg ;

    _AH = API_FTP_GET_LOGIN ;
    asm { push DS } ;
    asm { int TCPIPVECT  } ;
    error_code = _AX ;
    ds_reg = _DS ;
    es_reg = _ES ;
    asm { pop DS } ;

    if (error_code != 0)
    {
        es_reg = 0 ;
        ds_reg = 0 ;
        _DI = 0 ;
        _SI = 0 ;
    }
    *FTP_Login_Count     = (unsigned long far *)MK_FP(es_reg, _DI);
    *FTP_Login_failCount = (unsigned long far *)MK_FP(ds_reg, _SI);

    return error_code ;
}
#endif

/*************************************************************************/
//Telnet server: Return the addresss of the Telnetserver login counters
/*************************************************************************/
#ifdef _tcp66_
/*
 @doc DOC_tcp66_
 ---------------------------------------------------------------
 Access the Telnet server login counters
 ---------------------------------------------------------------
 @clib1 Get_Telnet_Login_Counters | Access the Telnet server login counters. |
        <cfont>int Get_Telnet_Login_Counters(<nl>
        <tab><tab><tab><tab> unsigned long far * * Telnet_Login_Count,<nl>
        <tab><tab><tab><tab> unsigned long far * * Telnet_Login_failCount);<efont> |
 @parm  int  | Telnet_Login_Count  | Output parameter:<s2>  A far pointer to the
        32 bit login counter will be output to the location pointed to by this
        parameter.<s2>  On failure, a NULL pointer is output here.
 @parm  int  | Telnet_Login_failCount  | Output parameter:<s2>  A far pointer to the
        32 bit login fail counter will be output to the location pointed to by
        this parameter.<s2>  On failure, a NULL pointer is output here.
 @rdesc 0:  success <nl>
        non-zero:  @CHIP-RTOS doesn't support Telnet server
        (pointers are set to NULL).
 @Also  tcp65.htm | Get_FTP_Login_Counters  | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x66<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.01 | V1.00 | V1.00 | V0.90

*/
int Get_Telnet_Login_Counters(unsigned long far *  * Telnet_Login_Count,
                              unsigned long far *  * Telnet_Login_failCount)
{
    int error_code ;
    unsigned int es_reg, ds_reg ;

    _AH = API_TELNET_GET_LOGIN ;
    asm { push DS } ;
    asm { int TCPIPVECT  } ;
    error_code = _AX ;
    ds_reg = _DS ;
    es_reg = _ES ;
    asm { pop DS } ;

    if (error_code != 0)
    {
        es_reg = 0 ;
        ds_reg = 0 ;
        _DI = 0 ;
        _SI = 0 ;
    }
    *Telnet_Login_Count     = (unsigned long far *)MK_FP(es_reg, _DI);
    *Telnet_Login_failCount = (unsigned long far *)MK_FP(ds_reg, _SI);

    return error_code ;
}
#endif

/*************************************************************************/
//Get telnet state
/*************************************************************************/
#ifdef _tcp67_
/*
 @doc DOC_tcp67_
 ---------------------------------------------------------------
 Check if have an active telnet session
 ---------------------------------------------------------------
 @clib  Get_Telnet_State | Check if have an active telnet session. |
        <cfont>int Get_Telnet_State ( int *error );<efont> |
 @parm   int  | error    | Output parameter:<s2>
         0:  no Telnet session<nl>
         1:  Telnet session is active<nl>
        -1:  BIOS doesn't support Telnet server
 @rdesc  0 = success <nl>
         Non-zero = Failure (see <code>error<codee> output parameter)<nl>
 @Also  tcp66.htm | Get_Telnet_Login_Counters  |
        tcp70.htm | Get_Installed_Servers  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x67<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.01 | V1.00 | V1.00 | V0.90

*/
int Get_Telnet_State ( int *error)
{
    _AH = API_GET_TELNET_STATE ;
    asm { int TCPIPVECT  } ;

    *error = _DX;
    return _AX;
}
#endif



/*************************************************************************/
//Get installed servers and devices of the SC12
/*************************************************************************/
#ifdef _tcp70_
/*
 @doc DOC_tcp70_
 ---------------------------------------------------------------
 Get information about running servers
 ---------------------------------------------------------------
 @clib  Get_Installed_Servers | Get information about running servers
        and interfaces of the TCP/IP Stack. |
        <cfont>void Get_Installed_Servers ( unsigned int far* first,<nl>
        <tab><tab><tab><tab><tab><tab><tab> unsigned int far* second );<efont> |
 @parm  int  | first    | The first eight possible available servers:<nl>
        <ul>
         Bit 0: GIS_ETHERNET - Ethernet device<nl>
         Bit 1: GIS_PPP_SERVER  - PPP server<nl>
         Bit 2: GIS_PPP_CLIENT - PPP client<nl>
         Bit 3: GIS_WEB_SERVER - Web server<nl>
         Bit 4: GIS_TELNET_SERVER - Telnet server<nl>
         Bit 5: GIS_FTP_SERVER - FTP server<nl>
         Bit 6: GIS_TFTP_SERVER - TFTP server<nl>
         Bit 7: GIS_DHCP - DHCP client<nl>
         <ule>
 @parm  int  | second    | The next eight possible available servers:<nl>
         <ul>
         Bit 0: GIS_SNMP_MIB - SNMP MIB variables support<nl>
         Bit 1: GIS_CFG_SERVER - UDP Config server<nl>
         Bit 2: GIS_PING_CLIENT - Ping client<nl>
         <ule>
 @rdesc -- none --
 @comm  The masked listed here are defined in the tcpip.h header file.<nl>
 @Also  tcp50.htm | PPP_Server_Installed  |
        tcp40.htm | PPP_Client_Installed  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x70<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.01 | V1.00 | V1.00 | V0.90

*/
void Get_Installed_Servers ( unsigned int far *first, unsigned int far *second )
{
    _AH = GET_INSTALLED_SERVERS ;
    asm { int TCPIPVECT  } ;
    *first = _AX;
    *second = _DX;
}
#endif

/*************************************************************************/
//Reconfigure Ethernet interface
/*************************************************************************/
#ifdef _tcp71_
/*
 @doc DOC_tcp71_
 ---------------------------------------------------------------
 Reconfigure Ethernet interface
 ---------------------------------------------------------------
 @clib  Reconfigure_ethernet | Reconfigure Ethernet interface after
        changing the IP configuration. |
        <cfont>int Reconfigure_ethernet ( void );<efont> |
 @parm  int  |   | -- none --.
 @rdesc 0:  success <nl>
        non-zero:  error <linkto>../../iperrlst.htm<linkmid>code<linktail><nl>
        <nl>
        (Error code 237 indicates that an Ethernet interface configuration was
        already in progress.)
 @comm  A new IP configuration set with the prompt
        <linkto>../../command.htm#IP_address<linkmid>commands<linktail>
        <cfont>ip<efont>, <cfont>netmask<efont> and
        <cfont>gateway<efont> (or the corresponding library
        <linkto>tcpIPW.htm<linkmid>Set_IPConfig<linktail> call)
        becomes valid after a successful call to this function.<nl>
        <nl>
        If DHCP is changed from 1 to 0 then a new IP address, subnet mask
        and gateway should be set with the prompt
        <linkto>../../command.htm#IP_address<linkmid>commands<linktail>
        <cfont>ip<efont>, <cfont>netmask<efont> and <cfont>gateway<efont>
        or <linkto>tcpIPW.htm<linkmid>Set_IPConfig<linktail>
        library call.
 @Also  tcpIPW.htm | Set_IPConfig  |
        tcp72.htm | DHCP_use  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x71<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int Reconfigure_ethernet(void)
{
    _AH = REINIT_ETHERNET ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif

/*************************************************************************/
//DHCP use   dhcp_use 0/1
/*************************************************************************/
#ifdef _tcp72_
/*
 @doc DOC_tcp72_
 ---------------------------------------------------------------
 Set/Reset DHCP usage on the Ethernet interface
 ---------------------------------------------------------------
 @clib  DHCP_use | Set/Reset DHCP usage on the Ethernet interface. |
        <cfont>int DHCP_use ( unsigned char dhcp_use );<efont>  |
 @parm  int  | dhcp_use  | 0: do not use DHCP, 1: Use DHCP.
 @rdesc 0:  success <nl>
        non-zero:  DHCP not available in this RTOS version.
 @comm  This entry becomes valid only after rebooting the system  or after
        calling the
        <linkto>tcp71.htm<linkmid>Reconfigure_ethernet<linktail>
        library function.<nl>
        <nl>
        If DHCP is changed from 1 to 0 then a new IP address, subnet mask
        and gateway should be set with either the
        prompt <linkto>../../command.htm#IP_address<linkmid>commands<linktail>
        or the <linkto>tcpIPW.htm<linkmid>Set_IPConfig<linktail>
        library call.<nl>
 @Also  tcp71.htm  | Reconfigure_ethernet  |
        tcpIPW.htm | Set_IPConfig  |
        tcp73.htm  | Get_DHCP_Status
 @Also  tcp73a.htm | Get_DHCP_Status_Ext  | | | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x72<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int DHCP_use(unsigned char dhcp_use)
{
    _AL = dhcp_use ;
    _AH = DHCP_USE ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif

/*************************************************************************/
//DHCP Stat
/*************************************************************************/
#ifdef _tcp73_
/*
 @doc DOC_tcp73_
 ---------------------------------------------------------------
 Get DHCP status of the Ethernet interface
 ---------------------------------------------------------------
 @clib  Get_DHCP_Status | Get DHCP status of the Ethernet interface. |
        <cfont>void Get_DHCP_Status ( unsigned int *dhcp_use,<nl>
        <tab><tab><tab><tab> unsigned int *dhcp_stat );<efont> |
 @parm  int  | dhcp_use  | Output parameter:<s2>Pointer to a where
        a "DHCP in use" boolean value will be output to.<s2>The
        location will be set to '1' if the DHCP is currently being
        used and '0' if not in use.
 @parm  int  | dhcp_stat  | Output parameter:<s2>Pointer to a where
        a DHCP status word will be stored.<s2> The status is encoded
        as follows:<nl>
        <ul>
          0: System is not configured (is in progress)<nl>
          1: System is configured by a DHCP Server<nl>
          2: System configure retry failed (or no retry started before)<nl>
        <ule>
 @rdesc  -- none --
 @Also  tcp73a.htm | Get_DHCP_Status_Ext  |
        tcp72.htm  | DHCP_use | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x73<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
void Get_DHCP_Status(unsigned int * dhcp_use, unsigned int *dhcp_stat)
{
    _AH = DHCP_STAT ;
    asm { int TCPIPVECT  } ;
    *dhcp_use  = _AX ;
    *dhcp_stat = _DX ;
}
#endif


/*************************************************************************/
//DHCP Stat extended function with getting dhcp config data
//(requires BIOS 1.03B or higher)
/*************************************************************************/
#ifdef _tcp73a_
/*
 @doc DOC_tcp73a_
 ---------------------------------------------------------------
 Get DHCP status of the Ethernet interface
 ---------------------------------------------------------------
 @clib  Get_DHCP_Status_Ext | Get DHCP status of the Ethernet interface. |
        <cfont>void Get_DHCP_Status_Ext ( unsigned int *dhcp_use,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; unsigned int *dhcp_stat,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; UserEthDhcp_Entry far * *dhcpptr );<efont> |
 @parm  int  | dhcp_use  | Output parameter:<s2>Pointer to a where
        a "DHCP in use" boolean value will be output to.<s2>The
        location will be set to '1' if the DHCP is currently being
        used and '0' if not in use.
 @parm  int  | dhcp_stat  | Output parameter:<s2>Pointer to a where
        a DHCP status word will be stored.<s2> The status is encoded
        as follows:<nl>
        <ul>
          0: System is not configured (is in progress)<nl>
          1: System is configured by a DHCP Server<nl>
          2: System configure retry failed (or no retry started before)<nl>
        <ule>
 @parm  int | dhcpptr | Output Parameter:<s2>Pointer to a pointer that will
        be set by this API call, referencing a 
        <cfont>UserEthDhcp_Entry<efont> data structure within @CHIP-RTOS memory.<s2>
        This structure will contain some DHCP configuration data (read-only!).<s2>
        If no data is available the pointer will be set to NULL.
 @rdesc -- none --
 @comm  The UserEthDhcp_Entry data is a read-only information.<s2>
        Do not write to this data structure!
 @Also  tcp73.htm | Get_DHCP_Status  |
        tcp72.htm | DHCP_use | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x73<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
void Get_DHCP_Status_Ext(unsigned int * dhcp_use, unsigned int *dhcp_stat, UserEthDhcp_Entry far * * dhcpptr)
{
    unsigned int es_reg;
    unsigned int di_reg;

    _AH = DHCP_STAT ;
    asm { int TCPIPVECT  } ;
    es_reg = _ES;
    di_reg = _DI;
    *dhcp_use  = _AX ;
    *dhcp_stat = _DX ;
    if (_DX != 1)
    {
        es_reg =
        di_reg = 0 ;
    }

    *dhcpptr = (UserEthDhcp_Entry far *) MK_FP(es_reg, di_reg);
    return;
}
#endif
/*************************************************************************/
//return the address of TCP/IP packet counter struct
/*************************************************************************/
#ifdef _tcp74_
/*
 @doc DOC_tcp74_
 ---------------------------------------------------------------
 Access the internal network packet counter
 ---------------------------------------------------------------
 @clib  Get_TCPIP_Statistics | Access the internal network packet counters. |
        <cfont>void Get_TCPIP_Statistics ( Packet_Count far * *pkt_cnt_ptr );<efont> |
 @parm  int | pkt_cnt_ptr | Output Parameter:<s2>Pointer to location in
        user memory which will receive a pointer to a
        <linkto>../../tcpstruc.htm#Packet_Count<linkmid>Packet_Count<linktail>
        data structure residing in @CHIP-RTOS memory space (read-only!).<s2> This 
        referenced @CHIP-RTOS data structure contains further 
        pointers to the counters for each protocol.
 @rdesc -- none --
 @comm  The counters referenced by <code>Packet_Count<codee> 
        data structure members
       <code>count_all_packets<codee> and <code>cnt_all_sended_packets<codee>
       count only Ethernet packets.<nl>
       <nl>
       Other counters referenced also count the packets from and
       to other devices: e.g. local loop back packets and PPP packets.<nl>
       <nl>
       The user is free to read and/or reset any of these referenced
       counters.<nl>
 @Also tcp78.htm | Get_TCPIP_Memory_Status  |
       tcp60.htm | Get_SNMP_Data  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x74<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
void Get_TCPIP_Statistics ( Packet_Count far * * pkt_cnt_ptr )
{
    unsigned es_reg;
    _ES = 0 ;
    _DI = 0 ;       // [ES:DI] remains null if no TCP/IP in RTOS.

    _AH = TCPIP_STATISTICS ;
    asm { int TCPIPVECT  } ;
    es_reg = _ES;
    *pkt_cnt_ptr = (Packet_Count far *)MK_FP(es_reg, _DI);
}
#endif

/*************************************************************************/
//ping open
/*************************************************************************/
#ifdef _tcp75_
/*
 @doc DOC_tcp75_
 ---------------------------------------------------------------
 Open and start ICMP echo requests
 ---------------------------------------------------------------
 @clib  Ping_Open | Open and start ICMP echo requests. |
        <cfont>int Ping_Open ( Ping far *pingptr, int *error );<efont> |
 @parm  int  | pingptr  | Pointer to user's  <code>Ping<codee>
        <linkto>../../tcpstruc.htm#Ping<linkmid>structure<linktail>.<nl>
        The contents of this structure will be initialized by this
        function call.
        <nl>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -2: Ping API not supported by RTOS version<nl>
        -1:  Failure, see reported <code>error<codee> code.<nl>
        >;= 0:  Socket descriptor<nl>
 @comm  Note:<s2> This API will send ICMP packets forever, until you
        call <linkto>tcp76.htm<linkmid>Ping_Close<linktail>.
 @Also  tcp76.htm | Ping_Close  |
        tcp77.htm | Ping_Statistics | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x75<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int Ping_Open (Ping far * pingptr, int * error)
{
    _ES = FP_SEG(pingptr);
    _DI = FP_OFF(pingptr);
    _AH = PING_OPEN ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
//ping close
/*************************************************************************/
#ifdef _tcp76_
/*
 @doc DOC_tcp76_
 ---------------------------------------------------------------
 Finish ICMP echo requests
 ---------------------------------------------------------------
 @clib  Ping_Close | Stop ICMP echo requests. |
        <cfont>int Ping_Close ( int sd );<efont> |
 @parm  int  | sd  | Socket descriptor.
 @rdesc -2: Ping API not supported by RTOS<nl>
        -1: Ping close failed, should not happen, only if socket
        descriptor is invalid<nl>
        0: Success<nl>
 @Also  tcp75.htm | Ping_Open |
        tcp77.htm | Ping_Statistics  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x76<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int Ping_Close (int sd)
{
    _BX = sd ;
    _AH = PING_CLOSE ;
    asm { int TCPIPVECT  } ;
    return _DX ;
}
#endif

/*************************************************************************/
//ping statistics
/*************************************************************************/
#ifdef _tcp77_
/*
 @doc DOC_tcp77_
 ---------------------------------------------------------------
 Retrieve ping information
 ---------------------------------------------------------------
 @clib  Ping_Statistics | Retrieve ping information. |
        <cfont>int Ping_Statistics ( Ping far *pingptr );<efont> |
 @parm  int  | pingptr  | Output parameter:<s2>
        Pointer to user's  <code>Ping<codee>
        <linkto>../../tcpstruc.htm#Ping<linkmid>structure<linktail>
        from the
        <linkto>tcp75.htm<linkmid>Ping_Open<linktail> call.<nl>
 @rdesc -2: Ping API not supported by RTOS version<nl>
        -1: Failure<nl>
        0: Success<nl>
 @comm  The structure at <code>pingptr<codee> is filled with
        the ping statistics.<nl>
 @Also  tcp75.htm | Ping_Open  |
        tcp76.htm | Ping_Close | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x77<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int Ping_Statistics(Ping far * pingptr)
{
    _ES = FP_SEG(pingptr);
    _DI = FP_OFF(pingptr);
    _AH = PING_STATISTICS ;
    asm { int TCPIPVECT  } ;
    return _DX ;
}
#endif

/*************************************************************************/
//memory
/*************************************************************************/
#ifdef _tcp78_
/*
 @doc DOC_tcp78_
 ---------------------------------------------------------------
 Get information about TCP/IP stack memory usage
 ---------------------------------------------------------------
 @clib  Get_TCPIP_Memory_Status | Get information about TCP/IP stack
        memory usage. |
        <cfont>void Get_TCPIP_Memory_Status ( unsigned long far *total,<nl>
        <tab><tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; unsigned long far *used );<efont> |
 @parm  int  | total  | Output parameter:<s2>Pointer to 32 bit location
        what will receive the maximum number of bytes of available memory.
 @parm  int  | used  | Output parameter:<s2>Pointer to 32 bit location
        what will receive the number of bytes of memory currently used.
 @rdesc -- none --
 @Also  tcp60.htm | Get_SNMP_Data  |
        tcp74.htm | Get_TCPIP_Statistics  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x78<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
void Get_TCPIP_Memory_Status(unsigned long far * total,
                             unsigned long far * used)
{
    asm { push DS } ;
    _ES = FP_SEG(total);
    _DI = FP_OFF(total);
    _DS = FP_SEG(used);
    _SI = FP_OFF(used);

    _AH = GET_MEMORY_INFO ;
    asm { int TCPIPVECT  } ;
    asm { pop DS } ;
}
#endif


/*************************************************************************/
//Set FTP Server Idle timeout (using: Set/Get Server Idle Timeout)
/*************************************************************************/
#ifdef _tcp79_
/*
 @doc DOC_tcp79_
 ---------------------------------------------------------------
 Set FTP server time-out
 ---------------------------------------------------------------
 @clib  Set_FTPServer_Idle_Timeout | Set FTP server time-out. |
        <cfont>int Set_FTPServer_Idle_Timeout ( unsigned int timeout );<efont> |
 @parm  int  | timeout  | Time out value in seconds.
 @rdesc 0:  success <nl>
        non-zero:  FTP server not available in this RTOS version
 @comm  This function inserts the specified FTP time-out into the
        CHIP.INI file.<s2> The new time-out value takes affect
        immediately, without requiring a reboot.<nl>
        <nl>
        Refer to
        <linkto>../../config.htm#FTP_TIMEOUT<linkmid>FTP_TIMEOUT<linktail>
        in CHIP.INI documentation.
 @Also  tcp79a.htm | Set_TelnetServer_Idle_Timeout  |
        tcp79b.htm | Get_FTPServer_Idle_Timeout |
        tcp79c.htm | Get_TelnetServer_Idle_Timeout
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x79<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int Set_FTPServer_Idle_Timeout ( unsigned int timeout )
{
    _BX = 0x00;                 // Ftp server
    _DX = timeout;

    _AL = 0x00;                 // set timeout
    _AH = SET_SERVER_IDLE_TIMEOUT ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif

/*************************************************************************/
//Set Telnet Server Idle timeout (using: Set/Get Server Idle Timeout)
/*************************************************************************/
#ifdef _tcp79a_
/*
 @doc DOC_tcp79a_
 ---------------------------------------------------------------
 Set Telnet server time-out
 ---------------------------------------------------------------
 @clib  Set_TelnetServer_Idle_Timeout | Set Telnet server time-out. |
        <cfont>int Set_TelnetServer_Idle_Timeout ( unsigned int timeout );<efont> |
 @parm  int  | timeout  | Time out in seconds.
 @rdesc 0:  success <nl>
        non-zero:  Telnet server not available in this RTOS version
 @comm  This function inserts the specified Telnet time-out into the
        CHIP.INI file.<s2> The new time-out value takes affect
        immediately, without requiring a reboot.<nl>
        <nl>
        Refer to
        <linkto>../../config.htm#TELNET_TIMEOUT<linkmid>TELNET_TIMEOUT<linktail>
        in CHIP.INI documentation.
 @Also  tcp79.htm  | Set_FTPServer_Idle_Timeout   |
        tcp79c.htm | Get_TelnetServer_Idle_Timeout |
        tcp79b.htm | Get_FTPServer_Idle_Timeout
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x79<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int Set_TelnetServer_Idle_Timeout( unsigned int timeout )
{
    _BX = 0x01;                 // Telnet server
    _DX = timeout;

    _AL = 0x00;                 // set timeout
    _AH = SET_SERVER_IDLE_TIMEOUT ;
    asm { int TCPIPVECT  } ;
    return _AX ;
}
#endif

/*************************************************************************/
//Get FTP Server Idle timeout (using: Set/Get Server Idle Timeout)
/*************************************************************************/
#ifdef _tcp79b_
/*
 @doc DOC_tcp79b_
 ---------------------------------------------------------------
 Get FTP server time-out value
 ---------------------------------------------------------------
 @clib  Get_FTPServer_Idle_Timeout | Get FTP server time-out value. |
        <cfont>unsigned int Get_FTPServer_Idle_Timeout ( void );<efont> |
 @parm  int  |   | -- none --
 @rdesc 0xFFFF or 0xFFFE:<s2>FTP server not available in this RTOS version<nl>
        Otherwise:<s2> Existing FTP server time-out value, in seconds.
 @comm  This function accesses the  FTP server's existing time-out value.<nl>
        <nl>
        Refer to
        <linkto>../../config.htm#FTP_TIMEOUT<linkmid>FTP_TIMEOUT<linktail>
        in CHIP.INI documentation.
 @Also  tcp79.htm  | Set_FTPServer_Idle_Timeout   |
        tcp79a.htm | Set_TelnetServer_Idle_Timeout |
        tcp79c.htm | Get_TelnetServer_Idle_Timeout
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x79<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
unsigned int Get_FTPServer_Idle_Timeout (void)
{
    _BX = 0x00;                 // FTP server

    _AL = 0x01;                 // get timeout
    _AH = SET_SERVER_IDLE_TIMEOUT ;
    asm { int TCPIPVECT  } ;
    return _DX ;
}
#endif

/*************************************************************************/
// Get Telnet Server Idle timeout (using: Set/Get Server Idle Timeout)
/*************************************************************************/
#ifdef _tcp79c_
/*
 @doc DOC_tcp79c_
 ---------------------------------------------------------------
 Get Telnet server time-out value
 ---------------------------------------------------------------
 @clib  Get_TelnetServer_Idle_Timeout | Get Telnet server time-out value. |
        <cfont>unsigned int Get_TelnetServer_Idle_Timeout ( void );<efont> |
 @parm  int  |   | -- none --.
 @rdesc 0xFFFF or 0xFFFE:<s2>Telnet server not available in this RTOS version<nl>
        Otherwise:<s2> Existing Telnet server time-out value, in seconds.
 @comm  This function accesses the  Telnet server's existing time-out value.
        <nl>
        <nl>
        Refer to
        <linkto>../../config.htm#TELNET_TIMEOUT<linkmid>TELNET_TIMEOUT<linktail>
        in CHIP.INI documentation.
 @Also  tcp79a.htm | Set_TelnetServer_Idle_Timeout |
        tcp79.htm  | Set_FTPServer_Idle_Timeout   |
        tcp79b.htm | Get_FTPServer_Idle_Timeout
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x79<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
unsigned int Get_TelnetServer_Idle_Timeout(void)
{
    _BX = 0x01;                 // Telnet server
    _AL = 0x01;                 // get timeout
    _AH = SET_SERVER_IDLE_TIMEOUT ;
    asm { int TCPIPVECT  } ;
    return _DX ;
}
#endif

/*************************************************************************/
//Register an IP callback function on incoming packets
/*************************************************************************/

#ifdef _tcp7A_

/*
 @doc DOC_tcp7a_
 ---------------------------------------------------------------
 Register an IP user callback handler
 ---------------------------------------------------------------
 @clib  RegisterIPCallbackHandler | Register an IP User callback handler. |
        <cfont>int RegisterIPCallbackHandler ( void far *funcptr );<efont> |
 @parm  int  | funcptr  | Pointer to user's IP callback Handler.
 @rdesc 0 = success <nl>
 @comm  This function allows the application programmer to install a ip packet
        filter callback function. The application programmer can implement a
        function fitting the following type definition:<nl>
        <nl>
        <tab><cfont>typedef int (huge *IPSortOutFuncPtr)(<nl>
        <tab><tab><tab><tab>
          <linkto>../../tcpstruc.htm#IpUserCallbackInfo<linkmid>IpUserCallbackInfo<linktail>
          *ipInfo ); <efont><nl>
        <nl>
        If a function of this type is installed by the user, the TCP/IP stack
        will call this function at any incoming IP packet.<s2> Inside of this
        function the user is able to check the given IP parameters and decide
        if the TCP/IP stack should process this packet or ignore it.<s2>
        If the callback function returns -1 the incoming packet will be ignored
        by the TCP/IP stack.<nl>
        <nl>
        To uninstall the callback function, this API call must be called with
        a null pointer.<s2>
        <i><bold>Do not forget to uninstall the function if your application exits!
        <bolde><ie>
 @commtarget SC1x3 | <bold>Important:<bolde><s2> The callback will only execute
        on incoming IPv4 packets.<nl>
 @Also  tcp19.htm | RegisterCallbackFunction |
        tcp7B.htm | Register_ARP_User_CB | 
        tcp7C.htm | RegisterIPCallbackHandler_Snd
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x7A<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90
*/
int RegisterIPCallbackHandler(void far *funcptr)
{
    _ES = FP_SEG(funcptr) ;
    _DI = FP_OFF(funcptr) ;

    _AH = IP_CALLBACK;
    asm { int TCPIPVECT  } ;
    return _DX;
}
#endif




/*************************************************************************/
//Register ARP  callback function
//(requires RTOS 1.10B or higher)
/*************************************************************************/
#ifdef _tcp7B_
/*
 @doc DOC_tcp7b_
 ---------------------------------------------------------------
 Register an ARP user callback handler
 ---------------------------------------------------------------
 @clib  Register_ARP_User_CB | Register an ARP User callback handler. |
        <cfont>void Register_ARP_User_CB(void far * funcPtr);<efont> |
 @parm  int  | funcptr  | Pointer to ARP callback function (or set to null to remove
                         a previously installed callback)
 @rdesc returns nothing<nl>
 @comm
        The application programmer can implement a function fitting the following
        type definition:<nl>
        <nl>
        <tab><cfont>typedef int (huge *MyArpCallbackFuncPtr)(<nl><tab><tab><tab><tab>
        <linkto>../../tcpstruc.htm#ArpUserCallbackInfo<linkmid>ArpUserCallbackInfo_t<linktail>
        far *arpInfo );<efont><nl>
        <nl>
        If a function of this type is installed by the user, the TCP/IP stack will call this
        function for any incoming ARP packet.<s2> The input parameter to the callback function
        allows access to the ARP packet.<s2> Inside of this function the user is able
        to check the content  of the incoming ARP packet and decide whether the TCP/IP
        stack should process this packet or ignore it.<s2> If the callback function
        returns -1, the incoming packet will be ignored by the TCP/IP stack.<nl>
        <nl>
        For structure of an ARP packet see 
        <linkto>../../tcpstruc.htm#ArpHeader<linkmid>ArpHeader<linktail>.<nl>
        <nl>
        To remove the callback function, this function call must be called with a null pointer.<s2>
        <bold><i>Do not forget to uninstall the callback if your application exits!<bolde><ie><nl>
        <nl>
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x7B<linkmid>documentation<linktail>
        for more details.
 @Also  tcp19.htm | RegisterCallbackFunction |
        tcp7A.htm | RegisterIPCallbackHandler | 
        tcp7C.htm | RegisterIPCallbackHandler_Snd

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x7B<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
void Register_ARP_User_CB(void far * funcPtr)
{
    _ES = FP_SEG(funcPtr) ;
    _DI = FP_OFF(funcPtr) ;

    _AH = ARP_USER_CB;
    asm { int TCPIPVECT  } ;
}
#endif

/*************************************************************************/
//Register an IP callback function on outgoing packets
/*************************************************************************/
#ifdef _tcp7C_

/*
 @doc DOC_tcp7C_
 ---------------------------------------------------------------
 Register an IP user callback handler
 ---------------------------------------------------------------
 @clib  RegisterIPCallbackHandler_Snd | Register an IP user callback handler 
        on outgoing packets. |
        <cfont>int RegisterIPCallbackHandler_Snd ( void far *funcptr );<efont> |
 @parm  int  | funcptr  | Pointer to user's IP callback Handler.
 @rdesc 0 = success <nl>
 @comm  This function allows the application programmer to install an IP packet
        filter callback function.<s2> The application programmer can implement a
        function fitting the following type definition:<nl>
        <nl>
        <tab><cfont>typedef int (huge *IPCheckOutPacketFuncPtr)(<nl>
        <tab><tab><tab><tab>
          <linkto>../../tcpstruc.htm#IpUserCallbackInfo<linkmid>IpUserCallbackInfo_t<linktail>
          *ipInfo );<efont><nl>
        <nl>
        If a function of this type is installed by the user, the TCP/IP stack
        will call this function at any end IP packet.<s2> Inside of this
        function the user is able to check the given IP parameters and decide
        if the TCP/IP stack should send this packet or ignore it.<s2>
        If the callback function returns -1 the incoming packet will be ignored
        by the TCP/IP stack.<nl>
        <nl>
        To uninstall the callback function, this API call must be called with
        a null pointer.<s2>
        <bold><i>Do not forget to uninstall the function if your application exits!
        <bolde><ie>
 @commtarget SC1x3 | <bold>Important:<bolde><s2> The callback will only execute
        on incoming IPv4 packets.<nl>
 @Also  tcp19.htm | RegisterCallbackFunction |
        tcp7A.htm | RegisterIPCallbackHandler |
        tcp7B.htm | Register_ARP_User_CB
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x7C<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90


*/
int RegisterIPCallbackHandler_Snd(void far *funcptr)
{
    _ES = FP_SEG(funcptr) ;
    _DI = FP_OFF(funcptr) ;
    _AH = IP_CALLBACK_SND;
    asm { int TCPIPVECT  } ;
    return _DX;
}
#endif


/*************************************************************************/
// Add gateway
/*************************************************************************/
#ifdef _tcp80_
/*
 @doc DOC_tcp80_
 ---------------------------------------------------------------
 Add the default gateway
 ---------------------------------------------------------------
 @clib  AddDefaultGateway | Add the default gateway. |
        <cfont>int AddDefaultGateway ( IP_INTERFACE which_interface,<nl>
        <tab><tab><tab><tab><tab><tab>const unsigned long far *Gateway,<nl>
        <tab><tab><tab><tab><tab><tab>int *error );<efont> |
 @parm  int  | which_interface  | Enumeration type:<nl>
        <ul>
        <li>II_ETHERNET = 0:<s2>  Ethernet
        <li>II_PPP_SERVER = 1:<s2>  PPP server
        <li>II_PPP_CLIENT = 2:<s2>  PPP client
        <ule>
 @parm  int  | Gateway  | Pointer to gateway IP address in network
       byte order.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  If this function is used, the
        <linkto>../../config.htm#IP_GATEWAY<linkmid>gateway<linktail>
        entry in the <cfont>CHIP.INI<efont> becomes invalidated, but
        unchanged.<s2> If the PPP server or PPP client is specified by the
        <code>which_interface<codee> parameter, then the gateway is set
        to the remote peer IP address.
 @Also  tcp80a.htm | AddDefaultGatewayEx |
        tcp81.htm | DelDefaultGateway  |
        tcp82.htm |  GetDefaultGateway
 @Also  tcp83.htm | AddStaticRoute  |
        tcp84.htm | DelStaticRoute  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x80<linkmid>documentation<linktail>
        for more details.

 @related IP | ../../config.htm#IP_GATEWAY | Gateway |
    <cfont>CHIP.INI<efont> Configuration
 @related PPP server | ../../config.htm#PPPSERVER_GATEWAY | Gateway |
    <cfont>CHIP.INI<efont> Configuration
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90
*/
int  AddDefaultGateway (IP_INTERFACE which_interface,
                        const unsigned long far * Gateway,
                        int * error)
{
    _BX = which_interface ;
    _ES = FP_SEG(Gateway);
    _DI = FP_OFF(Gateway);
    _AH = ADD_DEFAULT_GATEWAY ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif


#ifdef _tcp80a_
/*
 @doc DOC_tcp80a_
 ---------------------------------------------------------------
 Add the default gateway
 ---------------------------------------------------------------
 @clib  AddDefaultGatewayEx | Add the default gateway (Extended). |
        <cfont>int AddDefaultGatewayEx ( IP_INTERFACE which_interface,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp; unsigned long far *Gateway,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp; void far *userIfaceHandle,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp; int *error );<efont> |
 @parm  int  | which_interface  | Enumeration type:<nl>
        <ul>
        <li>II_ETHERNET = 0:<s2>  Ethernet
        <li>II_PPP_SERVER = 1:<s2>  PPP server
        <li>II_PPP_CLIENT = 2:<s2>  PPP client
        <li>II_USER_DEVICE = 3:<s2>  user device driver
        <ule>
 @parm  int  | Gateway  | Pointer to gateway IP address in network
      byte order.
 @parm  int  | userIfaceHandle | If <cfont>which_interface<efont>==3,
        Pointer to user device handle.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  If this function is used, the
        <linkto>../../config.htm#IP_GATEWAY<linkmid>gateway<linktail>
        entry in the <cfont>CHIP.INI<efont> becomes invalidated, but
        unchanged.<s2> If the PPP server or PPP client is specified by the
        <code>which_interface<codee> parameter, then the gateway is set
        to the remote peer IP address.
 @Also  tcp80.htm | AddDefaultGateway |
        tcp81.htm | DelDefaultGateway  |
        tcp82.htm |  GetDefaultGateway
        
 @Also  tcp83.htm | AddStaticRoute  |
        tcp84.htm | DelStaticRoute  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x80<linkmid>documentation<linktail>
        for more details.

 @related IP | ../../config.htm#IP_GATEWAY | Gateway |
    <cfont>CHIP.INI<efont> Configuration
 @related PPP server | ../../config.htm#PPPSERVER_GATEWAY | Gateway |
    <cfont>CHIP.INI<efont> Configuration
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90
*/
int  AddDefaultGatewayEx (IP_INTERFACE which_interface,
                          const unsigned long far * Gateway,
                          const void  far * userIfaceHandle,
                          int * error)
{
    _BX = which_interface ;
    _ES = FP_SEG(Gateway);
    _DI = FP_OFF(Gateway);
    _DX = FP_SEG(userIfaceHandle);
    _SI = FP_OFF(userIfaceHandle);
    _AH = ADD_DEFAULT_GATEWAY ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif


/*************************************************************************/
// Delete gateway
/*************************************************************************/
#ifdef _tcp81_
/*
 @doc DOC_tcp81_
 ---------------------------------------------------------------
 Delete the default gateway
 ---------------------------------------------------------------
 @clib  DelDefaultGateway | Delete the default gateway. |
        <cfont>int DelDefaultGateway ( const unsigned long far *Gateway,<nl>
        <tab><tab><tab><tab><tab><tab>int *error );<efont> |
 @parm  int  | Gateway  | Pointer to gateway IP address to be
        removed.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  If this function is used, the
        <linkto>../../config.htm#IP_GATEWAY<linkmid>gateway<linktail>
        entry in the <cfont>CHIP.INI<efont> becomes invalidated, but
        unchanged.
 @Also  tcp80.htm | AddDefaultGateway |
        tcp82.htm | GetDefaultGateway | |
 @Also  tcp83.htm | AddStaticRoute  |
        tcp84.htm | DelStaticRoute  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x81<linkmid>documentation<linktail>
        for more details.

 @related IP | ../../config.htm#IP_GATEWAY | Gateway |
    <cfont>CHIP.INI<efont> Configuration
 @related PPP server | ../../config.htm#PPPSERVER_GATEWAY | Gateway |
    <cfont>CHIP.INI<efont> Configuration
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90
*/
int  DelDefaultGateway (const unsigned long far * Gateway, int * error)
{
    _ES = FP_SEG(Gateway);
    _DI = FP_OFF(Gateway);
    _AH = DEL_DEFAULT_GATEWAY ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
// Get gateway
/*************************************************************************/
#ifdef _tcp82_
/*
 @doc DOC_tcp82_
 ---------------------------------------------------------------
 Get the current default gateway
 ---------------------------------------------------------------
 @clib  GetDefaultGateway | Get the current default gateway. |
        <cfont>int GetDefaultGateway ( unsigned long far *Gateway,<nl>
        <tab><tab><tab><tab><tab><tab>int *error );<efont> |
 @parm  int  | Gateway  | Output parameter:<s2>Pointer to where
        the gateway IP will be written in network byte order.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @Also  tcp80.htm | AddDefaultGateway  |
        tcp81.htm | DelDefaultGateway  | |
 @Also  tcp83.htm | AddStaticRoute  |
        tcp84.htm | DelStaticRoute  | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x82<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int  GetDefaultGateway (unsigned long far * Gateway, int * error)
{
    _ES = FP_SEG(Gateway);
    _DI = FP_OFF(Gateway);
    _AH = GET_DEFAULT_GATEWAY ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif


/*************************************************************************/
// Add a static route
/*************************************************************************/
#ifdef _tcp83_
/*
 @doc DOC_tcp83_
 ---------------------------------------------------------------
 Add a route for a interface
 ---------------------------------------------------------------
 @clib  AddStaticRoute | Add a route for a interface. |
        <cfont>int AddStaticRoute ( IP_INTERFACE which_interface,<nl>
        <tab><tab><tab><tab><tab> const Route_Entry far *route,<nl>
        <tab><tab><tab><tab><tab> int *error );<efont> |
 @parm  int  | which_interface  | Enumeration type:<nl>
        <ul>
        <li>II_ETHERNET = 0:<s2>  Ethernet
        <li>II_PPP_SERVER = 1:<s2>  PPP server
        <li>II_PPP_CLIENT = 2:<s2>  PPP client
        <ule>
 @parm  int  | route  | Pointer to user  <code>Route_Entry<codee>
        <linkto>../../tcpstruc.htm#Route_Entry<linkmid>structure<linktail>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  The <code>Route_Entry<codee> structure is defined in tcpipapi.h:<nl>
        <nl>Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x83<linkmid>documentation<linktail>
        for more details.
 @Also  tcp84.htm | DelStaticRoute  | | | |
 @Also  tcp80.htm | AddDefaultGateway |
        tcp81.htm | DelDefaultGateway |
        tcp82.htm | GetDefaultGateway
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x83<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int  AddStaticRoute (IP_INTERFACE which_interface,
                     const Route_Entry far * route,
                     int * error)
{
    _BX = which_interface;
    _ES = FP_SEG(route);
    _DI = FP_OFF(route);
    _AH = ADD_STATIC_ROUTE ;
    asm { int TCPIPVECT  } ;
    *error = _AX ;
    return _DX ;
}
#endif


/*************************************************************************/
// Delete a static route
/*************************************************************************/
#ifdef _tcp84_
/*
 @doc DOC_tcp84_
 ---------------------------------------------------------------
 Delete a route from an interface
 ---------------------------------------------------------------
 @clib  DelStaticRoute | Delete a route from an interface. |
        <cfont>int DelStaticRoute ( IP_INTERFACE which_interface,<nl>
        <tab><tab><tab><tab><tab> const Route_Entry far *route,<nl>
        <tab><tab><tab><tab><tab> int *error );<efont> |
 @parm  int  | which_interface  | Enumeration type:<nl>
        <ul>
        <li>II_ETHERNET = 0:<s2>  Ethernet
        <li>II_PPP_SERVER = 1:<s2>  PPP server
        <li>II_PPP_CLIENT = 2:<s2>  PPP client
        <ule>
 @parm  int  | route  | Pointer to user  <code>Route_Entry<codee>
        <linkto>../../tcpstruc.htm#Route_Entry<linkmid>structure<linktail>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  Only <code>route<codee>structure members <code>destIPAddress<codee>
        and <code>destNetmask<codee> must be set valid before calling.<nl>
 @Also  tcp83.htm | AddStaticRoute  | | | |
 @Also  tcp80.htm | AddDefaultGateway  |
        tcp81.htm | DelDefaultGateway |
        tcp82.htm | GetDefaultGateway
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x84<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.00 | V1.00 | V1.00 | V0.90

*/
int  DelStaticRoute (IP_INTERFACE which_interface,
                     const Route_Entry far * route,
                     int * error)
{
    _BX = which_interface;
    _ES = FP_SEG(route);
    _DI = FP_OFF(route);
    _AH = DEL_STATIC_ROUTE ;
    asm { int TCPIPVECT  } ;
    *error= _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
// Delete ARP entry by physical address
/*************************************************************************/
#ifdef _tcp88_
/*
 @doc DOC_tcp88_
 ---------------------------------------------------------------
 Delete ARP entry by physical address
 ---------------------------------------------------------------
 @clib  DelArpEntryByPhys | Delete ARP entry by physical address. |
        <cfont>int DelArpEntryByPhys ( const unsigned char far *phy,<nl>
        <tab><tab><tab><tab><tab><s3> int *error );<efont> |
 @parm  unsigned char far *  | phy | Pointer to the physical address (6 Byte)
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.

 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA8<linkmid>documentation<linktail>
        for more details.
 @Also  tcp89.htm | AddArpEntry  |
        tcp8A.htm | GetARPRouteCacheEntries | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x88<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int DelArpEntryByPhys(const unsigned char far *phy, int *error)
{
    _ES = FP_SEG(phy);
    _DI = FP_OFF(phy);
    _AH = DEL_ARP_ENTRY_BY_PHYS;
    asm { int TCPIPVECT  } ;
    *error= _AX ;
    return _DX ;
}
#endif


/*************************************************************************/
// Add ARP entry
/*************************************************************************/
#ifdef _tcp89_
/*
 @doc DOC_tcp89_
 ---------------------------------------------------------------
 Add ARP entry
 ---------------------------------------------------------------
 @clib  AddArpEntry | Add an entry in the ARP table. |
        <cfont>int AddArpEntry ( const unsigned long far *ip,<nl>
        <tab><tab><tab><tab>&nbsp; const unsigned char far *phy,<nl>
        <tab><tab><tab><tab>&nbsp; int *error );<efont> |
 @parm  unsigned long far *  | ip  | Pointer to the IP address
 @parm  unsigned char far *  | phy | Pointer to the physical address (6 Byte)
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @Also  tcp88.htm | DelArpEntryByPhys  |
        tcp8A.htm | GetARPRouteCacheEntries  |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x89<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int AddArpEntry(const unsigned long far *ip, const unsigned char far *phy, int *error)
{
    _BX = FP_SEG(ip);
    _SI = FP_OFF(ip);
    _ES = FP_SEG(phy);
    _DI = FP_OFF(phy);
    _AH = ADD_ARP_ENTRY;
    asm { int TCPIPVECT  } ;
    *error= _AX ;
    return _DX ;
}
#endif


/*************************************************************************/
// Get ARP cache copy
/*************************************************************************/
#ifdef _tcp8A_
/*
 @doc DOC_tcp8A_
 ---------------------------------------------------------------
 Read ARP/Route cache table
 ---------------------------------------------------------------
 @clib  GetARPRouteCacheEntries |This function returns all valid entries
        in the internal ARP/Route cache table.|
        <cfont>int GetARPRouteCacheEntries(<nl>
        <tab><tab><tab><tab>ArpRouteCacheEntry far * arpuserptr);<efont> |
 @parm  void *  | arpuserptr  | Output Parameter:<s2> Pointer to a user provided array of 64
            data <linkto>../../tcpstruc.htm#ArpRouteCacheEntry<linkmid>structures<linktail>
            for storing ARP/Route cache table.
 @rdesc  Number of valid entries output to table at <cfont>arpuserptr<efont>.<s2>
         This user provided array contains the current ARP/Route cache table.<nl>
 @Also  tcp88.htm | DelArpEntryByPhys  |
        tcp89.htm | AddArpEntry  |   |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x8A<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int GetARPRouteCacheEntries(ArpRouteCacheEntry far * arpuserptr)
{
    _BX = FP_SEG(arpuserptr);
    _SI = FP_OFF(arpuserptr);
    _AH = GET_ARPROUTE_CACHE;
    asm { int TCPIPVECT  } ;
    return _CX ;   //number of valid entries at arpuser array
}
#endif
/*************************************************************************/
//interface information
/*************************************************************************/
#ifdef _tcp8D_
/*
 @doc DOC_tcp8D_
 ---------------------------------------------------------------
 Read table of TCP/IP device interfaces
 ---------------------------------------------------------------
 @clib  Get_Iface_Entries |This function returns information about all
        installed TCP/IP device interfaces.|
        <cfont>int Get_Iface_Entries(Iface_Entry far * iface_entry, int max);<efont> |
 @parm  void *  | iface_entry  | Output Parameter:<s2> Pointer to a user
            provided array of
             <linkto>../../tcpstruc.htm#Iface_Entry<linkmid>Iface_Entry<linktail>
             type data structures which will receive the information.
 @parm  int   | max | Number of data structures in array.<s2> Up to this number of
               device interfaces will be reported.
 @rdesc  Number of valid entries in the array at 
         <cfont>iface_entry<efont> containing
         reported  device interface information.
 @commtarget SC1x3 |  This function works only for IPv4 device interfaces.<s2>
         The <linkto>tcpC0.htm<linkmid>Get_IPv6_Iface_Entries<linktail> API
         should be used to read out information for IPv6 interfaces.
 @Also  tcpC0.htm | Get_IPv6_Iface_Entries  |  |  |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x8D<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int Get_Iface_Entries(Iface_Entry far * iface_entry, int max)
{
    _BX = FP_SEG(iface_entry);
    _SI = FP_OFF(iface_entry);
    _CX = max;
    _AH = GET_IFACE_ENTRIES;
    asm { int TCPIPVECT  } ;
    return (int)_AX ;   //number of valid entries at iface_entry array
}
#endif


#ifdef _tcp8F_
/*
 @doc DOC_tcp8F_
 ---------------------------------------------------------------
 Read table of TCP/IP device interfaces (extended)
 ---------------------------------------------------------------
 @clib  Get_Iface_Entries_Ext |This function returns information about all
        installed TCP/IP device interfaces.|
        <cfont>int Get_Iface_Entries_Ext(Iface_Entry_Ext far * iface_entry, int max);<efont> |
 @parm  void *  | iface_entry  | Output Parameter:<s2> Pointer to a user
            provided array of
             <linkto>../../tcpstruc.htm#Iface_Entry_Ext<linkmid>Iface_Entry_Ext<linktail>
             type data structures which will receive the information.
 @parm  int   | max | Number of data structures in array.<s2> Up to this number of
               device interfaces will be reported.
 @rdesc  Number of valid entries in the array at 
         <cfont>iface_entry<efont> containing
         reported  device interface information.

 @comm  This function is different from <linkto>tcpipapi.htm#0xAC0x8D<linkmid>GET_IFACE_ENTRIES<linktail>.
        It stores at the user provided array from type <linkto>../../tcpstruc.htm#Iface_Entry_Ext<linkmid>structures<linktail>
        all ip configurations (IP multihoming on one interface) of each interface found, not only the first one.

 @commtarget SC1x3 |  This function works only for IPv4 device interfaces.<s2>
         The <linkto>tcpC0.htm<linkmid>Get_IPv6_Iface_Entries<linktail> API
         should be used to read out information for IPv6 interfaces.
 @Also  tcpC0.htm | Get_IPv6_Iface_Entries  |  |  |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x8F<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.10
 @target_clib V2.04

*/
int Get_Iface_Entries_Ext(Iface_Entry_Ext far * iface_entry, int max)
{
    _BX = FP_SEG(iface_entry);
    _SI = FP_OFF(iface_entry);
    _CX = max;
    _AH = GET_IFACE_ENTRIES_EXT;
    asm { int TCPIPVECT  } ;
    return (int)_AX ;   //number of valid entries at iface_entry array
}
#endif





/*************************************************************************/
//interface mtu
/*************************************************************************/
#ifdef _tcp8E_
/*
@doc DOC_tcp8E_
 ---------------------------------------------------------------
 Set MTU of a device interface
 ---------------------------------------------------------------
 @clib  SetIfaceMTU | Set MTU (Maximum Transfer Unit) of a device interface. |
        <cfont>int SetIfaceMTU ( IP_INTERFACE which_interface,<nl>
        <tab><tab><tab><tab>&nbsp; const void far *userIfaceHandle,<nl>
        <tab><tab><tab><tab>&nbsp; int mtu,<nl>
        <tab><tab><tab><tab>&nbsp; int *error );<efont> |
 @parm  int  | which_interface  | Enumeration type:<nl>
        <ul>
        <li>II_ETHERNET = 0:<s2>  Ethernet
        <li>II_PPP_SERVER = 1:<s2>  PPP server
        <li>II_PPP_CLIENT = 2:<s2>  PPP client
        <li>II_USER_DEVICE = 3:<s2>  user device driver
        <ule>
 @parm  int  | userIfaceHandle | If <cfont>which_interface<efont> is 3,
        this parameter is a pointer to user device handle.
 @parm  int  | mtu      | Maximum Transfer Unit
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x8E<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90
*/
int SetIfaceMTU(IP_INTERFACE which_interface,const void  far * userIfaceHandle,
                unsigned int mtu, int *error)
{
   _BX = which_interface;
   _CX = mtu;
   _ES = FP_SEG(userIfaceHandle);
   _DI = FP_OFF(userIfaceHandle);
   _AH = SET_IFACE_MTU;
   asm { int TCPIPVECT  } ;
   *error = _AX ;
   return _DX ;
}
#endif
/*************************************************************************/
// Install an IP multicast address, join a multicast group
/*************************************************************************/
#ifdef _tcp90_
/*
 @doc DOC_tcp90_
 ---------------------------------------------------------------
 Install an IP multicast address entry
 ---------------------------------------------------------------
 @clib  Add_IGMP_Membership | Install an IP multicast address entry. |
        <cfont>int Add_IGMP_Membership ( const unsigned long far *MulticastIP,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp; const unsigned char far *MacAddress,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp; int *error );<efont> |
 @parm: (DOC_SC123)  int  | MulticastIP  | Pointer to multicast IPv4 address.
 @parm: (DOC_SC12)  int  | MulticastIP  | Pointer to multicast IP address.
 @parm  int  | MacAddress  | Pointer to a 6 byte array that
        contains the corresponding Ethernet address.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm
        IP Multicasting is the Internet abstraction of hardware multicasting.<s2> It allows transmission of
        IP datagrams to a group of hosts that form a single multicast group.<s2> Membership in a multicast group
        is dynamic.<s2> Hosts may join or leave the group at any time.<s2> Each multicast group
        has unique IP multicast address (Class D address).<s2> The first four bits of an IP multicast
        address must match to binary 1110.<s2> IP multicast addresses range from 224.0.0.0 through
        239.255.255.255.<nl>
        <nl>
        For the usage of IP multicasting on an Ethernet interface, IP multicast addresses must be mapped to
        Ethernet hardware addresses.<s2> The Ethernet device of the IPC@CHIP&reg; will be switched into the Ethernet
        multicast mode.<s2> In this mode it receives any incoming IP packet with the mapped Ethernet multicast
        address and forwards it to the TCP/IP layer.<s2>
        Each IP multicast packet will be sent with the mapped Ethernet multicast address.<nl>
        <nl>
        Because of the feature, that a multicast IP packet will be received by any member of a multicast group,
        sending and receiving of IP multicast packets is only usable with UDP sockets (datagram sockets).<nl>
        <nl>
        After installing a IP multicast address with this API, the application programmer is able use this
        address as a destination address when sending datagrams.<s2> A UDP socket is able to receive datagrams
        at the specified multicast address.<nl>
        <nl>
        The maximum number of supported IP multicast addresses in the IPC@CHIP&reg; is limited to 15.<s2>
        Before installing an IP multicast address, you can find out the corresponding Ethernet multicast address
        with <linkto>tcp92.htm<linkmid>IPMulticast_to_MacAddr<linktail> API.<nl>
        <nl>
        This implementation does not support multicast routing.<s2>
        Sending and receiving multicast datagrams works only at local network.<nl>
        Using multicast addresses is only possible on the Ethernet interface.<s2>

 @commtarget SC1x3 |  This API applies only to IPv4 multicast.
 @Also  tcp91.htm | Drop_IGMP_Membership  |
        tcp92.htm |  IPMulticast_to_MacAddr | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x90<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int  Add_IGMP_Membership(const unsigned long far * MulticastIP,
                         const unsigned char far * MacAddress,
                         int * error)
{

    asm { push DS } ;
   // Note: This higher level notation has the advantage over the assembly
   //    LES DI and LDS SI in that for small or medium memory models the
   //    compiler can figure out that FP_SEG(x) means DS register for near
   //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
   _ES = FP_SEG(MulticastIP) ;
   _DI = FP_OFF(MulticastIP) ;

   _DS = FP_SEG(MacAddress) ;
   _SI = FP_OFF(MacAddress) ;

   _AH = ADD_IGMP_MEMBERSHIP;
   asm { int TCPIPVECT } ;
   asm { pop DS } ;
    *error = _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
//Delete an IP multicast address, leave a multicast group
/*************************************************************************/
#ifdef _tcp91_
/*
 @doc DOC_tcp91_
 ---------------------------------------------------------------
 Delete an IP multicast address entry
 ---------------------------------------------------------------
 @clib  Drop_IGMP_Membership | Delete an IP multicast address entry. |
        <cfont>int Drop_IGMP_Membership ( const unsigned long far *MulticastIP,<nl>
        <tab><tab><tab><tab><tab><tab>&nbsp;&nbsp; int *error );<efont> |
 @parm  int  | MulticastIP  | Pointer to multicast IP address
        to be deleted.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @commtarget SC1x3 |  This API applies only to IPv4 multicast.
 @Also  tcp90.htm | Add_IGMP_Membership  |
        tcp92.htm |  IPMulticast_to_MacAddr | |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x91<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int  Drop_IGMP_Membership (const unsigned long far * MulticastIP, int * error)
{
   _ES = FP_SEG(MulticastIP);
   _DI = FP_OFF(MulticastIP);
   _AH = DROP_IGMP_MEMBERSHIP;
   asm { int TCPIPVECT  } ;
   *error = _AX ;
    return _DX ;
}
#endif

/*************************************************************************/
//Map IP multicast to Ethernet multicast
/*************************************************************************/
#ifdef _tcp92_
/*
 @doc DOC_tcp92_
 ---------------------------------------------------------------
 Map IP multicast address to Ethernet address
 ---------------------------------------------------------------
 @clib  IPMulticast_to_MacAddr | Map IP multicast address to Ethernet address. |
        <cfont>int IPMulticast_to_MacAddr (<nl>
        <tab><tab><tab><tab><tab> const unsigned long far *MulticastIP,<nl>
        <tab><tab><tab><tab><tab> unsigned char far *MacAddress,<nl>
        <tab><tab><tab><tab><tab> int *error );<efont> |
 @parm  int  | MulticastIP  | Pointer to multicast IP address.
 @parm  int  | MacAddress  | Output Parameter:<s2>Pointer to a 6 byte array
        where the corresponding MAC address will be stored by this function.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>error<codee> code.
 @comm  This API function computes the MAC address in the following way:<nl>
        To map an IP multicast address to a corresponding Ethernet multicast
        address, place the low-order 23 bits of the IP multicast address
        into the low order 23 bits of the special Ethernet multicast
        address<nl>
        <tab>01 00 5E 00 00  00<nl>
        <nl>
        e.g. IP multicast address 224.0.0.1 becomes Ethernet
        address<nl>
        <tab>01 00 5E 00 00 01
 @commtarget SC1x3 |  This API applies only to IPv4 multicast addresses.<nl>
 @Also  tcp90.htm | Add_IGMP_Membership  |
        tcp91.htm | Drop_IGMP_Membership |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x92<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.02 | V1.00 | V1.00 | V0.90

*/
int  IPMulticast_to_MacAddr (const unsigned long far * MulticastIP,
                             unsigned char far * MacAddress,
                             int * error)
{

   asm { push DS } ;
   // Note: This higher level notation has the advantage over the assembly
   //    LES DI and LDS SI in that for small or medium memory models the
   //    compiler can figure out that FP_SEG(x) means DS register for near
   //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
   _ES = FP_SEG(MulticastIP) ;
   _DI = FP_OFF(MulticastIP) ;

   _DS = FP_SEG(MacAddress) ;
   _SI = FP_OFF(MacAddress) ;

   _AH = MCASTIP_TO_MACADDR;
   asm { int TCPIPVECT } ;
   asm { pop DS } ;
    *error = _AX ;
    return _DX ;
}
#endif

#ifdef _tcp9F_
/*
@doc DOC_tcp9F_
 ---------------------------------------------------------------
 Get TCP/IP device driver interface IP address and netmask
 ---------------------------------------------------------------
 @clib  Dev_Get_IP |  Get user device IP address and netmask. |

        <cfont>int  Dev_Get_IP(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab>int * ipaddr),<nl>
        <tab><tab><tab><tab>int * netmask,<nl>
        <tab><tab><tab><tab>int * errorcode);<efont> |

 @parm  void *  | DevHandlePtr  | 
 <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  int  | ipaddr    | Output parameter:<s2>Pointer to 32 bit location
        which will receive the IP address in big endian (network) byte order.
 @parm  int  | netmask    | Output parameter:<s2>Pointer to 32 bit location
        which will receive the net mask in big endian (network) byte order.
 @parm  int  | errorcode    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>errorcode<codee>.
 @Also  tcpA0.htm | Dev_Open_Interface  |
        tcpAB.htm | Dev_PPP_Get_Peer_IP |  |
  @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0x9F<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.05
 @target_clib V2.04

*/
int  Dev_Get_IP( DevUserIfaceHandle DevHandlePtr, 
                 long * ipaddr,
                 long * netmask,
                 int  * errorcode)
{
   _ES = FP_SEG(DevHandlePtr);
   _DI = FP_OFF(DevHandlePtr);
   _DX = FP_SEG(ipaddr);
   _SI = FP_OFF(ipaddr) ;
   _CX = FP_OFF(netmask) ;
   _BX = FP_SEG(netmask) ;

   _AH = DEV_GET_IP;
   asm { int TCPIPVECT  } ;
   *errorcode=_AX;
   return _DX;
}
#endif


#ifdef _tcpA0_
/*
 @doc DOC_tcpA0_
 ---------------------------------------------------------------
 Install/Add TCP/IP device driver interface
 ---------------------------------------------------------------
 @clib  Dev_Open_Interface |  Install user device driver |

        <cfont>Dev_Open_Interface(DevUserDriver far * DriverInfo,<nl>
        <tab><tab><tab><tab><tab>int * errorcode);<efont> |

 @parm  int  | DriverInfo  | Pointer to
         <linkto>../../tcpstruc.htm#DevUserDriver<linkmid>user driver information<linktail>.
 @parm  int  | errorcode    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>errorcode<codee>.
 @Also  tcpA1.htm | Dev_Close_Interface |
        tcpA2.htm | Dev_Recv_Interface | 
        tcpA3.htm | Dev_Recv_Wait
 @Also  tcpA4.htm | Dev_Notify_ISR |
        tcpA5.htm | Dev_Get_Buffer | 
        tcpA6.htm | Dev_Send_Complete
 @Also  tcpA7.htm | Dev_Wait_DHCP_Complete |
        tcpA8.htm | Dev_PPP_Register_Chap |
        tcpA9.htm | Dev_PPP_Register_Pap
 @Also  tcpAA.htm | Dev_PPP_Set_Option |
        tcpAB.htm | Dev_PPP_Get_Peer_IP | 
        tcpAC.htm | Dev_PPP_Get_Peer_DNSIP
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA0<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#Install_Dev
        | Example | - Installing device driver
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90


*/
int  Dev_Open_Interface(DevUserDriver far * DriverInfo,int * errorcode)
{
   _ES = FP_SEG(DriverInfo);
   _DI = FP_OFF(DriverInfo);
   _AH = DEV_OPEN_IFACE;
   asm { int TCPIPVECT  } ;
   *errorcode = _AX;
   return (int)_DX;
}
#endif


#ifdef _tcpA1_
/*
@doc DOC_tcpA1_
 ---------------------------------------------------------------
 Close TCP/IP device driver interface
 ---------------------------------------------------------------
 @clib  Dev_Close_Interface |  Close user device driver/interface. |

        <cfont>int  Dev_Close_Interface(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab>int * errorcode);<efont> |

 @parm  void *  | DevHandlePtr  | 
 <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  int  | errorcode    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>errorcode<codee>.
 @Also  tcpA0.htm | Dev_Open_Interface  |
         |  |  |
  @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA1<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#Close_Dev
        | Example | - Closing device driver
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int  Dev_Close_Interface(DevUserIfaceHandle DevHandlePtr, int * errorcode)
{
   _ES = FP_SEG(DevHandlePtr);
   _DI = FP_OFF(DevHandlePtr);
   _AH = DEV_CLOSE_IFACE;
   asm { int TCPIPVECT  } ;
   *errorcode=_AX;
   return _DX;
}
#endif

#ifdef _tcpA2_
/*************************************************************************/
/*
@doc DOC_tcpA2_
 ---------------------------------------------------------------
 Receive and process incoming data at the TCP/IP stack
 ---------------------------------------------------------------
 @clib  Dev_Recv_Interface |  Receive and process incoming data at the TCP/IP stack. |
        <cfont>int Dev_Recv_Interface(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab>int * errorcode);<efont> |

 @parm  void *  | DevHandlePtr  | 
 <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  int  | errorcode    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>errorcode<codee>.
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA2<linkmid>documentation<linktail>
        for more details.
 @Also  tcpA0.htm | Dev_Open_Interface  |
        tcpA3.htm | Dev_Recv_Wait |
        tcpA4.htm | Dev_Notify_ISR
 @Also  tcpA6.htm | Dev_Send_Complete  |
        tcpA7.htm | Dev_Wait_DHCP_Complete |
          | 
 @related     | ../../ip_dev.htm#DeviceReceive
        | Example | - function which would be called by this API
 @related     | ../../ip_dev.htm#ISR_and_RECVTask
        | Example | - Receiver Task which calls this API
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
/*************************************************************************/
int  Dev_Recv_Interface(DevUserIfaceHandle DevHandlePtr, int * errorcode)
{
   _ES = FP_SEG(DevHandlePtr);
   _DI = FP_OFF(DevHandlePtr);
   _AH = DEV_RECV_IFACE;
   asm { int TCPIPVECT  };
   *errorcode=_AX;
   return _DX;
}
#endif

#ifdef _tcpA3_
/*
@doc DOC_tcpA3_
 ---------------------------------------------------------------
 Wait for received data.
 ---------------------------------------------------------------
 @clib  Dev_Recv_Wait | Waits for data received signal from Interrupt Service Routine. |

        <cfont>int Dev_Recv_Wait(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab>int * errorcode);<efont> |

 @parm  void *  | DevHandlePtr  |
 <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  int  | errorcode    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success <nl>
        -1:  See reported <code>errorcode<codee>.
 @Also   tcpA0.htm | Dev_Open_Interface  |
         tcpA2.htm | Dev_Recv_Interface |
         tcpA4.htm | Dev_Notify_ISR
 @Also   tcpA6.htm | Dev_Send_Complete  |
         tcpA7.htm | Dev_Wait_DHCP_Complete |
          | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA3<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#ISR_and_RECVTask
        | Example | - Receiver Task
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
/*************************************************************************/
int Dev_Recv_Wait(DevUserIfaceHandle DevHandlePtr, int * errorcode)
{
   _ES = FP_SEG(DevHandlePtr);
   _DI = FP_OFF(DevHandlePtr);
   _AH = DEV_RECV_WAIT;
   asm { int TCPIPVECT  };
   *errorcode=_AX;
   return _DX;
}
#endif

/*************************************************************************/
#ifdef _tcpA4_
/*
@doc DOC_tcpA4_
 ---------------------------------------------------------------
 Signal from ISR
 ---------------------------------------------------------------
 @clib  Dev_Notify_ISR | Notify the TCP/IP stack from inside of an
          Interrupt Service Routine that there is incoming data
          available and/or that the device has sent a
          frame successfully. |

        <cfont>int Dev_Notify_ISR( DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab> unsigned int receivedPackets,<nl>
        <tab><tab><tab><tab><tab> unsigned int sentPackets);<efont> |

 @parm  void *  | DevHandlePtr  | 
    <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  int  | receivedPackets | Number of available received packets
 @parm  int  | sentPackets     | Number of sent packets completed (provisional)
 @rdesc 0:  success <nl>
        -1:  See reported <code>errorcode<codee>.
 @Also  tcpA0.htm | Dev_Open_Interface  |
        tcpA3.htm | Dev_Recv_Wait |
         |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA4<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#ISR_and_RECVTask
        | Example | - User device ISR
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int Dev_Notify_ISR(DevUserIfaceHandle DevHandlePtr,
                   unsigned int receivedPackets,
                   unsigned int sentPackets)
{
   _BX = receivedPackets;
   _CX = sentPackets;
   _ES = FP_SEG(DevHandlePtr);
   _DI = FP_OFF(DevHandlePtr);
   _AH = DEV_NOTIFY_ISR;
   asm { int TCPIPVECT  };
   return _AX;
}
#endif
/*************************************************************************/
#ifdef _tcpA5_
/*
@doc DOC_tcpA5_
 ---------------------------------------------------------------
 Get a buffer from TCP/IP stack
 ---------------------------------------------------------------
 @clib  Dev_Get_Buffer | Get a buffer from TCP/IP stack's pre-allocated buffer for storing
          incoming data from this device. |
        <cfont>int Dev_Get_Buffer( DevUserBufferHandle BufHandlePtr,<nl>
        <tab><tab><tab><tab><tab> char far * far * buffer,<nl>
        <tab><tab><tab><tab><tab> unsigned int length);<efont> |

 @parm  void *  | BufHandlePtr  | Output Parameter:<s2> Pointer to location where this
        function will on success set a handle to the allocated buffer.<s2>  This
        handle is used internally by the @Chip-RTOS TCP/IP stack to manage the
        subsequent release of this allocated buffer.<nl>
 @parm  void *  | buffer | Output Parameter:<s2> Pointer to a variable of type
        <linkto>../../tcpstruc.htm#DevUserBufferHandle<linkmid>DevUserBufferHandle<linktail>
        where the user buffer handle is stored.<s2> (This value is for internal use.)
 @parm  int  | length     | Number of bytes buffer required
 @rdesc 0:  success , *buffer points to the beginning of the allocated buffer<nl>
        -1:  Allocation failed, *buffer is a null pointer.
 @Also  tcpA0.htm | Dev_Open_Interface  |
        tcpA2.htm | Dev_Recv_Interface |
        tcpA6.htm | Dev_Send_Complete
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA5<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#DeviceReceive
        | Receiver | function
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int Dev_Get_Buffer(DevUserBufferHandle BufHandlePtr,
                   char far * far * buffer,
                   unsigned int length)
{
   *buffer=NULL;
   asm{ push ds }
   asm{ les di,BufHandlePtr }
   _AH = DEV_GET_BUF ;
   _CX = length ;
   asm{ int TCPIPVECT }
   asm{ push dx }
   if(_AX==0)
   {
      *buffer = MK_FP(_DS,_SI);
   }
   asm pop dx
   asm pop ds
   return _DX;
}
#endif

#ifdef _tcpA6_
/*
@doc DOC_tcpA6_
 ---------------------------------------------------------------
 Signal message send complete
 ---------------------------------------------------------------
 @clib  Dev_Send_Complete | This API signals the TCP/IP stack that the final frame in a message
         has been sent.<s2> (Note that a message can be fragmented into
        multiple link layer frames.) |

        <cfont>int Dev_Send_Complete(DevUserIfaceHandle DevHandlePtr);<efont> |

 @parm  void *  | DevHandlePtr  | 
   <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @rdesc 0:  success<nl>
        Otherwise: error
 @Also  tcpA0.htm | Dev_Open_Interface  |
        tcpA2.htm | Dev_Recv_Interface |
        tcpA3.htm | Dev_Recv_Wait
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA6<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#DeviceSend
        | Example | - User's Device Send Function
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/

int Dev_Send_Complete(DevUserIfaceHandle DevHandlePtr)
{
   _ES = FP_SEG(DevHandlePtr);
   _DI = FP_OFF(DevHandlePtr);
   _AH = DEV_SND_COMPLETE;
   asm { int TCPIPVECT  };
   return _AX;
}
#endif


#ifdef _tcpA7_
/*
@doc DOC_tcpA7_
 ---------------------------------------------------------------
 Wait for DHCP completion
 ---------------------------------------------------------------
 @clib  Dev_Wait_DHCP_Complete | Waits for completion of IP configuration process
        by DHCP ("<i>Dynamic Host Configuration Protocol<ie>").<s2> |
        <cfont>int  Dev_Wait_DHCP_Complete(DevUserDriver far * DriverInfo,<nl>
        <tab><tab><tab><tab><tab><tab><s2> unsigned int time_s,<nl>
        <tab><tab><tab><tab><tab><tab><s2> int * errorcode);<efont> |

 @parm  void *  | DriverInfo  | Pointer to
         <linkto>../../tcpstruc.htm#DevUserDriver<linkmid>user driver information<linktail>.
 @parm  int  | time_s | Timeout seconds.<s2> This value will depend on the DHCP server used.<s2>
           A minimum value of 15 seconds is recommended.
 @parm  int  | errorcode    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.

 @rdesc 0:  success<nl>
        -1:  See reported <code>errorcode<codee>.
 @Also  tcpA0.htm | Dev_Open_Interface  |
        tcpA2.htm | Dev_Recv_Interface |
        tcpA3.htm | Dev_Recv_Wait
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA7<linkmid>documentation<linktail>
        for more details.
 @related     | ../../ip_dev.htm#ISR_and_RECVTask
        | Example | - User's receiver task
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.10 | V1.00 | V1.00 | V0.90

*/
int  Dev_Wait_DHCP_Complete(DevUserDriver far * DriverInfo, unsigned int time_s, int * errorcode)
{
   _CX = time_s;
   _ES = FP_SEG(DriverInfo);
   _DI = FP_OFF(DriverInfo);
   _AH = DEV_WAIT_DHCP_COMPLETE;
   asm { int TCPIPVECT  };
   *errorcode=_AX;
    return _DX;
}
#endif



#ifdef _tcpA8_
/*
@doc DOC_tcpA8_
 ---------------------------------------------------------------
 Register a PPP CHAP authentication callback function
 ---------------------------------------------------------------
 @clib  Dev_PPP_Register_Chap | Register a PPP CHAP authentication callback function. |
        <cfont>int Dev_PPP_Register_Chap(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab><tab><tab> const void far * AuthCallbackFunction,<nl>
        <tab><tab><tab><tab><tab><tab><tab> int *error);<efont> |

 @parm  void *  | DevHandlePtr  | 
        <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  void *  | AuthCallbackFunction | Pointer to the authentication callback function.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success<nl>
        -1:  failed

 @comm  The prototype of the user provided function is defined as:<nl><nl>
        <cfont>char huge * myCHAPAuthenticate(char *username) ;<efont><nl><nl>
        which returns the password (secret) corresponding to this user.<s2>
        If the user name is invalid, this function must return a NULL pointer.<nl>
 @Also  tcpA9.htm | Dev_PPP_Register_Pap  |
        tcpAA.htm | Dev_PPP_Set_Option |
        tcpAB.htm | Dev_PPP_Get_Peer_IP
 @Also  tcpAC.htm | Dev_PPP_Get_Peer_DNSIP  |
         |  |
         | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA8<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90
*/
int  Dev_PPP_Register_Chap(DevUserIfaceHandle DevHandlePtr,
                           const void far * AuthCallbackFunction, int * error)
{
    asm { push DS } ;
    // Note: This higher level notation has the advantage over the assembly
    //    LES DI and LDS SI in that for small or medium memory models the
    //    compiler can figure out that FP_SEG(x) means DS register for near
    //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
    _ES = FP_SEG(DevHandlePtr) ;
    _DI = FP_OFF(DevHandlePtr) ;

    _DS = FP_SEG(AuthCallbackFunction) ;
    _SI = FP_OFF(AuthCallbackFunction) ;

    _AH = DEV_PPP_REGISTER_CHAP ;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    *error = _AX ;
    return   _DX ;
}
#endif

#ifdef _tcpA9_
/*
@doc DOC_tcpA9_
 ---------------------------------------------------------------
 Register a PPP PAP authentication callback function
 ---------------------------------------------------------------
 @clib  Dev_PPP_Register_Pap | Register a PPP PAP authentication callback function. |
        <cfont>int Dev_PPP_Register_Pap(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab><tab><tab> const void far * AuthCallbackFunction,<nl>
        <tab><tab><tab><tab><tab><tab><tab> int *error);<efont> |

 @parm  void *  | DevHandlePtr  | 
    <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  void *  | AuthCallbackFunction | Pointer to the authentication callback function.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success<nl>
        -1:  failed
 @comm  The prototype of the user provided function is defined as:<nl><nl>
        <cfont>int huge * myPAPAuthenticate(char *username, char * password) ;<efont><nl><nl>
        which returns 1 for a valid username/password pair, else 0.<nl>

 @Also  tcpA8.htm | Dev_PPP_Register_Chap  |
        tcpAA.htm | Dev_PPP_Set_Option |
        tcpAB.htm | Dev_PPP_Get_Peer_IP
 @Also  tcpAC.htm | Dev_PPP_Get_Peer_DNSIP  |
         |  |
         | 

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xA9<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90
*/
int  Dev_PPP_Register_Pap(DevUserIfaceHandle DevHandlePtr,
                          const void far * AuthCallbackFunction, int * error)
{
    asm { push DS } ;
    // Note: This higher level notation has the advantage over the assembly
    //    LES DI and LDS SI in that for small or medium memory models the
    //    compiler can figure out that FP_SEG(x) means DS register for near
    //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
    _ES = FP_SEG(DevHandlePtr) ;
    _DI = FP_OFF(DevHandlePtr) ;

    _DS = FP_SEG(AuthCallbackFunction) ;
    _SI = FP_OFF(AuthCallbackFunction) ;

    _AH = DEV_PPP_REGISTER_PAP ;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    *error = _AX ;
    return   _DX ;
}
#endif

#ifdef _tcpAA_
/*
@doc DOC_tcpAA_
 -------------------------------------------------------------------
 Set PPP options on an own installed device driver from type of PPP
 -------------------------------------------------------------------
 @clib  Dev_PPP_Set_Option | Set PPP option on an own PPP device driver. |
        <cfont>int Dev_PPP_Set_Option(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab><tab> const PPP_Option far * ppp_option,<nl>
        <tab><tab><tab><tab><tab><tab> int *error);<efont> |

 @parm  void *  | DevHandlePtr  | 
    <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  void *  | ppp_option | Pointer to the
    <linkto>../../tcpstruc.htm#PPP_Option<linkmid>PPP option<linktail>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success<nl>
        -1:  failed
 @Also  tcpA8.htm | Dev_PPP_Register_Chap  |
        tcpA9.htm | Dev_PPP_Register_Pap |
        tcpAB.htm | Dev_PPP_Get_Peer_IP
 @Also  tcpAC.htm | Dev_PPP_Get_Peer_DNSIP  |
         |  |
         | 

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xAA<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90
*/

int  Dev_PPP_Set_Option(DevUserIfaceHandle DevHandlePtr,
                        const PPP_Option far * ppp_option, int * error)
{
    asm { push DS } ;
    // Note: This higher level notation has the advantage over the assembly
    //    LES DI and LDS SI in that for small or medium memory models the
    //    compiler can figure out that FP_SEG(x) means DS register for near
    //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
    _ES = FP_SEG(DevHandlePtr) ;
    _DI = FP_OFF(DevHandlePtr) ;

    _DS = FP_SEG(ppp_option) ;
    _SI = FP_OFF(ppp_option) ;

    _AH = DEV_PPP_SET_OPTION ;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    *error = _AX ;
    return   _DX ;
}
#endif


#ifdef _tcpAB_
/*
@doc DOC_tcpAB_
 -------------------------------------------------------------------
 Get PPP peer IP address
 -------------------------------------------------------------------
 @clib  Dev_PPP_Get_Peer_IP | Get IP address of a PPP peer. |
        <cfont>int Dev_PPP_Get_Peer_IP(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab><tab> long far * address,<nl>
        <tab><tab><tab><tab><tab><tab> int *error);<efont> |

 @parm  void *  | DevHandlePtr  | 
    <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm: (DOC_SC123)  long *  | address | Output parameter:<s2>Pointer to the storage 
            where the peer's IPv4 address in network byte order will be
            written by this API.
 @parm: (DOC_SC12)  long *  | address | Output parameter:<s2>Pointer to the storage 
            where the peer's IP address in network byte order will be 
            written by this API.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success, address points to the IP of the PPP peer<nl>
        -1:  failed
 @Also  tcpA8.htm | Dev_PPP_Register_Chap  |
        tcpA9.htm | Dev_PPP_Register_Pap |
        tcpAA.htm | Dev_PPP_Set_Option
 @Also  tcpAC.htm | Dev_PPP_Get_Peer_DNSIP  |
        tcp9F.htm | Dev_Get_IP |
         | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xAB<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90
*/

int Dev_PPP_Get_Peer_IP(DevUserIfaceHandle DevHandlePtr,
                        long far * Address, int * error)
{
    asm { push DS } ;
    // Note: This higher level notation has the advantage over the assembly
    //    LES DI and LDS SI in that for small or medium memory models the
    //    compiler can figure out that FP_SEG(x) means DS register for near
    //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
    _ES = FP_SEG(DevHandlePtr) ;
    _DI = FP_OFF(DevHandlePtr) ;

    _DS = FP_SEG(Address) ;
    _SI = FP_OFF(Address) ;

    _AH = DEV_PPP_GET_PEER_IP ;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    *error = _AX ;
    return   _DX ;
}
#endif

#ifdef _tcpAC_
/*
@doc DOC_tcpAC_
 ----------------------------------------------------------------------------------
 Get PPP DNS server address
 ----------------------------------------------------------------------------------
 @clib  Dev_PPP_Get_Peer_DNSIP | Get IP address of the DNS server from a PPP peer. |
        <cfont>int Dev_PPP_Get_Peer_DNSIP(DevUserIfaceHandle DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab><tab>long far * address,<nl>
        <tab><tab><tab><tab><tab><tab>int flag,<nl>
        <tab><tab><tab><tab><tab><tab>int *error);<efont> |

 @parm  void *  | DevHandlePtr  | 
    <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm: (DOC_SC123)  long *  | address | Output parameter:<s2>Pointer to the storage 
            where the DNS server's IPv4 address will be written by this API.
 @parm: (DOC_SC12)  long *  | address | Output parameter:<s2>Pointer to the storage 
            where the DNS server's IP address will be written by this API.
 @parm  int  | flag | 1: get IP of primary DNS server, 2: Get IP of secondary DNS server
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success, address points to the IP of the DNS server<nl>
        -1:  failed
 @Also  tcpA8.htm | Dev_PPP_Register_Chap  |
        tcpA9.htm | Dev_PPP_Register_Pap |
        tcpAA.htm | Dev_PPP_Set_Option
 @Also  tcpAB.htm | Dev_PPP_Get_Peer_IP  |
         |  |
         | 
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xAC<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.11 | V1.01 | V1.01 | V0.90
*/

int Dev_PPP_Get_Peer_DNSIP(DevUserIfaceHandle DevHandlePtr,
                           long far * Address, int flag, int * error)
{
    asm { push DS } ;
    // Note: This higher level notation has the advantage over the assembly
    //    LES DI and LDS SI in that for small or medium memory models the
    //    compiler can figure out that FP_SEG(x) means DS register for near
    //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
    _ES = FP_SEG(DevHandlePtr) ;
    _DI = FP_OFF(DevHandlePtr) ;

    _DS = FP_SEG(Address) ;
    _SI = FP_OFF(Address) ;

    _BX = flag ;
    _AH = DEV_PPP_GET_PEER_DNS ;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    *error = _AX ;
    return   _DX ;
}
#endif



#ifdef _tcpAD_
/*
@doc DOC_tcpAD_
 ----------------------------------------------------------------------------------
 Get Device handle  by name
 ----------------------------------------------------------------------------------
 @clib  Dev_Get_Handle_By_Name | Get the driver handle pointer by a given driver name |
        <cfont>int Dev_Get_Handle_By_Name(const char * drivername,<nl>
        <tab><tab><tab><tab><tab><tab><tab>DevUserIfaceHandle far * DevHandlePtr,<nl>
        <tab><tab><tab><tab><tab><tab><tab>int *error);
        <efont><nl> |

 @parm  void * * | DevHandlePtr  |
    Contains the found <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
 @parm  char *  | drivername | Driver name e.g. NE2000 (type RTOS command ipcfg)
 @rdesc 0:  success, DevHandlePtr contains the device handle pointer<nl>
        -1:  failed

 @comm  This function delivers the required driver handle pointer, which is necessary
        for using <linkto>tcpAE.htm<linkmid>Dev_Config_Iface<linktail>

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xAD<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.05
 @target_clib V2.04
*/

int Dev_Get_Handle_By_Name(const char * drivername,DevUserIfaceHandle far * DevHandlePtr,
                           int *error)
{
    unsigned int es_reg ;
    *error=0;
    *DevHandlePtr=NULL; //Preset
    asm { push DS } ;
    _DS = FP_SEG(drivername) ;
    _SI = FP_OFF(drivername) ;
    _AH = DEV_GET_HANDLE_BYNAME;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    if(_AX==0)
    {
        es_reg =_ES;
        *DevHandlePtr=MK_FP(es_reg,_DI);
        return 0;
    }
    *error = _AX ;
    return   _DX ;
}
#endif


#ifdef _tcpAE_
/*
@doc DOC_tcpAE_
 ----------------------------------------------------------------------------------
 IPv4 configuration of a device interface
 ----------------------------------------------------------------------------------
 @clib  Dev_Config_Iface | IPv4 configuration of an interface |
        <cfont>int Dev_Config_Iface(DevIpv4IfaceCfg far * devcfg, int *error);<efont><nl>|

 @parm  void *  | devcfg | <linkto>../../tcpstruc.htm#DevIpv4IfaceCfg<linkmid>DevIpv4IfaceCfg<linktail>
                 filled by the caller. Contains the device handle,IPv4 configuration
                 and the multihomeindex number.
 @rdesc 0:  success,<nl>
        -1:  failed<nl>

 @comm  This functions provides the possibility to configure a device interface
        (e.g. the standard internal ethernet interface) with multiple IP addresses
        by enter a particular multihome index number.
        If an interface is already configured at the specified multihomeindex number, the user
        first has to unconfigure it with <linkto>tcpB0.htm<linkmid>Dev_UnConfig_Iface<linktail><linktail>.
        DHCP configuration of a device is only possible at multihomeindex 0.<nl>It is recommended to use this
        function only for changing ip configuration of own device interfaces or for changing IP configuration
        of the internal ethernet interface for multihomeindex 1..3 (SC1x3 1 ..4).
        Clibrary-based example:<nl>

        @raw
        DevUserIfaceHandle DevHandlePtr;
        DevIpv4IfaceCfg  devcfg;
        int error;
        //Get the driver handle by name
        if(-1==Dev_Get_Handle_By_Name("NE2000",&DevHandlePtr,&error))
        {
          printf("\r\nError: Cannot detect driver handle, code %d",error);
          return 0;
        }
        //Set ip configuration
        devcfg.IfaceHandle    = DevHandlePtr;
        devcfg.flags          = 0;
        devcfg.multiHomeIndex = 1;  //configure particular multihomeindex 1
        inet_addr("192.168.200.59",&devcfg.IpAddr);
        inet_addr("255.255.255.0"",&devcfg.Netmask)

        if(-1==Dev_Config_Iface(&devcfg,&error))
        {
             printf("Error %d\r\n",error);
        }

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xAE<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.05
 @target_clib V2.04
*/

int Dev_Config_Iface(DevIpv4IfaceCfg far * devcfg, int *error)
{
    _ES = FP_SEG(devcfg) ;
    _DI = FP_OFF(devcfg) ;
    _AH = DEV_CONFIG_IFACE;
    asm { int TCPIPVECT } ;
    *error =_AX;
    return _DX;
}
#endif


#ifdef _tcpAF_
/*
@doc DOC_tcpAF_
 ----------------------------------------------------------------------------------
 Configure a device interface with IPv6
 ----------------------------------------------------------------------------------
 @clib  Dev_Config_Iface_IPv6 | IPv6 configuration of an interface |
        <cfont>int Dev_Config_Iface_IPv6(DevIpv6IfaceCfg far * devcfg, int *error);<efont><nl>|

 @parm  void *  | devcfg | <linkto>../../tcpstruc.htm#DevIpv6IfaceCfg<linkmid>DevIpv4IfaceCfg<linktail>
                 filled by the caller. Contains the device handle,IPv6 configuration
                 and the multihomeindex number.
 @rdesc 0:  success,<nl>
        -1:  failed<nl>

 @comm  This functions provides the possibility to configure a device interface
        (e.g. the standard internal ethernet interface) with multiple IPv6 addresses
        by enter a particular multihome index number.
        If an interface is already configured at the specified multihomeindex number, the user
        first has to unconfigure it with <linkto>tcpB0.htm<linkmid>Dev_UnConfig_Iface<linktail><linktail>.
        DHCP configuration of a device is only possible at multihomeindex 0.<nl>It is recommended to use this
        function only for changing ip configuration of own device interfaces or for changing IP configuration
        of the internal ethernet interface for multihomeindex 1..4.
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xAF<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version     n/a  |  n/a  | n/a   | V1.05
 @target_clib V2.04
*/

int Dev_Config_Iface_IPv6(DevIpv6IfaceCfg far * devcfg, int *error)
{
    _ES = FP_SEG(devcfg) ;
    _DI = FP_OFF(devcfg) ;
    _AH = DEV_CONFIG_IFACE_IPV6;
    asm { int TCPIPVECT } ;
    *error =_AX;
    return _DX;
}
#endif



#ifdef _tcpB0_
/*
@doc DOC_tcpB0_
 ----------------------------------------------------------------------------------
 Remove a IPv4 or IPv6 configuration from a device interface (ip multihome)
 ----------------------------------------------------------------------------------
 @clib  Dev_UnConfig_Iface | Remove IPv4 or IPv6 device configuration |
        <cfont>int Dev_UnConfig_Iface(DevUserIfaceHandle DevHandlePtr, <nl>
        <tab><tab><tab><tab><tab><tab><tab>unsigned int proto,unsigned char mHomeIndex,<nl>
        <tab><tab><tab><tab><tab><tab><tab>int *error);
        <efont><nl> |

 @parm  void * | DevHandlePtr  |
    <linkto>../../tcpstruc.htm#DevUserIfaceHandle<linkmid>Device handle<linktail>
@parm   int  | proto      | Protocol family AF:INET or AF_INET6
 @parm  int  | mHomeIndex | Multi home index number of the device
 @rdesc 0:  success,<nl>
        -1:  failed
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xB0<linkmid>documentation<linktail>
        for more details.
 @comm
 Remove an IP configuration from an interface for a particular multi home index<nl>
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.10
 @target_clib V2.04
*/

int Dev_UnConfig_Iface(DevUserIfaceHandle DevHandlePtr, int proto, unsigned char mHomeIndex, int *error)
{
    _ES = FP_SEG(DevHandlePtr) ;
    _DI = FP_OFF(DevHandlePtr) ;
    _BX = proto;
    _AL = mHomeIndex;
    _AH = DEV_UNCONFIG_IFACE;
    asm { int TCPIPVECT } ;
    *error =_AX;
    return _DX;
}
#endif




#ifdef _tcpC0_
/*
 @doc DOC_tcpC0_
 ---------------------------------------------------------------
 Read table of TCP/IP IPv6 device interfaces
 ---------------------------------------------------------------
 @clib  Get_IPv6_Iface_Entries | This function returns information about all 
        installed TCP/IP IPv6 device interfaces.|
        <cfont>int Get_IPv6_Iface_Entries(<nl>
        <tab><tab><tab><tab><tab><tab>IfaceIPv6_Entry  far * iface_ipv6_entries,<nl>
        <tab><tab><tab><tab><tab><tab>int max);<efont> |
 @parm  void *  | iface_ipv6_entries  | Output Parameter:<s2> Pointer to a
       user provided array of
       <linkto>../../tcpstruc.htm#IfaceIPv6_Entry<linkmid>IfaceIPv6_Entry<linktail>
        type data structures which will receive the information.
 @parm  int   | max | Number of data structures in array.<s2> Up to this number of
               device interfaces will be reported.
 @rdesc  Number of valid entries in the array at 
         <cfont>iface_ipv6_entries<efont> containing
         reported  device interface information.
 @comm  This function works only for IPv6 device interfaces.<s2>
         The <linkto>tcp8D.htm<linkmid>Get_Iface_Entries<linktail> API
         should be used to read out information for IPv4 interfaces.
 @Also  tcp8D.htm | Get_Iface_Entries  |  |  |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xC0<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   |  n/a  |  n/a  | V0.90
*/

int Get_IPv6_Iface_Entries(IfaceIPv6_Entry  far * iface_ipv6_entries, int max)
{
   _CX = max;
   _ES = FP_SEG(iface_ipv6_entries);
   _DI = FP_OFF(iface_ipv6_entries);
   _AH = GET_IPV6_IFACE_ENTRIES;
   asm { int TCPIPVECT  };
   return _AX;
}
#endif

#ifdef _tcpC1_
/*
 @doc DOC_tcpC1_
 ---------------------------------------------------------------
 Convert an IP address text to binary
 ---------------------------------------------------------------
 @clib  inet_pton | Convert an IP address from standard text representation to binary.|
        <cfont>int inet_pton( int af,<nl>
        <tab><tab><tab><s2> const char far * source_ptr,<nl>
        <tab><tab><tab><s2> void far * dest_ptr);<efont> |
 @parm  int    | af     | Address family, AF_INET (for IPv4) or AF_INET6 (for IPv6)
 @parm  void * | src    | Input Parameter:<s2> Pointer to the IP address text
        (null terminated) to be converted
 @parm  void * | dst    | Output Parameter:<s2> Storage provided by the user which
        will receive the converted binary IP address.<s2> This buffer must provide
        4 bytes for AF_INET and 16 Bytes for AF_INET6.
 @rdesc <hangpara 12:18>1:<s2>  Success, the <cfont>dst<efont> buffer contains the converted
            binary IP in network byte order.<paraend>
        <hangpara 12:18>0:<s2>   Input string at <cfont>src<efont> was not a valid IP address of 
        indicated type (IPv4 or IPv6).<paraend>
        <hangpara 12:18>-1:  The <cfont>af<efont> parameter was set to an invalid
        address family.<paraend>
 @Also  tcpC2.htm | inet_ntop  |
        tcp08.htm| inet_addr |  |

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xC1<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   |  n/a  |  n/a  | V0.90
 */
int inet_pton(int af, const char far * source_ptr, void far * dest_ptr)
{
    asm { push DS } ;
    // Note: This higher level notation has the advantage over the assembly
    //    LES DI and LDS SI in that for small or medium memory models the
    //    compiler can figure out that FP_SEG(x) means DS register for near
    //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
    _ES = FP_SEG(source_ptr) ;
    _DI = FP_OFF(source_ptr) ;

    _DS = FP_SEG(dest_ptr) ;
    _SI = FP_OFF(dest_ptr) ;

    _BX = af ;
    _AH = INET_PTON;
    asm { int TCPIPVECT } ;
    asm { pop DS } ;

    return _DX;
}
//#endif
#endif

#ifdef _tcpC2_
/*
 @doc  DOC_tcpC2_
 -----------------------------------------------------------------------------------
 Convert an IP address from the binary format to standard text representation format
 -----------------------------------------------------------------------------------
 @clib  inet_ntop | Convert an IP address from binary to standard text. |
        <cfont>int inet_ntop( int af,<nl>
        <tab><tab><tab><s2> const void far * source_ptr,<nl>
        <tab><tab><tab><s2> char far * dest_ptr,int max);<efont> |
 @parm  int    | af     | Address family, AF_INET (for IPv4) or AF_INET6 (for IPv6)
 @parm  void * | src    | Input Parameter:<s2> Pointer to the IP address
            in binary to be converted.
 @parm  void * | dst    | Output Parameter:<s2> Storage provided by the caller which
        will receive the converted IP address text.<s2> This text will be a null
        terminated string.<nl>
 @parm  int    | max    | Size in bytes, of the provided buffer at <cfont>dst<efont>.<s2>
                          This string buffer should provide 16 bytes for AF_INET 
                          and 46 Bytes for AF_INET6.
 @rdesc <hangpara 12:18>1:<s2>  Success, the <cfont>dst<efont> buffer contains the converted IP address string. 
        <paraend>
        <hangpara 12:18>0:<s2>   Input at <cfont>src<efont> was not a valid IP address of indicated type
        (IPv4 or IPv6).<paraend>
        <hangpara 12:18>-1:  The <cfont>af<efont> parameter was set to an invalid address family.<paraend>
 @Also  tcpC1.htm | inet_pton  |
        tcp11.htm| InetToAscii |  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xC2<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   |  n/a  |  n/a  | V0.90
*/
int inet_ntop(int af , const void far * source_ptr, char far * dest_ptr, int max)
{

  asm { push DS } ;
   // Note: This higher level notation has the advantage over the assembly
   //    LES DI and LDS SI in that for small or medium memory models the
   //    compiler can figure out that FP_SEG(x) means DS register for near
   //    pointers.  For far pointers it compiles into the LES/LDS opcodes.
   _ES = FP_SEG(source_ptr) ;
   _DI = FP_OFF(source_ptr) ;

   _DS = FP_SEG(dest_ptr) ;
   _SI = FP_OFF(dest_ptr) ;

   _CX = max;
   _BX = af ;
   _AH = INET_NTOP;
   asm { int TCPIPVECT } ;
   asm { pop DS } ;
   return _DX;
}
#endif

#ifdef _tcpC3_
/*
 @doc DOC_tcpC3_
 ---------------------------------------------------------------
 open socket for IPv4 or IPv6 family
 ---------------------------------------------------------------
 @clib opensocket_ext | Open an IPv4 or IPv6 socket. |
        <cfont>int opensocket_ext(int family, unsigned char type,  int *error);<efont> |
 @parm  int  | family  | address family AF_INET (2) for IPv4 or AF_INET6 (28) for IPv6<nl>
 @parm  int  | type  | SOCK_STREAM = 1 for TCP socket<nl>
        SOCK_DGRAM = 2 for UDP datagram socket.
 @parm  int  | error   | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm<linkmid>code<linktail>, 0 on success.
 @rdesc -1: Failure (see <code>error<codee> output parameter)<nl>
        else socket descriptor
 @comm  Creates an endpoint for communication and returns a socket descriptor.
        <s2>This function provides the BSD socket() functionality.

 @Also  tcp02.htm | closesocket  |
        tcp03.htm | bind |
        tcp04.htm | connect

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xC3<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   |  n/a  |  n/a  | V0.90

*/
int opensocket_ext(int family, unsigned char type,  int *error)
{
    int sd;
    unsigned char fcode;
    int error_code = 0 ;

    fcode = (family==AF_INET)?API_OPENSOCKET:API_OPENSOCKET_IPV6;

    _AL = type ;
    _AH = fcode;
    asm { int TCPIPVECT  } ;
    sd = _AX ;
    if (_DX != 0)
    {
        error_code = sd ;       // Error code was returned in AX.
        sd = -1 ;
    }
    *error = error_code ;
    return sd ;
}
#endif


#ifdef _tcpD0_
/*
@doc DOC_tcpD0_
 ----------------------------------------------------------------------------------
 Add a certificate
 ----------------------------------------------------------------------------------
 @clib  PKI_CertificateAdd | Add a certificate to the public key infrastructure.
        The CA certificate must be added before the certificate is added.
        In addition, the private/public key pair for a local certificate must be
        added before adding the local certificate. |
        <cfont>int PKI_CertificateAdd(PKI_CERT_ADD_EntryPtr addEntryPtr, int *error);<efont> |
 @parm  PKI_CERT_ADD_EntryPtr  | addEntryPtr |
    <linkto>../../tcpstruc.htm#PKI_CERT_ADD_Entry<linkmid>Certificate Add structure<linktail>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success<nl>
        -1:  failed
 @Also  tcpD1.htm | PKI_CertificateDel |
        tcpD2.htm | PKI_OwnKeyPairAdd  |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xD0<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int PKI_CertificateAdd(PKI_CERT_ADD_EntryPtr addEntryPtr, int *error)
{
  _DI = FP_OFF(addEntryPtr);
  _ES = FP_SEG(addEntryPtr);
  _AH = PKI_CERT_ADD;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpD1_
/*
@doc DOC_tcpD1_
 ----------------------------------------------------------------------------------
 Delete a certificate
 ----------------------------------------------------------------------------------
 @clib  PKI_CertificateDel | Delete a certificate from the public key infrastructure. |
        <cfont>int PKI_CertificateDel(void far *idPtr, int *error);<efont> |
 @parm  void far * | idPtr | pointer to certificate identification string
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success<nl>
        -1:  failed
 @Also  tcpD0.htm | PKI_CertificateAdd |
        tcpD2.htm | PKI_OwnKeyPairAdd  |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xD1<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int PKI_CertificateDel(void far * idPtr, int *error)
{
  _DI = FP_OFF(idPtr);
  _ES = FP_SEG(idPtr);
  _AH = PKI_CERT_DEL;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpD2_
/*
@doc DOC_tcpD2_
 ----------------------------------------------------------------------------------
 Add a private/public key pair
 ----------------------------------------------------------------------------------
 @clib  PKI_OwnKeyPairAdd | Add a public/private key pair for a local certificate to the public
        key infrastructure. |
        <cfont>int PKI_OwnKeyPairAdd(PKI_OWNKEYPAIR_ADD_EntryPtr keyEntryPtr,<nl>
               <tab><tab><tab><tab><tab>&nbsp; int *error);<efont> |
 @parm  PKI_OWNKEYPAIR_ADD_EntryPtr  | keyEntryPtr |
    <linkto>../../tcpstruc.htm#PKI_OWNKEYPAIR_ADD_Entry<linkmid>Own key pair structure<linktail>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0:  success<nl>
        -1:  failed
 @Also  tcpD0.htm | PKI_CertificateAdd  |
        tcpD1.htm | PKI_CertificateDel  |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xD2<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int PKI_OwnKeyPairAdd(PKI_OWNKEYPAIR_ADD_EntryPtr keyEntryPtr, int *error)
{
  _DI = FP_OFF(keyEntryPtr);
  _ES = FP_SEG(keyEntryPtr);
  _AH = PKI_OWNKEYPAIR_ADD;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpD7_
/*
@doc DOC_tcpD7_
 ----------------------------------------------------------------------------------
 Close a SSL session
 ----------------------------------------------------------------------------------
 @clib  SSL_SessionClose | Close a SSL session.  |
        <cfont>int SSL_SessionClose(int sessionID, int *error);<efont> |
 @parm  int  | sessionId | Session ID
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Success<nl>
        -1:  failed
 @comm  All cached connection information in this session will be freed too.
        User should close the SSL connection or the socket, first.

 @Also  tcpD8.htm | SSL_SessionNew |
                  |                |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xD7<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_SessionClose(int sessionID, int *error)
{
  _BX = sessionID;
  _AH = SSL_SESSION_CLOSE;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpD8_
/*
@doc DOC_tcpD8_
 ----------------------------------------------------------------------------------
 Open a new SSL session
 ----------------------------------------------------------------------------------
 @clib  SSL_SessionNew | Open a new SSL session. Could be used as either SSL
        server session or SSL client session. If it is used as a server session
        the field certIdentity in the structure should be non-null, otherwise
        the SSL server can't run on this session. |
        <cfont>int SSL_SessionNew(SSL_SESSION_NEW_EntryPtr newSessionPtr,<nl>
               <tab><tab><tab><tab>&nbsp;&nbsp; int *error);<efont> |
 @parm  SSL_SESSION_NEW_EntryPtr  | newSessionPtr |
    <linkto>../../tcpstruc.htm#SSL_SESSION_NEW_Entry<linkmid>New SSL structure<linktail>
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc >;0: Session ID<nl>
        -1:  failed
 @comm Each session maintains its own connect information for the convenience
       of reconsumption. You can resume a previous connection only if the current
       connect attempt and the previous one are in the same SSL session, and
       your previous connection cache hasn't been overwritten yet.<nl>
       <nl>
       For SSL server, all connections spawned from a single listening socket
       belong to one session, you should assign the session ID to the listening
       socket. All accepted sockets will inherit that session ID.<nl>
       <nl>
       For SSL client, user determines which session one connection belongs to.
       For example, users may decide that any connection to the same SSL server
       uses a single session ID, so that when user is trying to connect to the
       same server again, he may resume the previous connection.

 @Also  tcpD9.htm | SSL_SessionProp |
        tcpDA.htm | SSL_SessionOpt  |
        tcpD7.htm | SSL_SessionClose

 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xD8<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_SessionNew(SSL_SESSION_NEW_EntryPtr newSessionPtr, int *error)
{
  _DI = FP_OFF(newSessionPtr);
  _ES = FP_SEG(newSessionPtr);
  _AH = SSL_SESSION_NEW;
  asm { int TCPIPVECT  } ;
  if (_DX == 0)
  {
    *error = _DX;
    return _AX;     // AX contains SessionID
  }
  else
  {
    *error = _AX ;  // AX contains ErrorCode
    return   _DX ;
  }
}
#endif

#ifdef _tcpD9_
/*
@doc DOC_tcpD9_
 ----------------------------------------------------------------------------------
 Set proposals for a SSL session
 ----------------------------------------------------------------------------------
 @clib  SSL_SessionProp | Use this function to set proposals for a SSL session.
        For a client session, the proposals are used to construct the Client
        Hello message. For a server session, the proposals are used to match
        Client Hello message in order to determine the final cipher suite to use. |
        <cfont>int SSL_SessionProp(int sessionID, int far *proposals, int count,<nl>
              <tab><tab><tab><tab><tab>int *error);<efont> |
 @parm  int   | sessionID | Session ID for SSL session
 @parm  int * | proposals | Array of integer with Session proposals
 @parm  int  | count | Number of entries in the proposal array
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Suceess<nl>
        -1:  failed
 @comm To use this function on a server session, a previous call to function
       <linkto>tcpDA.htm<linkmid>SSL_SessionOpt<linktail> is needed.
       If the user doesn't call this function to set any session proposals,
       the default value is going to be used.<nl><nl>
       <bold>Possible proposals array entries:<bolde><nl>
       @raw
             TLS_RSA_NULL_MD5          = 0x0001
             TLS_RSA_NULL_SHA          = 0x0002
             TLS_RSA_EXPORT_RC4_40_MD5 = 0x0003
             TLS_RSA_RC4_128_MD5       = 0x0004
             TLS_RSA_RC4_128_SHA       = 0x0005
             TLS_RSA_3DES_EDE_CBC_SHA  = 0x000A
             TLS_RSA_AES_128_CBC_SHA   = 0x002F
             TLS_RSA_AES_256_CBC_SHA   = 0x0035
             TLS_RSA_EPT1K_RC4_56_SHA  = 0x0064

 @Also  tcpD8.htm | SSL_SessionNew  |
        tcpDA.htm | SSL_SessionOpt  |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xD9<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V1.07

 @target_clib V2.02
*/
int SSL_SessionProp(int sessionID, int far *proposals, int count, int *error)
{
  _DI = FP_OFF(proposals);
  _ES = FP_SEG(proposals);
  _BX = sessionID;
  _CX = count;
  _AH = SSL_SESSION_PROP;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpDA_
/*
@doc DOC_tcpDA_
 ----------------------------------------------------------------------------------
 Set options for a SSL session
 ----------------------------------------------------------------------------------
 @clib  SSL_SessionOpt | Call this function to set SSL session options. |
        <cfont>int SSL_SessionOpt(int sessionID, int option, int value,<nl>
              <tab><tab><tab><tab>&nbsp;&nbsp; int *error);<efont> |
 @parm  int  | sessionID | Session ID for SSL session
 @parm  int  | option    | option<nl>
             <ul>1: Client Authentication<nl>
                 2: Server Proposals<ule>
 @parm  int  | value     | option value<nl>
             <ul>0: disable option<nl>
                 1: enable option<ule>
 @parm  int  | error     | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Suceess<nl>
        -1:  failed
 @comm The client authentication option is used to enable client authentication
       on a SSL server session. It takes effect only if the session is bound to an
       SSL server socket, in which case, upon receiving the ClientHello message,
       the SSL server is going to send back a CertificateRequest message along with its
       own Certificate, ServerHello and ServerHelloDone messages.<nl>
       <nl>
       The server proposals option is used to allow the SSL server to have more control
       on which cipher suite to use. If this option is not used on an SSL server session,
       upon receiving a ClientHello message, the SSL server just chooses the first matched
       cipher suite from its own session proposal list, according to server's preference.
       If a cipher suite proposed by the client is not the SSL server session's proposal
       list, even if the SSL server supports that cipher suite, it won't be chosen.
       For example, if server proposals option is enabled and server prefers cipher suites
       1,2,3,4 and in this order. However, client only offers 4,3,2 and in this order,
       then cipher suite 2 will be chosen.

 @Also  tcpD8.htm | SSL_SessionNew  |
        tcpD9.htm | SSL_SessionProp  |
        tcpDB.htm | SSL_AddClientCA
        
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDA<linkmid>documentation<linktail>
        for more details.

 @target      SC12  | SC13  | SC11  | SC1x3
 @version     n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_SessionOpt(int sessionID, int option, int value, int *error)
{
  _BX = sessionID;
  _DX = option;
  _CX = value;
  _AH = SSL_SESSION_OPT;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpDB_
/*
@doc DOC_tcpDB_
 ----------------------------------------------------------------------------------
 Add a client CA certificate
 ----------------------------------------------------------------------------------
 @clib  SSL_AddClientCA | Call this function to add client CAs to ServerHello message. |
        <cfont>int SSL_AddClientCA(int sessionID, void far *caIdPtr,<nl>
              <tab><tab><tab><tab><tab>int *error);<efont> |
 @parm  int          | sessionID | Session ID for SSL session
 @parm  void far *   | caIdPtr   | Pointer to client CA certificate identity name
 @parm  int  | error | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Suceess<nl>
        -1:  failed
 @comm If client authentication option is used to enable client authentication
       on a SSL server session, this call can be used to add CAs to the ServerHello message
       (called CertificateRequest).<nl>
       This function must be called against an SSL server session. The SSL server will list
       CA's Distinguished Name to the client in his ServerHello message . This function can
       be called multiple times to add multiple potential CAs for client certificates.
       <nl>
       Before you can use this call, the client CAs certificate must be added to the PKI.

 @Also  tcpD0.htm | PKI_CertificateAdd  |
        tcpD8.htm | SSL_SessionNew      |
        tcpDA.htm | SSL_SessionOpt
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDB<linkmid>documentation<linktail>
        for more details.

 @target      SC12  | SC13  | SC11  | SC1x3
 @version     n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_AddClientCA(int sessionID, void far *caIdPtr, int *error)
{
  _BX = sessionID;
  _DI = FP_OFF(caIdPtr);
  _ES = FP_SEG(caIdPtr);
  _AH = SSL_CLI_CA_ADD;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpDC_
/*
@doc DOC_tcpDC_
 ----------------------------------------------------------------------------------
 Start the SSL client
 ----------------------------------------------------------------------------------
 @clib  SSL_ClientStart | Call this function to start the SSL client and SSL handshaking.
        Before this call, the user should set proper socket options on socket
        descriptor.  |
        <cfont>int SSL_ClientStart(int sd, char far * srvCommonName, int *error);<efont> |
 @parm  int  | sd | Socket descriptor
 @parm  char far * | srvCommonName | Server common name.<nl>
        The common name is used to verify the certificate of the peer. If user
        passes in a NULL string, the certificate identity is not checked. This
        means, any valid certificate, even if it belongs to a bad party, will be
        accepted.
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Success<nl>
        -1:  failed
 @comm  The certificate identity (common name field) may contain the wildcard character
        * which is considered to match any single domain name component or component fragment.
        E.g., "*.a.com" in certificate Common Name matches the server common name
        "foo.a.com" but not "bar.foo.a.com". And certificate common name "f*.com" matches
        server common name "foo.com" but not "bar.com".

 @Also  tcpD8.htm | SSL_SessionNew |
        tcp16.htm | setsockopt     |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDC<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_ClientStart(int sd, char far *srvCommonName, int *error)
{
  _BX = sd;
  _DI = FP_OFF(srvCommonName);
  _ES = FP_SEG(srvCommonName);
  _AH = SSL_CLI_START;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif

#ifdef _tcpDD_
/*
@doc DOC_tcpDD_
 ----------------------------------------------------------------------------------
 Send queued SSL user data
 ----------------------------------------------------------------------------------
 @clib  SSL_SendFlush | Queued SSL user data will be flushed.
        SSL will queue user data if the send path is not triggered up when
        socket option TCP_SSL_SEND_MIN_SIZE is greater than zero. All data
        will be sent out rigth away, if this function is called. |
        <cfont>int SSL_SendFlush(int sd, int *error);<efont> |
 @parm  int  | sd | Socket descriptor
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Success<nl>
        -1:  failed

 @Also  tcp16.htm | setsockopt     |
                  |                |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDD<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_SendFlush(int sd, int *error)
{
  _BX = sd;
  _AH = SSL_SEND_FLUSH;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif


#ifdef _tcpDE_
/*
@doc DOC_tcpDE_
 ----------------------------------------------------------------------------------
 Close a SSL connection
 ----------------------------------------------------------------------------------
 @clib  SSL_ConnClose | Close a SSL connection.
        The user data will be flushed and a close notify message
        will be send to the SSL peer. User may also close the whole
        socket instead of only closing the SSL layer. |
        <cfont>int SSL_ConnClose(int sd, int *error);<efont> |
 @parm  int  | sd | Socket descriptor
 @parm  int  | error    | Output parameter:<s2>Failure
        <linkto>../../iperrlst.htm#error<linkmid>code<linktail>, 0 on success.
 @rdesc 0: Success<nl>
        -1:  failed
 @comm  Note that the peer may not accept any data after the SSL layer
        is closed.

 @Also  tcp02.htm | closesocket    |
                  |                |
                  |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDE<linkmid>documentation<linktail>
        for more details.

 @target     SC12  | SC13  | SC11  | SC1x3
 @version    n/a   | n/a   | n/a   | V0.91

 @target_clib V2.02
*/
int SSL_ConnClose(int sd, int *error)
{
  _BX = sd;
  _AH = SSL_CONN_CLOSE;
  asm { int TCPIPVECT  } ;
  *error = _AX ;
  return   _DX ;
}
#endif


#ifdef _tcpDFA_
/*
@doc DOC_tcpDFA_
 ----------------------------------------------------------------------------------
 Build MD5 checksums (init)
 ----------------------------------------------------------------------------------
 @clib  Crypt_MD5_Init | Init MD5 checksum generator. |
        <cfont>int Crypt_MD5_Init ( Crypt_MD5_ContextPtr md5context );<efont> |
 @parm  Crypt_MD5_ContextPtr | md5context | Pointer to
        <linkto>../../tcpstruc.htm#Crypt_MD5_Context<linkmid>MD5 context structure<linktail>
 @rdesc 0: Success<nl>
        -1:  failed
 @Also  tcpDFB.htm | Crypt_MD5_Update |
        tcpDFC.htm | Crypt_MD5_Final  |
                   |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDF<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.05
 @target_clib V2.04
*/
int Crypt_MD5_Init (Crypt_MD5_ContextPtr md5context)
{
  _ES = FP_SEG(md5context);
  _DI = FP_OFF(md5context);
  _AL = 1;
  _AH = CRYPT_MD5_HASH;
  asm { int TCPIPVECT  } ;
  return   _DX ;
}
#endif


#ifdef _tcpDFB_
/*
@doc DOC_tcpDFB_
 ----------------------------------------------------------------------------------
 Build MD5 checksums (update)
 ----------------------------------------------------------------------------------
 @clib  Crypt_MD5_Update | Update MD5 checksum generator. |
        <cfont>int Crypt_MD5_Update ( Crypt_MD5_ContextPtr md5context,
        <tab><tab><tab><tab><tab><tab>unsigned char far* inBuffer,
        <tab><tab><tab><tab><tab><tab>unsigned int length );<efont> |
 @parm  Crypt_MD5_ContextPtr | md5context | Pointer to
        <linkto>../../tcpstruc.htm#Crypt_MD5_Context<linkmid>MD5 context structure<linktail>
 @parm  unsigned char far *   | inBuffer   | Pointer to user data
 @parm  unsigned int          | length     | Length of inBuffer in bytes
 @rdesc 0: Success<nl>
        -1:  failed
 @Also  tcpDFA.htm | Crypt_MD5_Init |
        tcpDFC.htm | Crypt_MD5_Final  |
                   |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDF<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.05
 @target_clib V2.04
*/
int Crypt_MD5_Update (Crypt_MD5_ContextPtr md5context,
                      unsigned char far *inBuffer, unsigned int length)
{
  _ES = FP_SEG(md5context);
  _DI = FP_OFF(md5context);
  _DX = FP_SEG(inBuffer);
  _SI = FP_OFF(inBuffer);
  _CX = length;
  _AL = 2;
  _AH = CRYPT_MD5_HASH;
  asm { int TCPIPVECT  } ;
  return   _DX ;
}
#endif

#ifdef _tcpDFC_
/*
@doc DOC_tcpDFC_
 ----------------------------------------------------------------------------------
 Build MD5 checksums (final)
 ----------------------------------------------------------------------------------
 @clib  Crypt_MD5_Final | Final MD5 checksum generator. |
        <cfont>int Crypt_MD5_Final ( Crypt_MD5_ContextPtr md5context );<efont> |
 @parm  Crypt_MD5_ContextPtr | md5context | Pointer to
        <linkto>../../tcpstruc.htm#Crypt_MD5_Context<linkmid>MD5 context structure<linktail>
 @rdesc 0: Success<nl>
        -1:  failed
 @comm  After this call md5context->;digest will hold the final hash value.
 @Also  tcpDFA.htm | Crypt_MD5_Init |
        tcpDFB.htm | Crypt_MD5_Update  |
                   |
 @rtos  This library function invokes a RTOS software interrupt.
        Refer to this RTOS API function's
        <linkto>../../tcpipapi.htm#0xAC0xDF<linkmid>documentation<linktail>
        for more details.
 @target     SC12  | SC13  | SC11  | SC1x3
 @version    V1.20 | V1.20 | V1.20 | V1.05
 @target_clib V2.04
*/
int Crypt_MD5_Final (Crypt_MD5_ContextPtr md5context)
{
  _ES = FP_SEG(md5context);
  _DI = FP_OFF(md5context);
  _AL = 3;
  _AH = CRYPT_MD5_HASH;
  asm { int TCPIPVECT  } ;
  return   _DX ;
}
#endif

/**************************************************************************/
//end tcpip.c
/*************************************************************************/
